@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_arch_c =
- *   "$Id: arch.c,v 1.33 1998/09/28 02:13:18 master Exp master $";
+ *   "$Id: arch.c,v 1.34.1.1 1999/07/13 04:17:38 master Exp $";
  */
 
 /*
@@ -262,7 +262,7 @@ void load_archetypes() {
     struct timeval tv1,tv2;
 #endif
 
-    sprintf(filename,"%s/%s",settings.libdir,settings.archetypes);
+    sprintf(filename,"%s/%s",settings.datadir,settings.archetypes);
     LOG(llevDebug,"Reading archetypes from %s...\n",filename);
     if((fp=open_and_uncompress(filename,0,&comp))==NULL) {
 	LOG(llevError," Can't open archetype file.\n");
