@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_button_c =
- *   "$Id: button.c,v 1.32 1998/05/16 01:59:28 master Exp $";
+ *   "$Id: button.c,v 1.33 1999/01/30 10:59:39 master Exp $";
  */
 
 /*
@@ -124,7 +124,7 @@ void push_button(object *op) {
 
 void update_button(object *op) {
     object *ab,*tmp;
-    int tot,any_down=0;
+    int tot,any_down=0, old_value=op->value;
     objectlink *ol;
 
     /* LOG(llevDebug, "update_button: %s (%d)\n", op->name, op->count); */
@@ -149,6 +149,7 @@ void update_button(object *op) {
 		if ( (!QUERY_FLAG(ab,FLAG_FLYING) || 
 		      QUERY_FLAG(tmp,FLAG_FLY_ON)) &&
 		     (ab->race==tmp->slaying ||
+		      ((ab->type==SPECIAL_KEY) && (ab->slaying==tmp->slaying)) || 
 		      (!strcmp (tmp->slaying, "player") && 
 		       ab->type == PLAYER)))
 			    tmp->value = 1;
@@ -159,9 +160,13 @@ void update_button(object *op) {
     }
     if(any_down) /* If any other buttons were down, force this to remain down */
 	op->value=1;
-    SET_ANIMATION(op, op->value);
-    update_object(op);
-    push_button(op); /* Make all other buttons the same */
+
+    /* If this button hasn't changed, don't do anything */
+    if (op->value != old_value) {
+	SET_ANIMATION(op, op->value);
+	update_object(op);
+	push_button(op); /* Make all other buttons the same */
+    }
 }
 
 /*
