@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_glue_c =
- *   "$Id: glue.c,v 1.21 1998/09/28 02:13:56 master Exp master $";
+ *   "$Id: glue.c,v 1.22 1998/11/26 10:43:23 master Exp $";
  */
 
 /*
@@ -42,7 +42,6 @@ type_func_ob	remove_friendly_object_func;
 type_func_void	process_active_maps_func;
 type_func_map	update_buttons_func;
 type_func_int_int_ob_cchar	draw_info_func;
-type_func_ob	draw_look_func;
 type_int_func_ob_ob_int	apply_func;
 type_func_ob	draw_func;
 type_func_ob_ob	monster_check_apply_func;
@@ -79,7 +78,6 @@ void init_function_pointers() {
   process_active_maps_func = dummy_function;
   update_buttons_func = dummy_function_map;
   draw_info_func = dummy_draw_info;
-  draw_look_func = dummy_function_ob;
   apply_func = dummy_int_function_ob_ob_int;
   draw_func = dummy_function_ob;
   monster_check_apply_func = dummy_function_ob2;
@@ -156,15 +154,6 @@ void set_draw_info(type_func_int_int_ob_cchar addr) {
   draw_info_func = addr;
 }
 
-/*
- * Specify which function to call to update the content
- * of the look-window of a player.
- */
-
-void set_draw_look(type_func_ob addr) {
-  draw_look_func = addr;
-}
-
 /*
  * Specify which function to call to apply an object.
  */
