@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_image_c =
- *   "$Id: image.c,v 1.18 1998/09/28 02:24:32 master Exp master $";
+ *   "$Id: image.c,v 1.19 1999/03/18 10:35:25 master Exp $";
  */
 
 /*
@@ -130,7 +130,7 @@ static void ReadFaceData()
     New_Face *on_face=NULL;
     FILE *fp;
 
-    sprintf(buf,"%s/faces", settings.libdir);
+    sprintf(buf,"%s/faces", settings.datadir);
     LOG(llevDebug,"Reading faces from %s...",buf);
     if ((fp=fopen(buf,"r"))==NULL) {
 	perror("Can't open faces file");
@@ -198,7 +198,7 @@ int ReadBmapNames () {
     FILE *fp;
     int value, nrofbmaps = 0, i, fg,bg;
 
-    sprintf (buf,"%s/bmaps", settings.libdir);
+    sprintf (buf,"%s/bmaps", settings.datadir);
     LOG(llevDebug,"Reading bmaps from %s...",buf);
     if ((fp=fopen(buf,"r"))==NULL) {
 	perror("Can't open bmaps file");
