@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_init_c =
- *   "$Id: init.c,v 1.26 1998/09/28 02:14:47 master Exp master $";
+ *   "$Id: init.c,v 1.29 1999/03/28 01:02:56 master Exp $";
  */
 
 /*
@@ -46,8 +46,12 @@ CSPORT,				/* Client/server port */
 0, NULL, 0,    /* dumpvalues, dumparg, daemonmode */
 0, /* argc */
 NULL, /* argv */
-LIBDIR, PLAYERDIR, MAPDIR, ARCHETYPES,TREASURES, 
-UNIQUE_DIR, TMPDIR
+DATADIR, 
+LOCALDIR,
+PLAYERDIR, MAPDIR, ARCHETYPES,TREASURES, 
+UNIQUE_DIR, TMPDIR,
+STAT_LOSS_ON_DEATH,
+SIMPLE_EXP
 };
 
 
@@ -83,7 +87,9 @@ void init_environ() {
 
 #ifndef SECURE
     cp=getenv("CROSSFIRE_LIBDIR");
-    if (cp) settings.libdir=cp;
+    if (cp) settings.datadir=cp;
+    cp=getenv("CROSSFIRE_LOCALDIR");
+    if (cp) settings.localdir=cp;
     cp=getenv("CROSSFIRE_PLAYERDIR");
     if (cp) settings.playerdir=cp;
     cp=getenv("CROSSFIRE_MAPDIR");
