@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_living_c =
- *   "$Id: living.c,v 1.48 1998/09/28 02:15:57 master Exp master $";
+ *   "$Id: living.c,v 1.52 1999/03/28 01:24:04 master Exp $";
  */
 
 /*
@@ -155,7 +155,7 @@ int learn_prayer_chance[MAX_STAT + 1] = {
 
 #define MAX_EXP_IN_OBJ levels[MAXLEVEL]/(MAX_EXP_CAT - 1) 
 
-static long levels[MAXLEVEL+1]={
+static uint32 levels[MAXLEVEL+1]={
 0,
 0,1000,2000,4000, 8000,
 16000,32000,64000,125000,250000,		/* 10 */
@@ -180,6 +180,33 @@ static long levels[MAXLEVEL+1]={
 118100000,119700000,121300000,122900000,124500000, 	
 126100000,127700000,129300000,130900000,785400000	/* 110 */};
 
+static uint32 new_levels[MAXLEVEL+1]={
+0,
+0,2000,4000, 8000,
+16000,32000,64000,125000,250000,		/* 9 */
+500000,900000,1400000,2000000,2600000,
+3300000,4100000,4900000,5700000,6600000,	/* 19 */
+7500000,8400000,9300000,10300000,11300000,
+12300000,13300000,14400000,15500000,16600000,	/* 29 */
+17700000,18800000,19900000,21100000,22300000,	
+23500000,24700000,25900000,27100000,28300000,	/* 39 */
+29500000,30800000,32100000,33400000,34700000,
+36000000,37300000,38600000,39900000,41200000,	/* 49 */
+42600000,44000000,45400000,46800000,48200000,
+49600000,51000000,52400000,53800000,55200000,	/* 59 */
+56600000,58000000,59400000,60800000,62200000,
+63700000,65200000,66700000,68200000,69700000,	/* 69 */
+71200000,72700000,74200000,75700000,77200000,
+78700000,80200000,81700000,83200000,84700000,	/* 79 */
+86200000,87700000,89300000,90900000,92500000,
+94100000,95700000,97300000,98900000,100500000,	/* 89 */
+102100000,103700000,105300000,106900000,108500000,
+110100000,111700000,113300000,114900000,116500000,	/* 99 */
+118100000,119700000,121300000,122900000,124500000, 	
+126100000,127700000,129300000,130900000,785400000,
+1570800000	/* 110 */
+};
+
 /* Max level is 100.  By making it 101, it means values 0->100 are valid.
  * Thus, we can use op->level directly, and it also works for level 0 people.
  */
@@ -856,7 +883,7 @@ void add_statbonus(object *op) {
 
 void fix_player(object *op) {
   int i,j;
-  float f,max=9,added_speed=0,bonus_speed=0, sp_tmp;
+  float f,max=9,added_speed=0,bonus_speed=0, sp_tmp,speed_reduce_from_disease=1;
   float M,W,s,D,K,S,M2;
   int weapon_weight=0,weapon_speed=0;
   int best_wc=0, best_ac=0, wc=0;
@@ -905,7 +932,8 @@ void fix_player(object *op) {
 
 
   if(!QUERY_FLAG(op,FLAG_USE_ARMOUR) && op->type==PLAYER) 
-      op->stats.ac=MAX(-10,op->arch->clone.stats.ac - op->level/3);
+	/* for players which cannot use armour, they gain AC -1 per 3 levels. */
+	op->stats.ac=MAX(-10,op->arch->clone.stats.ac - op->level/3);
   else
       op->stats.ac=op->arch->clone.stats.ac;
 
@@ -932,13 +960,21 @@ void fix_player(object *op) {
 		  || (tmp->type == SHIELD) || (tmp->type == RING)
 		  || (tmp->type == BOOTS) || (tmp->type == GLOVES)
 		  || (tmp->type == AMULET ) || (tmp->type == GIRDLE)
-		  || (tmp->type == BRACERS ) || (tmp->type == CLOAK)){
+		  || (tmp->type == BRACERS ) || (tmp->type == CLOAK) 
+		  ||(tmp->type == DISEASE) || (tmp->type == FORCE)){
 			op->contr->digestion += tmp->stats.food;
 			op->contr->gen_hp += tmp->stats.hp;
 			op->contr->gen_sp += tmp->stats.sp;
 			op->contr->gen_grace += tmp->stats.grace;
 		}
 	  }
+
+		if(tmp->type==SYMPTOM) {
+		  speed_reduce_from_disease = tmp->last_sp / 100.0;
+		  if(speed_reduce_from_disease ==0) speed_reduce_from_disease = 1;
+		}
+		  
+		  
       op->protected|=tmp->protected;
       op->vulnerable|=tmp->vulnerable;
       if (tmp->type!=BOW) {
@@ -1261,6 +1297,7 @@ void fix_player(object *op) {
   /* Put a lower limit on speed.  Note with this speed, you move once every
    * 100 ticks or so.  This amounts to once every 12 seconds of realtime.
    */
+  op->speed = op->speed * speed_reduce_from_disease;
   if (op->speed<0.01 && op->type==PLAYER) op->speed=0.01;
 
   if(op->type == PLAYER) {
@@ -1312,19 +1349,23 @@ int allowed_class(object *op) {
  * the given level.
  */
 
-long level_exp(int level,double expmul) {
-/*  int   count,required_exp;*/
+uint32 level_exp(int level,double expmul) {
+    static long int bleep=1650000; 
 
-  static long int bleep=1650000; 
-/* Eneq(@csd.uu.se):  New level-algorithm; level 2 at 1000 then  
-   times 2 for all following. */
+    if(level<=100) {
+	if (settings.simple_exp) {
+	    return expmul * new_levels[level];
+	} else {
+	    return expmul * levels[level];
+	}
+    }
 
-  if(level<=100) return expmul * levels[level];
-
-/*  for (count=10, required_exp=levels[count];count<level;count++)
-    required_exp*=1.5; */
-/*  return required_exp; */
-    return expmul*(levels[100]+bleep*(level-100));
+    /*  return required_exp; */
+    if (settings.simple_exp) {
+	return expmul*(new_levels[100]+bleep*(level-100));
+    } else {
+	return expmul*(levels[100]+bleep*(level-100));
+    }
 }
 
 #ifdef ALLOW_SKILLS /* new experience system */ 
@@ -1341,126 +1382,129 @@ long level_exp(int level,double expmul) {
  */
  
 void add_exp(object *op, int exp) {
-  object *exp_ob=NULL; /* the object into which experience will go */ 
-  object *tmp,*pl_exp[MAX_EXP_CAT];
-  int old_exp,del_exp=0,nrofexp=0,i;
+    object *exp_ob=NULL; /* the object into which experience will go */ 
+    object *tmp,*pl_exp[MAX_EXP_CAT];
+    int old_exp,del_exp=0,nrofexp=0,i;
 
-  /* safety */
-  if(!op) { 
-    LOG(llevError,"add_exp() called for null object!\n"); 
-    return; 
-  } 
+    /* safety */
+    if(!op) { 
+	LOG(llevError,"add_exp() called for null object!\n"); 
+	return; 
+    }
 
 #ifdef EXP_DEBUG
-  LOG(llevDebug,"add_exp() called for %s, exp = %d\n",query_name(op),exp); 
+    LOG(llevDebug,"add_exp() called for %s, exp = %d\n",query_name(op),exp); 
 #endif
 
-  if(op->type != PLAYER) 		/* for Monsters only */
-     exp =  adjust_exp(op,exp);
-  else {				/* Players only */ 
-     if(exp>0) { /* ADDING exp (to one object) */ 
-	int limit;
+    if(op->type != PLAYER) { 		/* for Monsters only */
+	/* Sanity check */
+	if (!QUERY_FLAG(op, FLAG_ALIVE)) return;
+	exp =  adjust_exp(op,exp);
+    }
+    else {				/* Players only */ 
+	if(exp>0) { /* ADDING exp (to one object) */ 
+	    int limit=0;
 
-	if(!op->chosen_skill) { 
-	   LOG(llevError,"add_exp() called for %s w/ no ready skill.\n",op->name);
-	   return;
-	} else if(!op->exp_obj && !op->chosen_skill->exp_obj) { 
-	   /* This shouldn't be an error - killing monsters via scrolls
-	    * will get here, because use_magic skill doesn't give exp -
-	    * this means things like rods and scrolls.
-	    */
-	   LOG(llevDebug,"add_exp() called for skill w/o exp obj (%s), .\n", 
-	       op->chosen_skill->name);
-	   return;
-	}
+	    if(!op->chosen_skill) { 
+		LOG(llevError,"add_exp() called for %s w/ no ready skill.\n",op->name);
+		return;
+	    } else if(!op->exp_obj && !op->chosen_skill->exp_obj) { 
+		/* This shouldn't be an error - killing monsters via scrolls
+		 * will get here, because use_magic skill doesn't give exp -
+		 * this means things like rods and scrolls.
+		 */
+		LOG(llevDebug,"add_exp() called for skill w/o exp obj (%s), .\n", 
+		    op->chosen_skill->name);
+		return;
+	    }
 
-	/* if op->exp_obj is set, then the player has killed with an 
-	 * animated object cf. fireball */
-	if(op->exp_obj)  
-	   exp_ob = op->exp_obj;
-	else
-	   exp_ob = op->chosen_skill->exp_obj; 
+	    /* if op->exp_obj is set, then the player has killed with an 
+	     * animated object cf. fireball */
+	    if(op->exp_obj)  
+		exp_ob = op->exp_obj;
+	    else
+		exp_ob = op->chosen_skill->exp_obj; 
 
-        /* General adjustments for playbalance */ 
+	    /* General adjustments for playbalance */ 
 
-	/* I changed this from the old algorithm. Formerly,
-	 * if the experience you would have gained was 
-	 * greater than 1/2 your TOTAL experience, you only
-	 * gained 1/2 the award (which could *still be greater
-	 * than 1/2 your total exp!) (Actually, incorrect.  Previously
-	 * if it was greater than half your total, you would gain half your
-	 * your total - mw) . Now, exp gain is limited
-	 * so the exp award can be no *more than* 1/2 of 
-	 * the exp is takes to get from your present level to 
-	 * the next one (basically, no one can learn faster than
-	 * that!).
-	 */
+	    /* I changed this from the old algorithm. Formerly,
+	     * if the experience you would have gained was 
+	     * greater than 1/2 your TOTAL experience, you only
+	     * gained 1/2 the award (which could *still be greater
+	     * than 1/2 your total exp!) (Actually, incorrect.  Previously
+	     * if it was greater than half your total, you would gain half your
+	     * your total - mw) . Now, exp gain is limited
+	     * so the exp award can be no *more than* 1/2 of 
+	     * the exp is takes to get from your present level to 
+	     * the next one (basically, no one can learn faster than
+	     * that!).
+	     */
 
-	if(exp_ob->level < MAXLEVEL) { 
-	  limit=(levels[exp_ob->level+1]-levels[exp_ob->level])/2;
-	  if (exp > limit) exp=limit;
-	} else { /* there is no going any higher! */ 
-/*	  add_exp(op,0);	Why do this if we aren't chaning anything? */
-	  return;
- 	}
+	    if(exp_ob->level < MAXLEVEL) { 
+		if (settings.simple_exp) {
+		    limit=(new_levels[exp_ob->level+1]-new_levels[exp_ob->level])/2;
+		} else {
+		    limit=(levels[exp_ob->level+1]-levels[exp_ob->level])/2;
+		}
+		if (exp > limit) exp=limit;
+	    } else { /* there is no going any higher! */ 
+		return;
+	    }
 
-	/* for beginning players, no less than 10 exp minimum */
-	if ((op->stats.exp < 10) && (exp == 0)) exp = 10;
+	    /* prevents some forms of abuse */
+	    if(op->type==PLAYER && op->contr->braced) exp=exp/5; 
 
-	/* prevents some forms of abuse */
-	if(op->type==PLAYER && op->contr->braced) exp=exp/5; 
+	    /* Adding exp properly - we have to make sure that:
+	     *	1) op->stats.exp<MAX_EXPERIENCE 
+	     *	2) exp_ob->stats.exp<MAX_EXP_IN_OBJ
+	     * 	3) sum of exp obj experience = op->stats.exp
+	     */
 
-	/* Adding exp properly - we have to make sure that:
-         *	1) op->stats.exp<MAX_EXPERIENCE 
-   	 *	2) exp_ob->stats.exp<MAX_EXP_IN_OBJ
-	 * 	3) sum of exp obj experience = op->stats.exp
-	 */
-
-        exp = adjust_exp(op,exp);	/* op->stats.exp < MAX_EXPERIENCE */ 
-	old_exp = exp;	
-        exp = adjust_exp(exp_ob,exp);   /* exp_ob->stats.exp < MAX_EXP_IN_OBJ */ 
-					/* check and  adjustment */ 
-	if(old_exp>exp) op->stats.exp+=(exp-old_exp); 
-	player_lvl_adj(op,NULL);   
-	player_lvl_adj(op,exp_ob);   
+	    exp = adjust_exp(op,exp);	/* op->stats.exp < MAX_EXPERIENCE */ 
+	    old_exp = exp;	
+	    exp = adjust_exp(exp_ob,exp);   /* exp_ob->stats.exp < MAX_EXP_IN_OBJ */ 
+					    /* check and  adjustment */ 
+	    if(old_exp>exp) op->stats.exp+=(exp-old_exp); 
+	    player_lvl_adj(op,NULL);   
+	    player_lvl_adj(op,exp_ob);   
   
-     } else if (op->type ==PLAYER && exp < 0) { /* SUBTRACT exp (from all exp obj) */ 
-  	float fraction = (float) exp/(float) op->stats.exp;
+	} else if (op->type ==PLAYER && exp < 0) { /* SUBTRACT exp (from all exp obj) */ 
+	    float fraction = (float) exp/(float) op->stats.exp;
 
-	/* Sub exper - we will remove the same fraction of experience
-	 * from all experience objects. 
- 	 */
+	    /* Sub exper - we will remove the same fraction of experience
+	     * from all experience objects. 
+	     */
 
-	for(tmp=op->inv;tmp;tmp=tmp->below)
-	  if(tmp->type==EXPERIENCE && tmp->stats.exp) { 
-		pl_exp[nrofexp] = tmp;
-		nrofexp++; 
-	  } 
-	/* we do experience objects first here */
-	for(i=0;i<nrofexp;i++) { 
-	   del_exp += adjust_exp(pl_exp[i],(pl_exp[i]->stats.exp*fraction)); 
-  	   player_lvl_adj(op,pl_exp[i]); /* adj exp object */ 
+	    for(tmp=op->inv;tmp;tmp=tmp->below)
+		if(tmp->type==EXPERIENCE && tmp->stats.exp) { 
+		    pl_exp[nrofexp] = tmp;
+		    nrofexp++; 
+		}
+
+	    /* we do experience objects first here */
+	    for(i=0;i<nrofexp;i++) { 
+		del_exp += adjust_exp(pl_exp[i],(pl_exp[i]->stats.exp*fraction)); 
+		player_lvl_adj(op,pl_exp[i]); /* adj exp object */ 
+	    }
+
+	    (void) adjust_exp(op, del_exp);
+	    player_lvl_adj(op,NULL); 
+
+	} else if (op->type !=PLAYER && exp < 0) { /* SUBTRACT monster exp */ 
+
+	    (void) adjust_exp(op, exp);
+	    player_lvl_adj(op,NULL);
+
+	} else { /* No exp gain, but check lvl adj */ 
+
+	    if(op->chosen_skill && op->chosen_skill->exp_obj)
+		player_lvl_adj(op, op->chosen_skill->exp_obj);
+	    player_lvl_adj(op,NULL); 
 	}
 
-	(void) adjust_exp(op, del_exp);
-	player_lvl_adj(op,NULL); 
-
-     } else if (op->type !=PLAYER && exp < 0) { /* SUBTRACT monster exp */ 
-
-        (void) adjust_exp(op, exp);
-        player_lvl_adj(op,NULL);
-
-     } else { /* No exp gain, but check lvl adj */ 
-
-	if(op->chosen_skill && op->chosen_skill->exp_obj)
-  	    player_lvl_adj(op, op->chosen_skill->exp_obj);
-  	player_lvl_adj(op,NULL); 
-     }
-
-     /* reset the player exp_obj to NULL */
-     if(op->exp_obj) op->exp_obj = NULL;
-  }
-
+	/* reset the player exp_obj to NULL */
+	if(op->exp_obj) op->exp_obj = NULL;
+    }
 }
 
 #else /*ALLOW_SKILLS */ /* add_exp() - the old exp system */
@@ -1472,40 +1516,42 @@ void add_exp(object *op, int exp) {
  */
 
 void add_exp(object *op,int exp) {
-  char buf[MAX_BUF];
+    char buf[MAX_BUF];
 
-  if (exp > op->stats.exp / 2)
-    if (op->stats.exp < 100)
-      exp = 50;
-    else
-      exp = op->stats.exp / 2;
-  if(op->type==PLAYER && op->contr->braced) exp=exp/5; 
-  /* shuffled some stuff into here  -b.t. */
-  exp = adjust_exp(op,exp);
+    if (exp > op->stats.exp / 2) {
+	if (op->stats.exp < 100)
+	    exp = 50;
+	else
+	    exp = op->stats.exp / 2;
+    }
 
-  if(op->type==PLAYER) {
-    if(op->level < MAXLEVEL && op->stats.exp >= level_exp(op->level+1,op->expmul)) {
-      op->level++;
-      if(op->level < 11)
-      {  
-        op->contr->levhp[op->level] = (int) RANDOM()%4 + (int) RANDOM()%4 + 3;
-        op->contr->levsp[op->level] = (int) RANDOM()%3 + (int) RANDOM()%3 + 2;
+    if(op->type==PLAYER && op->contr->braced) exp=exp/5; 
+    /* shuffled some stuff into here  -b.t. */
+    exp = adjust_exp(op,exp);
+
+    if(op->type==PLAYER) {
+	if(op->level < MAXLEVEL && op->stats.exp >= level_exp(op->level+1,op->expmul)) {
+	    op->level++;
+	    if(op->level < 11) {
+
+		op->contr->levhp[op->level] = (int) RANDOM()%4 + (int) RANDOM()%4 + 3;
+		op->contr->levsp[op->level] = (int) RANDOM()%3 + (int) RANDOM()%3 + 2;
 		  op->contr->levgrace[op->level]=(int)RANDOM()%2 + (int) RANDOM()%2 + 1;
-      }  
-      fix_player(op);
-      if(op->level>1) {
-        sprintf(buf,"You are now level %d.",op->level);
-        (*draw_info_func)(NDI_UNIQUE, 0, op,buf);
-      }
-      add_exp(op,0); /* To increase more levels */
-    } else if(op->level>1&&op->stats.exp<level_exp(op->level,op->expmul)) {
-      op->level--;
-      fix_player(op);
-      sprintf(buf,"You are now level %d.",op->level);
-      (*draw_info_func)(NDI_UNIQUE, 0, op,buf);
-      add_exp(op,0); /* To decrease more levels */
-    } 
-  } 
+	    }
+	    fix_player(op);
+	    if(op->level>1) {
+		sprintf(buf,"You are now level %d.",op->level);
+		(*draw_info_func)(NDI_UNIQUE, 0, op,buf);
+	    }
+	    add_exp(op,0); /* To increase more levels */
+	} else if(op->level>1&&op->stats.exp<level_exp(op->level,op->expmul)) {
+	    op->level--;
+	    fix_player(op);
+	    sprintf(buf,"You are now level %d.",op->level);
+	    (*draw_info_func)(NDI_UNIQUE, 0, op,buf);
+	    add_exp(op,0); /* To decrease more levels */
+	}
+    }
 }    
 
 #endif /* ALLOW_SKILLS */ 
@@ -1516,34 +1562,34 @@ void add_exp(object *op,int exp) {
  */
 
 void player_lvl_adj(object *who, object *op) {
-  char buf[MAX_BUF];
+    char buf[MAX_BUF];
 
     if(!op)        /* when rolling stats */ 
-      op = who;	
+	op = who;	
  
     if(op->level < MAXLEVEL && op->stats.exp >= level_exp(op->level+1,op->expmul)) {
 	op->level++;
 
-      if(who && (who->level < 11) && op->type!=EXPERIENCE) { 
-          who->contr->levhp[who->level] = (int) RANDOM()%4 + (int) RANDOM()%4 + 3;
-          who->contr->levsp[who->level] = (int) RANDOM()%3 + (int) RANDOM()%3 + 2;
+	if(who && (who->level < 11) && op->type!=EXPERIENCE) { 
+	    who->contr->levhp[who->level] = (int) RANDOM()%4 + (int) RANDOM()%4 + 3;
+	    who->contr->levsp[who->level] = (int) RANDOM()%3 + (int) RANDOM()%3 + 2;
 			 who->contr->levgrace[who->level]=(int)RANDOM()%2 + (int) RANDOM()%2 + 1;
-      }
+	}
 
-      if(who) fix_player(who);
-      if(op->level>1 && op->type==EXPERIENCE) {
-        sprintf(buf,"You are now level %d in %s based skills.",op->level,op->name);
-        if(who) (*draw_info_func)(NDI_UNIQUE|NDI_RED, 0, who,buf);
-      }  
-      player_lvl_adj(who,op); /* To increase more levels */
+	if(who) fix_player(who);
+	if(op->level>1 && op->type==EXPERIENCE) {
+	    sprintf(buf,"You are now level %d in %s based skills.",op->level,op->name);
+	    if(who) (*draw_info_func)(NDI_UNIQUE|NDI_RED, 0, who,buf);
+	}
+	player_lvl_adj(who,op); /* To increase more levels */
     } else if(op->level>1&&op->stats.exp<level_exp(op->level,op->expmul)) {
-      op->level--;
-      if(who) fix_player(who);
-      if(op->type==EXPERIENCE) {
-        sprintf(buf,"You are now level %d in %s based skills.",op->level,op->name);
-        if(who) (*draw_info_func)(NDI_UNIQUE|NDI_RED, 0, who,buf);
-      }
-      player_lvl_adj(who,op); /* To decrease more levels */
+	op->level--;
+	if(who) fix_player(who);
+	if(op->type==EXPERIENCE) {
+	    sprintf(buf,"You are now level %d in %s based skills.",op->level,op->name);
+	    if(who) (*draw_info_func)(NDI_UNIQUE|NDI_RED, 0, who,buf);
+	}
+	player_lvl_adj(who,op); /* To decrease more levels */
     }
 }
 
@@ -1552,22 +1598,22 @@ void player_lvl_adj(object *who, object *op) {
  */
  
 int adjust_exp(object *op, int exp) {
-  int max_exp = MAX_EXPERIENCE;
+    int max_exp = MAX_EXPERIENCE;
 
-  op->stats.exp += exp;
-  if(op->stats.exp < 0) {
-    exp -= op->stats.exp;
-    op->stats.exp = 0;
-  } 
-  /* reset max_exp value if we have experience obj */
-  if(op->type==EXPERIENCE) 
-      max_exp = MAX_EXP_IN_OBJ;
+    op->stats.exp += exp;
+    if(op->stats.exp < 0) {
+	exp -= op->stats.exp;
+	op->stats.exp = 0;
+    }
+    /* reset max_exp value if we have experience obj */
+    if(op->type==EXPERIENCE) 
+	max_exp = MAX_EXP_IN_OBJ;
 
-  if(op->stats.exp>max_exp) {
-    exp = exp - (op->stats.exp - max_exp);
-    op->stats.exp=max_exp;
-  }     
-  return exp;	/* return the actual amount changed stats.exp by */ 
+    if(op->stats.exp>max_exp) {
+	exp = exp - (op->stats.exp - max_exp);
+	op->stats.exp=max_exp;
+    }
+    return exp;	/* return the actual amount changed stats.exp by */ 
 }
 
 /* check_dm_add_exp() - called from c_wiz.c. Needed by ALLOW_SKILLS
@@ -1576,9 +1622,9 @@ int adjust_exp(object *op, int exp) {
 
 int check_dm_add_exp_to_obj(object *exp_ob, int i) {
 
-  if((exp_ob->stats.exp + i) < 0) 
-      i= -1*(exp_ob->stats.exp);
-  else if((exp_ob->stats.exp +i)> MAX_EXP_IN_OBJ)
-      i= MAX_EXP_IN_OBJ - exp_ob->stats.exp;
-  return i;
+    if((exp_ob->stats.exp + i) < 0) 
+	i= -1*(exp_ob->stats.exp);
+    else if((exp_ob->stats.exp +i)> MAX_EXP_IN_OBJ)
+	i= MAX_EXP_IN_OBJ - exp_ob->stats.exp;
+    return i;
 }
