@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_map_c =
- *   "$Id: map.c,v 1.55 1998/09/28 02:16:42 master Exp master $";
+ *   "$Id: map.c,v 1.58 1999/03/23 07:04:08 master Exp $";
  */
 
 /*
@@ -35,6 +35,11 @@
 
 extern int nrofallocobjects,nroffreeobjects;
 
+#if defined(sgi)
+/* popen_local is defined in porting.c */
+#define popen popen_local
+#endif
+
 #if defined (MACH) || defined (NeXT) || defined (__MACH__)
 #ifndef S_ISGID
 #define S_ISGID 0002000
@@ -112,9 +117,9 @@ char *create_pathname (char *name) {
      * someplace else in the code? msw 2-17-97
      */
     if (*name == '/')
-      sprintf (buf, "%s/%s%s", settings.libdir, settings.mapdir, name);
+      sprintf (buf, "%s/%s%s", settings.datadir, settings.mapdir, name);
     else
-      sprintf (buf, "%s/%s/%s", settings.libdir, settings.mapdir, name);
+      sprintf (buf, "%s/%s/%s", settings.datadir, settings.mapdir, name);
     return (buf);
 }
 
@@ -131,7 +136,7 @@ static char *create_items_path (char *s) {
     if (*s == '/')
       s++;
 
-    sprintf (buf, "%s/%s/", settings.libdir, settings.uniquedir);
+    sprintf (buf, "%s/%s/", settings.localdir, settings.uniquedir);
 
     for (t=buf+strlen(buf); *s; s++,t++)
       if (*s == '/')
@@ -885,6 +890,9 @@ static void load_unique_objects(mapstruct *m) {
 	sprintf(firstname, "%s.v%02d", create_items_path(m->path), count);
 	if (!access(firstname, R_OK)) break;
     }
+    /* If we get here, we did not find any map */
+    if (count==10) return;
+
     if ((fp=open_and_uncompress(firstname, 0, &comp))==NULL) {
 	/* There is no expectation that every map will have unique items, but this
 	 * is debug output, so leave it in.
@@ -1014,16 +1022,22 @@ void make_path_to_file (char *filename)
     LOG(llevDebug, "make_path_tofile %s...", filename);
     while ((cp = strchr (cp + 1, (int) '/'))) {
 	*cp = '\0';
+#if 0
 	LOG(llevDebug, "\n Checking %s...", buf);
+#endif
 	if (stat(buf, &statbuf) || !S_ISDIR (statbuf.st_mode)) {
 	    LOG(llevDebug, "Was not dir...");
 	    if (mkdir (buf, 0777)) {
 		perror ("Couldn't make path to file");
 		return;
 	    }
+#if 0
 	    LOG(llevDebug, "Made dir.");
 	} else
 	    LOG(llevDebug, "Was dir");
+#else
+	}
+#endif
 	*cp = '/';
     }
     LOG(llevDebug,"\n");
