@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_object_c =
- *   "$Id: object.c,v 1.58 1998/09/28 02:17:56 master Exp master $";
+ *   "$Id: object.c,v 1.64 1999/03/25 10:49:46 master Exp $";
  */
 
 /*
@@ -89,15 +89,30 @@ inline int CAN_MERGE(object *ob1, object *ob2) {
      */
     if (!QUERY_FLAG(ob1,FLAG_ANIMATE) && FABS((ob1)->speed) > 0.001 ) return 0;
 
+
+    /* If the objects have been identified, set the BEEN_APPLIED flag.
+     * This is to the comparison of the flags below will be OK.  We
+     * just can't ignore the been applied or identified flags, as they
+     * are not equal - just if it has been identified, the been_applied
+     * flags lose any meaning.
+     */
+    if (QUERY_FLAG(ob1, FLAG_IDENTIFIED))
+	SET_FLAG(ob1, FLAG_BEEN_APPLIED);
+
+    if (QUERY_FLAG(ob2, FLAG_IDENTIFIED))
+	SET_FLAG(ob2, FLAG_BEEN_APPLIED);
+
+
     /* the 0x400000 on flags2 is FLAG_INV_LOCK.  I don't think something
      * being locked in inventory should prevent merging.
+     * 0x4 in flags3 is CLIENT_SENT 
      */
     if ((ob1->arch != ob2->arch) || 
 	(ob1->stats.sp != ob2->stats.sp) ||
 	(ob1->flags[0] != ob2->flags[0]) || 
 	(ob1->flags[1] != ob2->flags[1]) ||
 	((ob1->flags[2] & ~0x400000) != (ob2->flags[2] & ~ 0x400000)) ||
-	(ob1->flags[3] != ob2->flags[3]) || 
+	((ob1->flags[3] & ~0x4) != (ob2->flags[3] & ~0x4)) || 
 	(ob1->name != ob2->name) || 
 	(ob1->title != ob2->title) ||
 	(ob1->msg != ob2->msg) || 
@@ -533,7 +548,7 @@ void copy_object(object *op2, object *op) {
     add_refcount(op->slaying);
   if(op->msg!=NULL)
     add_refcount(op->msg);
-  if(op2->speed<0)
+  if((op2->speed<0) && !editor)
     op->speed_left=op2->speed_left-RANDOM()%200/100.0;
   update_ob_speed(op);
 }
@@ -679,52 +694,55 @@ void update_ob_speed(object *op) {
  * update_object() updates the array which represents the map.
  * It takes into account invisible objects (and represent squares covered
  * by invisible objects by whatever is below them (unless it's another
- * invisible object, etc...))
+ * invisible object, etc...)
  * If the object being updated is beneath a player, the look-window
  * of that player is updated (this might be a suboptimal way of
  * updating that window, though, since update_object() is called _often_)
  */
 
 void update_object(object *op) {
-  object *tmp, *player;
+    object *tmp, *player;
 
-  if(op->env!=NULL) {
-    tmp=is_player_inv(op->env);
-    /* If we are in ericserver mode, I think we should send an update
-     * or something.  Ideally, client should handle animations on its
-     * own.
-     */
-    return;
-  }
-
- /* Can be null if the player has quit but window still exists. */
-  if (op->map->map != NULL) {
-    player=update_position (op->map, op->x, op->y);
-    /*
-     * insert_ob_in_map calls update_ob.  insert_ob_in_map is called with
-     * the player object anytime he moves - as such, we compare the object
-     * being updated against the player object so that we don't send
-     * unnecessary update commands.  Also, the client doesn't do anything
-     * with the players face anyways.
-     * As a note - we assume that we get here because the face has changed -
-     * this might not always be the case, but seems to be a good amount of
-     * the time, and its easier to do this than track down all the places in
-     * the code that changes the face.
-     *
-     * Add a check so that if the item that is changing is hidden from
-     * the player (ie, below the floor), we don't send an update to the
-     * player.
-     */
-    if (player && player!=op) {
-	for (tmp=op; tmp!=NULL; tmp=tmp->above)
-	    if (QUERY_FLAG(tmp,FLAG_IS_FLOOR) && !tmp->invisible) break;
-
-	if (!tmp) esrv_update_item_func(UPD_FACE, player, op);
+    if(op->env!=NULL) {
+	tmp=is_player_inv(op->env);
+	/* If we are in ericserver mode, I think we should send an update
+	 * or something.  Ideally, client should handle animations on its
+	 * own.
+	 */
+	return;
     }
-  }
 
-  if(op->more!=NULL)
-    update_object(op->more);
+    /* Can be null if the player has quit but window still exists. */
+    if (op->map->map != NULL) {
+	player=update_position (op->map, op->x, op->y);
+	/*
+	 * insert_ob_in_map calls update_ob.  insert_ob_in_map is called with
+	 * the player object anytime he moves - as such, we compare the object
+	 * being updated against the player object so that we don't send
+	 * unnecessary update commands.  Also, the client doesn't do anything
+	 * with the players face anyways.
+	 * As a note - we assume that we get here because the face has changed -
+	 * this might not always be the case, but seems to be a good amount of
+	 * the time, and its easier to do this than track down all the places in
+	 * the code that changes the face.
+	 *
+	 * Add a check so that if the item that is changing is hidden from
+	 * the player (ie, below the floor), we don't send an update to the
+	 * player.
+	 * If update_look has been set, that is going to send all the stuff
+	 * anyways, so no reason to send an update for it
+	 */
+
+	if (player && player!=op && !player->contr->socket.update_look) {
+	    for (tmp=op; tmp!=NULL; tmp=tmp->above)
+		if (QUERY_FLAG(tmp,FLAG_IS_FLOOR) && !tmp->invisible) break;
+
+	    if (!tmp) esrv_update_item_func(UPD_FACE, player, op);
+	}
+    }
+
+    if(op->more!=NULL)
+	update_object(op->more);
 }
 
 
@@ -745,8 +763,12 @@ void update_object(object *op) {
 object *update_position (mapstruct *m, int x, int y) {
     object *tmp, *last = NULL, *player=NULL;
     unsigned int flags = 0;
-    MapLook f=blank_look,floor=blank_look;
-    MapLook f1 = blank_look;
+    MapLook f,floor, f1;
+
+
+    f1=blank_look;
+    f=blank_look;
+    floor=blank_look;
 
     for (tmp = get_map_ob (m, x, y); tmp; last = tmp, tmp = tmp->above) {
 
@@ -1083,7 +1105,7 @@ void remove_ob(object *op) {
 	    CLEAR_FLAG(op, FLAG_APPLIED);
 	    tmp->container=NULL;
 	}
-      (*draw_look_func)(tmp);
+	tmp->contr->socket.update_look=1;
     }
     if(QUERY_FLAG(op,FLAG_FLYING)?QUERY_FLAG(tmp,FLAG_FLY_OFF):
       QUERY_FLAG(tmp,FLAG_WALK_OFF))
@@ -1235,41 +1257,16 @@ void insert_ob_in_map_simple(object *op, mapstruct *m)
   }
   else
     set_map_ob(op->map,op->x,op->y,op);   /* Tell the map that we're here */
-  update_object(op);
-
-/* comment out, 0.93.7 - insert_ob_in_map_simple should only be called in
- * some special places with objects - in most all places, the object
- * was already around, and is being re-inserted.  This will hopefully fix
- * a problem with dropping objects on a slow move space (otherwise,
- * the slow move penalty was applied for each object.
- */
-
-#if 0
-  /* Only check this if we are the head of the object */
-  if (!op->head) {
-      check_walk_on(op);
-      if(QUERY_FLAG(op,FLAG_FREED))	/* check_walk_on() killed it */
-	return;
-
-      /* If we are a multi part object, lets work our way through the check
-       * walk on's.  See if the object has been freed after each check.
-       */
-      for (tmp=op->more; tmp!=NULL; tmp=tmp->more) {
-          check_walk_on(op);
-          if(QUERY_FLAG(op,FLAG_FREED))	/* check_walk_on() killed it */
-		return;
-      }
-
-  }
-#endif
+  
   if(op->type==PLAYER)
     op->contr->do_los=1;
   for(tmp=get_map_ob(op->map,op->x,op->y);tmp!=NULL;tmp=tmp->above)
     switch(tmp->type) {
     case PLAYER:
-      (*draw_look_func)(tmp);
-      break;
+	tmp->contr->socket.update_look=1;
+	break;
     }
+    update_object(op);
 }
 
 /*
@@ -1315,7 +1312,8 @@ void insert_ob_in_map(object *op,mapstruct *m) {
   op->map=m;
   CLEAR_FLAG(op,FLAG_APPLIED); /* hack for fixing F_APPLIED in items of dead people */
   CLEAR_FLAG(op, FLAG_INV_LOCKED);
-  CLEAR_FLAG(op, FLAG_NO_STEAL);
+  if (!QUERY_FLAG(op, FLAG_ALIVE))
+    CLEAR_FLAG(op, FLAG_NO_STEAL);
   /* If there are other objects, then */
   if((top=get_map_ob(op->map,op->x,op->y))!=NULL) {
     /*
@@ -1388,7 +1386,6 @@ void insert_ob_in_map(object *op,mapstruct *m) {
   }
   else
     set_map_ob(op->map,op->x,op->y,op);   /* Tell the map that we're here */
-  update_object(op);
 
   /* Only check this if we are the head of the object */
   if (!op->head) {
@@ -1417,8 +1414,8 @@ void insert_ob_in_map(object *op,mapstruct *m) {
   for(tmp=get_map_ob(op->map,op->x,op->y);tmp!=NULL;tmp=tmp->above)
     switch(tmp->type) {
     case PLAYER:
-      (*draw_look_func)(tmp);
-      break;
+	tmp->contr->socket.update_look=1;
+	break;
     }
   /* build up linked list of light sources in each map. We do
    * this even for non-dark maps, as down the line we might make
@@ -1432,6 +1429,11 @@ void insert_ob_in_map(object *op,mapstruct *m) {
 	} else if(m->darkness&&(op->glow_radius>0||op->lights)) /* a light moved, check los */
 		update_all_los(m);
 #endif 
+    /* Don't know if moving this to the end will break anything.  However,
+     * we want to have update_look set above before calling this.
+     */
+    update_object(op);
+
 
 }
 
@@ -1501,10 +1503,18 @@ void decrease_ob_nr(object *op,int i) {
      * environment before we call remove_ob, since that deletes the
      * environment.
      */
-    tmp=is_player_inv (op->env);
-    if(tmp!=NULL) {
+    if(op->env!=NULL) {
+      tmp=is_player_inv (op->env);
+      if(tmp!=NULL) {
 	(*esrv_del_item_func)(tmp->contr, op->count);
 	(*esrv_update_item_func)(UPD_WEIGHT, tmp, tmp);
+      }
+    } else {
+      for(tmp=op->above;tmp!=NULL;tmp=tmp->above)
+        if(tmp->type==PLAYER) {
+	    (*esrv_del_item_func)(tmp->contr, op->count);
+	    (*esrv_update_item_func)(UPD_WEIGHT, tmp, tmp);
+	}
     }
     remove_ob(op);
     free_object(op);
@@ -1774,6 +1784,9 @@ void set_cheat(object *op) {
  * the given archetype.  start and stop specifies how many squares
  * to search (see the freearr_x/y[] definition).
  * It returns a random choice among the alternatives found.
+ * start and stop are where to start relative to the free_arr array (1,9
+ * does all 4 immediate directions).  This returns the index into the
+ * array of the free spot, -1 if no spot available (dir 0 = x,y)
  */
 
 int find_free_spot(archetype *at, mapstruct *m,int x,int y,int start,int stop) {
@@ -1785,7 +1798,7 @@ int find_free_spot(archetype *at, mapstruct *m,int x,int y,int start,int stop) {
     else if(wall(m,x+freearr_x[i],y+freearr_y[i])&&maxfree[i]<stop)
       stop=maxfree[i];
   }
-  if(!index) return 0;
+  if(!index) return -1;
   return altern[RANDOM()%index];
 }
 
