@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_player_c =
- *   "$Id: player.c,v 1.36 1998/09/28 02:21:22 master Exp master $";
+ *   "$Id: player.c,v 1.39 1999/01/30 10:57:14 master Exp $";
  */
 
 /*
@@ -105,8 +105,10 @@ void free_player(player *pl) {
 	prev->next=pl->next;
     } else first_player=pl->next;
 
-    if(pl->ob != NULL)
+    if(pl->ob != NULL) {
+	if (!QUERY_FLAG(pl->ob, FLAG_REMOVED)) remove_ob(pl->ob);
 	free_object(pl->ob);
+    }
 
     CFREE(pl);
 }
