@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_porting_c =
- *   "$Id: porting.c,v 1.16 1998/09/28 02:21:43 master Exp master $";
+ *   "$Id: porting.c,v 1.17 1999/03/23 07:04:19 master Exp $";
  */
 
 /*
@@ -132,6 +132,68 @@ void remove_directory(const char *path)
     }
 }
 
+#if defined(sgi)
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+#define popen fixed_popen
+
+FILE *popen_local(const char *command, const char *type)
+{
+	int		fd[2];
+	int		pd;
+	FILE	*ret;
+	if (!strcmp(type,"r"))
+	{
+		pd=STDOUT_FILENO;
+	}
+	else if (!strcmp(type,"w"))
+	{
+		pd=STDIN_FILENO;
+	}
+	else
+	{
+		return NULL;
+	}
+	if (pipe(fd)!=-1)
+	{
+		switch (fork())
+		{
+		case -1:
+			close(fd[0]);
+			close(fd[1]);
+			break;
+		case 0:
+			close(fd[0]);
+			if ((fd[1]==pd)||(dup2(fd[1],pd)==pd))
+			{
+				if (fd[1]!=pd)
+				{
+					close(fd[1]);
+				}
+				execl("/bin/sh","sh","-c",command,NULL);
+				close(pd);
+			}
+			exit(1);
+			break;
+		default:
+			close(fd[1]);
+			if (ret=fdopen(fd[0],type))
+			{
+				return ret;
+			}
+			close(fd[0]);
+			break;
+		}
+	}
+	return NULL;
+}
+
+#endif /* defined(sgi) */
+
+
 /*****************************************************************************
  * String related function
  ****************************************************************************/
