@@ -601,7 +601,7 @@ init_msgfile (void)
 	return;
     did_init_msgfile = 1;
 
-    sprintf (fname, "%s/messages", settings.libdir);
+    sprintf (fname, "%s/messages", settings.datadir);
     LOG (llevDebug, "Reading messages from %s...", fname);
 
     if ((fp = open_and_uncompress (fname, 0, &comp)) != NULL)
@@ -673,7 +673,7 @@ init_book_archive (void)
     if (!booklist)
 	booklist = bl;
 
-    sprintf (fname, "%s/bookarch", settings.libdir);
+    sprintf (fname, "%s/bookarch", settings.localdir);
     LOG (llevDebug, " Reading bookarch from %s...\n", fname);
 
     if ((fp = open_and_uncompress (fname, 0, &comp)) != NULL)
@@ -1348,13 +1348,16 @@ artifact_msg (int level, int booksize)
      * in art_name_array. Also, we check to be sure an artifactlist
      * for that type exists!
      */
-    do
-      {
-	  index = RANDOM () % (sizeof (art_name_array) / sizeof (arttypename));
-	  type = art_name_array[index].type;
-	  al = find_artifactlist (type);
-      }
-    while (al == NULL);
+    i=0;
+    do {
+	index = RANDOM () % (sizeof (art_name_array) / sizeof (arttypename));
+	type = art_name_array[index].type;
+	al = find_artifactlist (type);
+	i++;
+    } while ((al == NULL) && (i<10));
+
+    if (i==10) /* Unable to find a message */
+	return("None");
 
     /* There is no reason to start on the artifact list at the begining. Lets
      * take our starting position randomly... */
@@ -2043,7 +2046,7 @@ write_book_archive (void)
     if (!need_to_write_bookarchive) return;
     need_to_write_bookarchive=0;
 
-    sprintf (fname, "%s/bookarch", settings.libdir);
+    sprintf (fname, "%s/bookarch", settings.localdir);
     LOG (llevDebug, "Updating book archive: %s...\n", fname);
 
     if ((fp = fopen (fname, "w")) == NULL)
