@@ -106,7 +106,7 @@ void init_formulae() {
   if (has_been_done) return;
   else has_been_done = 1;
  
-  sprintf(filename, "%s/formulae", settings.libdir);
+  sprintf(filename, "%s/formulae", settings.datadir);
   LOG(llevDebug, "Reading alchemical formulae from %s...",filename);
   if ((fp = open_and_uncompress(filename, 0, &comp)) == NULL) {
     LOG(llevError, "Can't open %s.\n", filename);
