@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_time_c =
- *    "$Id: time.c,v 1.14 1998/08/01 09:22:42 master Exp $";
+ *    "$Id: time.c,v 1.15 1998/12/28 06:45:01 master Exp $";
  */
 
 /*
@@ -57,8 +57,7 @@ long process_utime_long_count;
  * but NetBSD does use 2 params.
  */
 
-#if defined(__sun__) || defined(linux) || defined(__NetBSD__) \
-   || defined(__FreeBSD__)
+#ifdef GETTIMEOFDAY_TWO_ARGS
 #define GETTIMEOFDAY(last_time) gettimeofday(last_time, (struct timezone *) NULL);
 #else
 #define GETTIMEOFDAY(last_time) gettimeofday(last_time);
