@@ -1,7 +1,7 @@
 
 /*
  * static char *rcs_treasure_c =
- *   "$Id: treasure.c,v 1.52 1998/08/01 09:23:02 master Exp $";
+ *   "$Id: treasure.c,v 1.54 1999/03/18 10:42:12 master Exp $";
  */
 
 /*
@@ -174,7 +174,7 @@ void load_treasures() {
   treasure *t;
   int comp;
 
-  sprintf(filename,"%s/%s",settings.libdir,settings.treasures);
+  sprintf(filename,"%s/%s",settings.datadir,settings.treasures);
   if((fp=open_and_uncompress(filename,0,&comp))==NULL) {
     LOG(llevError,"Can't open treasure file.\n");
     return;
@@ -1060,7 +1060,7 @@ void init_artifacts() {
   if (has_been_inited) return;
   else has_been_inited = 1;
 
-  sprintf(filename, "%s/artifacts", settings.libdir);
+  sprintf(filename, "%s/artifacts", settings.datadir);
   LOG(llevDebug, "Reading artifacts from %s...",filename);
   if ((fp = open_and_uncompress(filename, 0, &comp)) == NULL) {
     LOG(llevError, "Can't open %s.\n", filename);
