@@ -98,7 +98,7 @@ static void Picks(XtPointer client,String entryPath)
   char mapdir[PATH_MAX+1];
   int i=0;
 
-  sprintf(mapdir,"%s/%s",settings.libdir,settings.mapdir);
+  sprintf(mapdir,"%s/%s",settings.datadir,settings.mapdir);
   for(path = entryPath; mapdir[i++] == *path++;);
 
   debug1("Picks() %s\n",path);
@@ -112,7 +112,7 @@ static void Walls(XtPointer client,String entryPath)
   char mapdir[PATH_MAX+1];
   int i = 0;
 
-  sprintf(mapdir,"%s/%s",settings.libdir,settings.mapdir);
+  sprintf(mapdir,"%s/%s",settings.datadir,settings.mapdir);
   for(path = entryPath; mapdir[i++] == *path++;);
 
   debug1("Walls() %s\n",path);
@@ -673,7 +673,7 @@ static void Layout(App self)
 	("infoButton",menuButtonWidgetClass, box,
 	 XtNmenuName,"info",
 	 NULL);
-    sprintf(path,"%s/%s",settings.libdir,"doc");
+    sprintf(path,"%s/%s",settings.datadir,"doc");
     self->infof = CnvFilesCreate("info",use,Info,(XtPointer)self,path);
     
     /*** look ***/
@@ -710,12 +710,12 @@ static void Layout(App self)
 	("pickButton",menuButtonWidgetClass, box,
 	 XtNmenuName,"picks",
 	 NULL);
-    sprintf(path,"%s/%s/%s",settings.libdir,settings.mapdir,"editor/picks");
+    sprintf(path,"%s/%s/%s",settings.datadir,settings.mapdir,"editor/picks");
     self->picks = CnvFilesCreate("picks",use,Picks,(XtPointer)self,path);
     use = XtVaCreateManagedWidget 
       ("wallButton",menuButtonWidgetClass, box,
        NULL);
-    sprintf(path,"%s/%s/%s",settings.libdir,settings.mapdir,"editor/walls");
+    sprintf(path,"%s/%s/%s",settings.datadir,settings.mapdir,"editor/walls");
     self->walls = CnvFilesCreate("menu",use,Walls,(XtPointer)self,path);
 
     use = XtVaCreateManagedWidget 
@@ -833,28 +833,20 @@ App AppCreate(XtAppContext appCon,
 
     CnvInitialize(self->shell);
 
-    if(displaymode==Dm_Pixmap) {
-	if (ReadPixmaps(self->display, &pixmaps, &masks, &colormap)) {
+    if (displaymode == Dm_Bitmap)  {
+	pixmaps = ReadBitmaps(self->display);
+    }
+    if (displaymode == Dm_Pixmap) {
+        if (ReadPixmaps(self->display, &pixmaps, &masks, &colormap)) {
 	    /* We really should do something better than this */
 	    fprintf(stderr,"Not enough space in colormap - switch colormap.\n");
 /*	    exit(1);*/
 	}
-    } else {
-	if (displaymode==Dm_Bitmap)
-	    pixmaps = ReadBitmaps(self->display);
-	else if (!check_font_path(XtDisplay (self->shell))) {
-	    fprintf(stderr, "Trying to fix fontpath...\n");
-	    fflush(stderr);
-	    set_font_path (XtDisplay (self->shell), FONTDIR);
-	    if (!check_font_path(XtDisplay (self->shell))) {
-		LOG(llevError,"Failed to set fontpath.\n");
-	    }
-	}
     }
     XtVaSetValues(self->shell, XtNcolormap, colormap, NULL);
 
     /*** creating ***/
-    sprintf(path,"%s/%s",settings.libdir,settings.mapdir);
+    sprintf(path,"%s/%s",settings.datadir,settings.mapdir);
     self->path = CnvPathCreate("fileSelect",path, "");
     self->clip = EditCreate(self,ClipBoard,"/Clipboard"); /* separate from */
     Layout(self);
