@@ -1,12 +1,13 @@
 #include <Defines.h>
 #include <global.h>
 #include <debug.h>
-#include <xio.h>
 #include <X11.h>
 #include <CrUtil.h>
 
+
 extern    Pixmap *pixmaps;       /* list of pixmaps */
 extern    Pixmap *masks;       /* list of pixmaps */
+extern XChar2b fontindex_to_XChar2b ( Fontindex s );
 
 /*
  *Function: FaceDraw
@@ -20,7 +21,7 @@ extern    Pixmap *masks;       /* list of pixmaps */
 void FaceDraw (Widget w, GC gc, New_Face *face, int x, int y) {
     XChar xbuf;
 
-    if(settings.displaymode==Dm_Pixmap) {
+    if(displaymode==Dm_Pixmap) {
 	XSetClipMask(XtDisplay (w), gc, masks[face->number]);
 	XSetClipOrigin(XtDisplay (w), gc, x, y);
 	XCopyArea(XtDisplay (w), pixmaps[face->number],
@@ -36,11 +37,11 @@ void FaceDraw (Widget w, GC gc, New_Face *face, int x, int y) {
 	    XSetBackground (XtDisplay (w), gc, WhitePixel(XtDisplay(w),
 		XScreenNumberOfScreen(XtScreen(w))));
 	}
-	if (settings.displaymode==Dm_Bitmap) {
+	if (displaymode==Dm_Bitmap) {
 	    XCopyPlane(XtDisplay (w), pixmaps[face->number], 
 		       XtWindow(w), gc, 0, 0, FONTSIZE, FONTSIZE, x, y, 1);
 	} else {
-	    xbuf = FontindexToXChar (face->number);
+	    xbuf = FontindexToXChar(face->number);
 	    XDRAWIMAGESTRING (XtDisplay (w),XtWindow(w), gc, 
 			      x, y + 24, &xbuf, 1);
 
@@ -60,7 +61,7 @@ void FaceDraw (Widget w, GC gc, New_Face *face, int x, int y) {
 GC GCCreate (Widget w) {
     XGCValues values;
     GC gc;
-    if (settings.displaymode!=Dm_Font)
+    if (displaymode!=Dm_Font)
 	gc= XtAllocateGC (w, 0, 0L, NULL, GCBackground | GCForeground, 0);
     else {
 	values.font = XLoadFont (XtDisplay(w),FONTNAME);
