@@ -1655,9 +1655,11 @@ Boolean EditObjectDelete (Edit self, int x, int y, int z)
 	else
 	    return False;
     }
-    if (z > 0)
-        obj = obj->above;
-
+    /* This is just plain wrong 
+    **                    -- deletes object above the selected object!
+    ** if (z > 0)
+    **    obj = obj->above;
+    */
     if (self->app->attr && self->app->attr->op == obj)
 	AttrChange(self->app->attr, NULL, 0, 0);
     if (AppItemGetEdit(self->app) == self)
@@ -1668,7 +1670,8 @@ Boolean EditObjectDelete (Edit self, int x, int y, int z)
     remove_ob (obj);
     free_object (obj);
     /* remove_ob should do this for us */
-    /*update_position (self->emap, x, y);*/
+    /* But it doesnt - ds */
+    update_position (self->emap, x, y);
     return True;
 }
 
