@@ -59,9 +59,11 @@ extern void EditDestroy ( Edit self );
 extern void EditUpdate ( Edit self );
 extern EditReturn EditSave ( Edit self );
 extern void EditPerformFill ( Edit self, int x, int y );
+extern void EditPerformFillBelow ( Edit self, int x, int y );
 extern void EditFillRectangle ( Edit self, XRectangle rec );
 extern void EditWipeRectangle ( Edit self, XRectangle rec );
 extern void EditShaveRectangle ( Edit self, XRectangle rec );
+extern void EditShaveRectangleBelow ( Edit self, XRectangle rec );
 extern void EditCopyRectangle ( Edit self, Edit src, XRectangle rect, int sx, int sy );
 extern void EditDeletePoint ( Edit self, int x, int y );
 extern void EditModified ( Edit self );
