@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_commands_h =
- *   "$Id: commands.h,v 1.12 1998/09/28 02:43:00 master Exp master $";
+ *   "$Id: commands.h,v 1.13 1999/03/25 07:11:33 master Exp $";
  */
 
 /*
@@ -43,6 +43,9 @@
  * be initialized in one of the source files.
  */
 
+#ifndef COMMANDS_H
+#define COMMANDS_H
+
 typedef int (*CommFunc)(object *op, char *params);
 
 typedef struct {		/* global list's structure */
@@ -59,3 +62,4 @@ extern const int CommandsSize,NewServerCommandSize,
 	SocketCommandsSize, WizCommandsSize;
 
 
+#endif
