@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_config_h =
- *   "$Id: config.h,v 1.58 1998/09/28 02:43:23 master Exp master $";
+ *   "$Id: config.h,v 1.4 1999/07/13 04:52:27 cvs Exp $";
  */
 
 /*
@@ -102,9 +102,12 @@
  * SEARCH_ITEMS - let players search for items on the ground
  * SECURE - Allow overriding values with run time flags?
  * SET_TITLE - lets players set their title
+ * SIMPLE_EXP - uses simpler experience system
  * SPELL_* - various spell related options
+ * STAT_LOSS_ON_DEATH - toggle between stat loss or stat depletion
  * USE_LIGHTING - enable light/darkness & light sources
  * USE_SWAP_STATS - allows stat swapping for new characters
+ * WATCHDOG - allows use of an external watchdog program
  *
  ***********************************************************************/
 
@@ -371,6 +374,24 @@
 
 #define SET_TITLE
 
+/*
+ * Set to true if you want to use the new (0.95.3) experience system.
+ * The system has the following changes:
+ *
+ * 1) 2000 exp need for second level.  All additional levels are shifted
+ *  accordingly.
+ * 2) Your stats in your skill categories don't affect the amount of
+ *  exp you get.
+ * 3) Your level difference doesn't affect the exp you get for killing
+ *  monsters.
+ *
+ * If this is set to FALSE out, you get the old system.
+ *
+ * This can also be set by using -simple-exp/+simple-exp as a run
+ * time option.
+ */
+
+#define SIMPLE_EXP TRUE
 
 /*  SPELLPOINT_LEVEL_DEPEND  --  Causes the spellpoint cost
  *  of spells to vary with their power.  Spells that become very
@@ -408,6 +429,16 @@
 /* #define SPELL_FAILURE_EFFECTS */
 
 
+/* Set this to FALSE if you don't want characters to loose a random stat when
+ * they die - instead, they just get deplete.
+ * Setting it to TRUE keeps the old behaviour.  This can be
+ * changed at run time via -stat_loss_on_death or +stat_loss_on_death.
+ * In theory, this can be changed on a running server, but so glue code
+ * in the wiz stuff would need to be added for that to happen.
+ */
+
+#define STAT_LOSS_ON_DEATH FALSE
+
 /*
  * The following enables the new light/darkness code.  Basically, darkness
  * affects line of sight, depending how dark the actual map is.  There are
@@ -434,14 +465,22 @@
 #define	USE_SWAP_STATS
 #define SORT_ROLLED_STATS
 
+/*
+ * WATCHDOG lets sends datagrams to port 13325 on localhost
+ * in (more-or-less) regular intervals, so an external watchdog
+ * program can kill the server if it hangs (for whatever reason).
+ * It shouldn't hurt anyone if this is defined but you don't
+ * have an watchdog program.
+ */
 
+#define WATCHDOG
 
 /***********************************************************************
  * SECTION 2 - Machine/Compiler specific stuff.
  *
  * Short list of items:
  * COMPRESS* - selection of compression programs
- * O_NDELAY - If you don't of O_NDELAY, uncomment it.
+ * O_NDELAY - If you don't have O_NDELAY, uncomment it.
  *
  ***********************************************************************/
 
@@ -512,7 +551,8 @@
  * Section 3
  *
  * General file and other defaults that don't need to be changed, and
- * do not change gameplay as percieved by players much.
+ * do not change gameplay as percieved by players much.  Some options
+ * may affect memory consumption however.
  *
  * Values:
  *
@@ -529,6 +569,8 @@
  * MOTD - message of the day - printed each time someone joins the game
  * PERM_FILE - limit play times
  * SHUTDOWN - used when shutting down the server
+ * SOCKETBUFSIZE - size of buffer used internally by the server for storing
+ *    backlogged messages.
  * TMPDIR - directory to use for temp files
  * UNIQUE_DIR - directory to put unique item files into
  * USE_CALLOC for some memory requests
@@ -565,7 +607,9 @@
 
 /*
  * Where to send error-reports.  If you're hacking at the source, define
- * this as your mail-address.
+ * this as your mail-address.  You do not need to define this - you can
+ * leave it undefined if you don't want the information available from this
+ * and instead use some other mean (motd for example)
  */
 
 #ifndef DM_MAIL
@@ -741,6 +785,19 @@
 #endif
 
 
+/*
+ * SOCKETBUFSIZE is the size of the buffer used internally by the server for
+ * storing backlogged messages for the client.  This is not operating system
+ * buffers or the like.  This amount is used per connection (client).
+ * This buffer is in addition to OS buffers, so it may not need to be very
+ * large.  When the OS buffer and this buffer is exhausted, the server
+ * will drop the client connection for falling too far behind.  So if
+ * you have very slow client connections, a larger value may be 
+ * warranted.
+ */
+
+#define SOCKETBUFSIZE 128*1024
+
 /*
  * Your tmp-directory should be large enough to hold the uncompressed
  * map-files for all who are playing.
@@ -908,30 +965,5 @@
 /*#define BACKUP_SAVE_AT_HOME*/
 
 
-/***********************************************************************
- * Section 5 - items that will definately be gone with X11 support
- * is removed from the server
- ***********************************************************************/
-
-/*
- * The following is only interesting if you run crossfire seteuid-flagged.
- * XOpenDisplay may want to read the .Xauthority file of the person who
- * runs the program. This can only be allowed if the system allows free
- * changing of the uid back and forth between invocation time uid
- * and the setuid uid. Otherwise we can't change euid back to suid after
- * setting it to invoking uid to read the xauth file. So far, only
- * POSIX-compatible systems and System-V derivates allow a process to
- * reset to a previous uid.
- * If this flag is left undefined, crossfire will not set uid back to
- * that of the invoking process while opening the first display connection.
- * In this case, you'll have to do xhost +machine before running crossfire,
- * 'machine' being the machine you run the program on.
- *    //magnuz@cd.chalmers.se
- */
-/* #define HAVE_SAVE_UID */
-#if (defined(hpux) || defined(sysv)) && !defined(HAVE_SAVE_UID)
-#  define HAVE_SAVE_UID
-#endif
-
 
 
