@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_define_h =
- *   "$Id: define.h,v 1.60 1998/09/28 02:44:07 master Exp master $";
+ *   "$Id: define.h,v 1.61.1.3 1999/03/07 02:51:04 master Exp master $";
  */
 
 /*
@@ -227,23 +227,12 @@
 #define POWER_CRYSTAL 156
 #define CORPSE 157
 
+#define DISEASE 158
+#define SYMPTOM 159
 
-#define WINUPPER (-5)
-#define WINLOWER 5
-#define WINLEFT (-5)
-#define WINRIGHT 5
-#define BARLENGTH_INV 281
-#define BARLENGTH_LOOK 146
 #define MAX_NAME 16
 #define BIG_NAME 32
 #define SIZEOFFREE 49
-#define INFOLINES 36
-#define INFOCHARS 50 /* Note that this is only the default */
-#define FONTWIDTH 8  /* Note that this is only the default */
-#define FONTHEIGHT 13
-#define S_BULLET 0
-#define S_FIREBALL 1
-#define S_LIGHTNING 2
 
 /*
  * Number of compression methods depend on whether COMPRESS_SUFFIX is defined.
@@ -260,7 +249,7 @@
  * (Already done, Vick 930307 :)
  */
 
-#define NROFATTACKS 23
+#define NROFATTACKS 24
 
 #define AT_PHYSICAL	0x00000001 /*     1 */
 #define AT_MAGIC	0x00000002 /*     2 */
@@ -311,7 +300,7 @@
 
 #define NRSPELLPATHS	20
 
-#define NROFREALSPELLS	171	/* Number of different spells */
+#define NROFREALSPELLS	180	/* Number of different spells */
 
 #define NROFSKILLS  32  /* match to the number of elements in skills[] array */
 
@@ -412,6 +401,7 @@
 #define FLAG_IDENTIFIED		29 /* Not implemented yet */
 #define FLAG_REFLECTING		30 /* Object reflects from walls (lightning) */
 #define FLAG_CHANGING		31 /* Changes to other_arch when anim is done*/
+/* Start of values in flags[1] */
 #define FLAG_SPLITTING		32 /* Object splits into stats.food other objs */
 #define FLAG_HITBACK		33 /* Object will hit back when hit */
 #define FLAG_STARTEQUIP		34 /* Object was given to player at start */
@@ -447,6 +437,7 @@
 #define FLAG_NO_APPLY		62 /* Avoids step_on/fly_on to this object */
 #define FLAG_IS_FLOOR		63 /* Can't see what's underneath this object */
 #define FLAG_LIFESAVE		64 /* Saves a players' life once, then destr. */
+/* Start of values in flags[2] */
 #define FLAG_NO_STRENGTH	65 /* Strength-bonus not added to wc/dam */
 #define FLAG_SLEEP		66 /* NPC is sleeping */
 #define FLAG_STAND_STILL	67 /* NPC will not (ever) move */
@@ -478,11 +469,17 @@
 #define FLAG_SEE_IN_DARK	93 /* if set ob not effected by darkness */ 
 #define FLAG_IS_CAULDRON	94 /* container can make alchemical stuff */
 #define FLAG_DUST		95 /* item is a 'powder', effects throwing */
+/* Start of values in flags[3] */
 #define FLAG_NO_STEAL		96 /* Item can't be stolen */
 #define FLAG_ONE_HIT		97 /* Monster can only hit once before going
 				    * away (replaces ghosthit)
 				    */
-#define NUM_FLAGS		97 /* Should always be equal to the last
+#define FLAG_CLIENT_SENT	98 /* THIS IS A DEBUG FLAG ONLY.  We use it to
+				    * detect cases were the server is trying
+				    * to send an upditem when we have not
+				    * actually sent the item.
+				    */
+#define NUM_FLAGS		98 /* Should always be equal to the last
 				    * defined flag */
 
 /* Values can go up to 127 before the size of the flags array in the
@@ -711,7 +708,7 @@
 #      define RANDOM() rand()
 #      define SRANDOM(xyz) srand(xyz)
 #    else
-#      "Could not find a usuable random routine"
+#      error "Could not find a usable random routine"
 #    endif
 #  endif
 #endif
