@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_funcpoint_h =
- *   "$Id: funcpoint.h,v 1.14 1998/09/28 02:46:05 master Exp master $";
+ *   "$Id: funcpoint.h,v 1.15 1998/11/26 10:57:54 master Exp $";
  */
 
 /*
@@ -59,8 +59,6 @@ typedef void (*type_func_player_int)(player *, int);
 extern int	(*apply_func)			(object *, object *, int);
 extern void	(*draw_func)			(object *);
 extern void	(*draw_info_func)		(int, int, object *, const char *);
-extern void	(*draw_look_faces_func)		(object *);
-extern void	(*draw_look_func)		(object *);
 extern void	(*emergency_save_func)		(int);
 extern void	(*fix_auto_apply_func)		(mapstruct *);
 extern void	(*init_blocksview_players_func)	();
