@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_global_h =
- *   "$Id: global.h,v 1.40 1998/09/28 02:46:33 master Exp master $";
+ *   "$Id: global.h,v 1.40.1.8 1999/03/28 00:57:45 master Exp $";
  */
 
 /*
@@ -73,6 +73,8 @@ typedef unsigned short Fontindex;
 /* pull in treasure structure */
 #include "treasure.h"
 
+#include "commands.h"
+
 /*
  * So far only used when dealing with artifacts.
  * (now used by alchemy and other code too. Nov 95 b.t).
@@ -202,11 +204,14 @@ extern New_Face *inv_curse_face, *inv_damn_face, *inv_equip_face, *inv_lock_face
 
 
 extern long max_time;	/* loop time */
+extern NewSocket *init_sockets;
+
 
 EXTERN char *font_graphic;
 
 #ifndef __CEXTRACT__
 #include "libproto.h"
+#include "sockproto.h"
 #endif
 
 #ifdef __hpux__ /* Must do this after including proto.h */
@@ -232,7 +237,7 @@ EXTERN char *font_graphic;
 
 #ifdef USE_CALLOC
 # define CALLOC(x,y)	calloc(x,y)
-# define CFREE(x)	cfree(x)
+# define CFREE(x)	free(x)
 #else
 # define CALLOC(x,y)	malloc(x*y)
 # define CFREE(x)	free(x)
@@ -266,13 +271,16 @@ typedef struct Settings {
     uint8   daemonmode;     /* If true, detach and become daemon */
     int	    argc;	    /* parameters that were passed to the program */
     char    **argv;	    /* Only used by xio.c, so will go away at some time */
-    char    *libdir;	    /* Library location (ARchetypes, scores, etc. */
+    char    *datadir;	    /* read only data files */
+    char    *localdir;	    /* read/write data files */
     char    *playerdir;	    /* Where the player files are */
     char    *mapdir;	    /* Where the map files are */
     char    *archetypes;    /* name of the archetypes file - libdir is prepended */
     char    *treasures;	    /* location of the treasures file. */
     char    *uniquedir;	    /* directory for the unique items */
     char    *tmpdir;	    /* Directory to use for temporary files */
+    uint8   stat_loss_on_death;	/* If true, chars lose a random stat when they die */
+    uint8   simple_exp;	    /* If true, use the simple experience system */
 } Settings;
 
 extern Settings settings;
