@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_includes_h =
- *   "$Id: includes.h,v 1.23 1998/09/28 02:47:45 master Exp master $";
+ *   "$Id: includes.h,v 1.24 1999/03/29 01:07:38 master Exp $";
  */
 
 /*
@@ -94,4 +94,12 @@
 #include "logger.h"
 #include "newclient.h"
 
+#ifndef TRUE
+#define TRUE 1
+#endif
+
+#ifndef FALSE
+#define FALSE 0
+#endif
+
 #endif /* INCLUDES_H */
