@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_newserver_h =
- *   "$Id: newserver.h,v 1.4 1998/09/28 02:48:58 master Exp master $";
+ *   "$Id: newserver.h,v 1.7 1999/03/25 07:15:43 master Exp $";
  */
 
 /*
@@ -61,13 +61,25 @@ struct statsinfo {
  */
 enum FaceSendMode { Send_Face_Pixmap, Send_Face_Bitmap, Send_Face_None};
 
-enum Sock_Status {Ns_Avail, Ns_Add, Ns_Dead};
+enum Sock_Status {Ns_Avail, Ns_Add, Ns_Dead, Ns_Old};
+
+/* Reserver 0 for neither of these being set */
+enum Old_Mode {Old_Listen=1, Old_Player=2};
+
+/* The following is the setup for a ring buffer for storing outbut
+ * data that the OS can't handle right away.
+ */
+
+typedef struct Buffer {
+    char    data[SOCKETBUFSIZE];
+    int	    start;
+    int	    len;
+} Buffer;
 
 typedef struct NewSocket {
     enum Sock_Status status;
     int fd;
     enum FaceSendMode facemode;
-    uint32  facecache:1;    /* IF true, client is caching images */
     struct Map lastmap;
     uint8 faces_sent[MAXFACENUM];
     uint8 anims_sent[MAXANIMNUM];
@@ -75,9 +87,17 @@ typedef struct NewSocket {
     /* If we get an incomplete packet, this is used to hold the data. */
     SockList	inbuf;
     char    *host;	    /* Which host it is connected from (ip address)*/
+    Buffer  outputbuffer;   /* For undeliverable data */
+    uint32  facecache:1;    /* IF true, client is caching images */
     uint32  sent_scroll:1;
     uint32  sound:1;	    /* does the client want sound? */
     uint32  cs_version, sc_version; /* versions of the client */
+    uint32  update_look:1;  /* If true, we need to send the look window */
+    uint32  can_write:1;    /* Can we write to this socket? */
+
+    /* Below here is information only relevant for old sockets */
+    char    *comment;	    /* name or listen comment */
+    enum Old_Mode old_mode;
 } NewSocket;
 
 typedef struct FaceInfo {
