@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_spellist_h =
- *   "$Id: spellist.h,v 1.34 1998/09/28 02:52:21 master Exp master $";
+ *   "$Id: spellist.h,v 1.36 1999/03/25 11:02:08 master Exp $";
  */
 
 /*
@@ -222,24 +222,25 @@ spell spells[NROFREALSPELLS]={
  PATH_RESTORE, "enchantment",},
 /* mlee - Keep these spells 0 book chance, as they are low level quest items.*/
 /* raised the grace value on some immuntity spells -b.t. */
+  /* keep them path_null, that prevents them being given out by praying*/
 {"immunity to cold",            6, 60,  0, 10, 0, 0,  0,  1, 1, 1, 1,
- PATH_PROT, "protection",},
+ PATH_NULL, "protection",},
 {"immunity to electricity",     8, 65,  0, 10, 0, 0,  0,  1, 1, 1, 1,
- PATH_PROT, "protection",},
+ PATH_NULL, "protection",},
 {"immunity to fire",            10,70,  0, 10, 0, 0,  0,  1, 1, 1, 1,
- PATH_PROT, "protection",},
+ PATH_NULL, "protection",},
 {"immunity to poison",          12,60,  0, 10, 0, 0,  0,  1, 1, 1, 1,
- PATH_PROT, "protection",},
+ PATH_NULL, "protection",},
 {"immunity to slow",            14,60,  0, 10, 0, 0,  0,  1, 1, 1, 1,
- PATH_PROT, "protection",},
+ PATH_NULL, "protection",},
 {"immunity to paralysis",        16,60,  0, 10, 0, 0, 0,  1, 1, 1, 1,
- PATH_PROT, "protection",},						/*100*/
+ PATH_NULL, "protection",},						/*100*/
 {"immunity to draining",         18,75,  0, 10, 0, 0, 0,  1, 1, 1, 1,
- PATH_PROT, "protection",},
+ PATH_NULL, "protection",},
 {"immunity to magic",           20,150,  0, 30, 0, 0,  0,  1, 1, 1, 1,
- PATH_PROT, "protection",},
+ PATH_NULL, "protection",},
 {"immunity to attack",          26,170,  0, 50, 0, 0, 0,  1, 1, 1, 1,
- PATH_PROT, "protection",},
+ PATH_NULL, "protection",},
 /* set the path to PATH_NULL so god_intervention wont hand out this spell */
 {"invulnerability",             80,225,  0, 30, 0, 0, 0,  1, 1, 1, 1,
  PATH_NULL, "protection",},
@@ -382,7 +383,26 @@ PATH_TURNING,"holy_orb",},
 {"medium snowstorm",    		 3,10, 20, 10, 0, 0,  6,  1, 0, 0, 0,
  PATH_FROST, "snowball_m",},
 {"large snowstorm",     		 5,16, 10, 15, 0, 0,  2,  1, 0, 0, 0,
- PATH_FROST, "snowball_l",}					/* 170 */
+ PATH_FROST, "snowball_l",},					/* 170 */
+{"cure disease",               5,30,  0, 10, 3, 5,  1,  0, 0, 1, 1,
+ PATH_RESTORE,NULL},
+{"cause red death",           20,100, 0, 10, 0, 0,  0,  1, 0, 1, 0,
+ PATH_WOUNDING,"ebola"},
+{"cause flu",                  2, 10, 0, 10, 0, 0,  0,  1, 0, 1, 0,
+ PATH_WOUNDING,"flu"},
+{"cause black death",         15, 85, 0, 10, 0, 0,  0,  1, 0, 1, 0,
+ PATH_WOUNDING,"bubonic_plague"},
+{"cause leprosy",              5, 20, 0, 10, 0, 0,  0,  1, 0, 1, 0,
+ PATH_WOUNDING,"leprosy"},
+{"cause smallpox",            20,100, 0, 10, 0, 0,  0,  1, 0, 1, 0,
+ PATH_WOUNDING,"smallpox"},
+{"cause plague",              20,100, 0, 10, 0, 0,  0,  1, 0, 1, 0,
+ PATH_WOUNDING,"pneumonic_plague"},
+{"cause anthrax",             12, 75, 0, 10, 0, 0,  0,  1, 0, 1, 0,
+ PATH_WOUNDING,"anthrax"},
+{"cause typhoid",             15, 85, 0, 10, 0, 0,  0,  1, 0, 1, 0,
+ PATH_WOUNDING,"typhoid"}
+
 };
 
 /*  peterm:  the following defines the parameters for all the
@@ -573,7 +593,17 @@ spell_parameters SP_PARAMETERS[NROFREALSPELLS] =
 {    0,      0,     0,      4,		12},	/* cause many wounds  */
 {   8,      6,      3,      0,		24},	/*small snowstorm*/       
 {   8,      10,     3,      0,		24},	/*medium snowstorm*/      
-{   8,      14,     4,      0,		32}	/*large snowstorm*/       
+{   8,      14,     4,      0,		32},	/*large snowstorm*/       
+{   0,       0,     0,      0,		0},	/*cure disease*/      
+{   0,       0,     1,      1,		24},	/*cause red death*/      
+{   0,       0,     3,      5,		10},	/*cause flu*/      
+{   0,       0,     3,      10,		20},	/*cause black death*/      
+{   0,       0,     1,      1,		10},	/*cause leprosy*/      
+{   0,       0,     1,      4,		10},	/*cause smallpox*/      
+{   0,       0,     1,      5,		24},	/*cause plague*/      
+{   0,       0,     1,      10,		10},	/*cause anthrax*/      
+{   0,       0,     1,      10,		24}	/*cause typhoid*/      
+
 };
 
 char *spellpathnames[NRSPELLPATHS] = {
