@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_spells_h =
- *   "$Id: spells.h,v 1.28 1998/09/28 02:52:34 master Exp master $";
+ *   "$Id: spells.h,v 1.29 1999/01/30 11:28:34 master Exp $";
  */
 
 /*
@@ -178,7 +178,11 @@ enum spellnrs {
   SP_BULLET_SWARM,      SP_BULLET_STORM,        SP_CAUSE_MANY,  /* 165 */
   SP_S_SNOWSTORM, SP_M_SNOWSTORM,
 
-  SP_L_SNOWSTORM
+  SP_L_SNOWSTORM,       SP_CURE_DISEASE,       SP_CAUSE_EBOLA,   /* 170 */
+  SP_CAUSE_FLU,    SP_CAUSE_PLAGUE,
+
+  SP_CAUSE_LEPROSY,   SP_CAUSE_SMALLPOX,   SP_CAUSE_PNEUMONIC_PLAGUE, /* 175 */
+  SP_CAUSE_ANTHRAX, SP_CAUSE_TYPHOID
 
 };
 
