@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_xbmtobdf_c =
- *   "$Id: xbmtobdf.c,v 1.1 1996/07/24 07:25:58 master Exp $";
+ *   "$Id: xbmtobdf.c,v 1.3 1998/05/16 02:33:22 master Exp $";
  */
 
 /*
@@ -17,7 +17,7 @@
 #endif
 #include <sys/types.h>
 #if (!defined (__STRICT_ANSI__) || defined (__sun__) || defined(sgi) || defined(__osf__)) && !defined(vax)
-#if !defined(MACH) &&  !defined(NeXT)
+#if !defined(MACH) &&  !defined(NeXT) && !defined(__FreeBSD__)
 #include <malloc.h>
 #endif
 #include <stdlib.h>
@@ -89,7 +89,7 @@ static void usage() {
     exit(-1);
 }
 
-static char *basename(char *n) {
+static char *basename_local(char *n) {
     char *t;
     return (t = strrchr(n, '/')) ? ++t : n;
 }
@@ -218,7 +218,7 @@ static void convert_bitmap(char *file_name, int ch_enc) {
     /*fprintf(stderr, "%s: size %dx%d.\n", file_name, w, h);*/
 
     if (!use_bitmaps) {
-	ch_name = basename(file_name);
+	ch_name = basename_local(file_name);
 	
 	(void) printf("STARTCHAR %s\nENCODING %d\n",
 		      ch_name, ch_enc);
