@@ -67,8 +67,9 @@ char * cauldron_sound ( void ) {
 void attempt_do_alchemy(object *caster, object *cauldron) {
   recipelist *fl;
   recipe *rp=NULL;
-  int numb,i;
-  int formula=0,danger=calc_alch_danger(caster,cauldron);
+  float success_chance;
+  int numb,ability=1;
+  int formula=0;
  
      if(caster->type!=PLAYER) return; /* only players for now */ 
 
@@ -77,17 +78,23 @@ void attempt_do_alchemy(object *caster, object *cauldron) {
  
      numb=numb_ob_inside(cauldron);
      if((fl=get_formulalist(numb))) {
-        int j,ability=SK_level(caster)+cauldron->magic;
+
+        /* the caster only gets an increase in ability 
+         * if they know alchemy skill */
+        if(find_skill(caster,SK_ALCHEMY)!=NULL) {
+	  change_skill(caster,SK_ALCHEMY);
+          ability+=SK_level(caster)*((4.0 + cauldron->magic)/4.0);
+        }
 
 #ifdef ALCHEMY_DEBUG
-	LOG(llevDebug,"Got alchemy ability: %d\n",ability);
+	LOG(llevDebug,"Got alchemy ability lvl = %d\n",ability);
 #endif
 
         if(QUERY_FLAG(caster,FLAG_WIZ)) { 
 	    rp=fl->items;
-	    while(rp && rp->index!=formula) {
+	    while(rp && (formula % rp->index)!=0) {
 #ifdef EXTREME_ALCHEMY_DEBUG
-		LOG(llevDebug," grabbed list %d formula: %s of %s (%d)\n",numb,
+		LOG(llevDebug," found list %d formula: %s of %s (%d)\n",numb,
 		   rp->arch_name,rp->title,rp->index);
 #endif
 	    	rp=rp->next;
@@ -98,33 +105,51 @@ void attempt_do_alchemy(object *caster, object *cauldron) {
 		    LOG(llevDebug,"WIZ got formula: %s of %s\n",
 			rp->arch_name,rp->title);
 		else 
-		    LOG(llevDebug,"WIZ got formula: %s\n",rp->arch_name);
+		    LOG(llevDebug,"WIZ got formula: %s (nbatches:%d)\n",rp->arch_name,
+                      formula/rp->index);
 #endif
-		attempt_recipe(caster,cauldron,rp);
-	    } else LOG(llevDebug,"WIZ couldnt find formula for ingredients.\n"); 
+		attempt_recipe(caster,cauldron,ability,rp,formula/rp->index);
+	    }else LOG(llevDebug,"WIZ couldnt find formula for ingredients.\n"); 
 	    return;
-	} 
+	} /* End of WIZ alchemy */
 
-	/* player loop--trying to match random recipe */ 
-        for(i=ability;i>0;i--) { 
-    	    rp=fl->items;
+	/*  compute base chance of recipe success */
+	success_chance = 15.0 * ability / ( numb * numb * numb + 30 + 15.0*ability);
+#ifdef ALCHEMY_DEBUG
+	LOG(llevDebug,"base success chance =  %f\n",success_chance);
+#endif
+	   
+	/* find the recipe */
+	for(rp = fl->items;rp!=NULL && (formula % rp->index)!=0;rp=rp->next);
 
-	    if(fl->number>1) /* select a random recipe */
-                for(j=RANDOM()%fl->number;j>0;j--) rp=rp->next;
+	if(rp)  /* if we found a recipe */
+	{
+	  float ave_chance = fl->total_chance/(float)fl->number;
+	  if(ave_chance == 0) ave_chance = 1;
+	  /* adjust the success chance by the chance from the recipe list */
+	  if(ave_chance > rp->chance)
+	    success_chance *= (rp->chance + ave_chance)/ (2.0*ave_chance);
+	  else
+	    success_chance = 1.0- ( (1.0-success_chance)*(rp->chance +ave_chance)/(2.0*rp->chance));
 
-            if(rp->index==formula) { /* we matched a recipe */
-	        if(!(attempt_recipe(caster,cauldron,rp))) 
-		   	break;
-	        else return;
-            }
+#ifdef ALCHEMY_DEBUG
+	  LOG(llevDebug,"percent success chance =  %f\n",success_chance);
+#endif
+
+	  /* roll the dice */
+	  if(RANDOM()%100 <= 100 * success_chance) {
+	    if(attempt_recipe(caster,cauldron,ability,rp,formula/rp->index)) return;
+	  }
 	}
-     } 
-
-      /* if we get here, we failed!! */
-     alchemy_failure_effect(caster,cauldron,rp,danger);
+     }
+     /* if we get here, we failed!! */
+     alchemy_failure_effect(caster,cauldron,rp,calc_alch_danger(caster,cauldron));
 }
 
-/* content_recipe_value()- recipe value of the entire contents of a container. */
+/* content_recipe_value()- recipe value of the entire contents of a container.
+ * This appears to just generate a hash value, which I guess for now works
+ * ok, but the possibility of duplicate hashes is certainly possible - msw
+  */
 
 int content_recipe_value (object *op) {
   char name[MAX_BUF];
@@ -144,7 +169,7 @@ int content_recipe_value (object *op) {
         tmp=tmp->below;
     }   
 #ifdef ALCHEMY_DEBUG
-    LOG(llevDebug," FORMULA value=%d\n",formula);
+    LOG(llevDebug," Formula value=%d\n",formula);
 #endif
     return formula;
 }
@@ -170,30 +195,45 @@ int numb_ob_inside (object *op) {
 /* attempt_recipe() - essentially a wrapper for make_item_from_recipe() and 
  * insert_ob_in_ob. If the caster has some alchemy skill, then they might
  * gain some exp from (successfull) fabrication of the product. 
+ * If nbatches==-1, don't give exp for this creation (random generation/
+ * failed recipe)
  */ 
  
-object * attempt_recipe(object *caster, object *cauldron, recipe *rp) { 
-  object *item=NULL;   
+object * attempt_recipe(object *caster, object *cauldron,int ability, recipe *rp, int nbatches) { 
+  object *item=NULL;  
+  /* this should be passed to this fctn, not too effiecent cpu use this way */
+  int numb=numb_ob_inside(cauldron), batches=abs(nbatches);
+
+#ifdef EXTREME_ALCHEMY_DEBUG
+  LOG(llevDebug,"attempt_recipe(): got %d nbatches\n",nbatches);
+  LOG(llevDebug,"attempt_recipe(): using recipe %s\n", rp->title?rp->title:"unknown");
+#endif
+
+  if((item=make_item_from_recipe(cauldron,rp))!=NULL) { 
+    remove_contents(cauldron->inv,item);
+    adjust_product(item,ability,rp->yield?(rp->yield*batches):batches); /* adj lvl, nrof on caster level */ 
+    if(!item->env && (item=insert_ob_in_ob(item,cauldron))==NULL) { 
+      new_draw_info(NDI_UNIQUE, 0,caster,"Nothing happened.");
+      /* new_draw_info_format(NDI_UNIQUE, 0,caster, 
+            "Your spell causes the %s to explode!",cauldron->name); */
+      /* kaboom_cauldron(); */ 
+    } else {
+      /* we learn from our experience IF we know something of the alchemical arts */
+      if(nbatches>=0 && caster->chosen_skill&&caster->chosen_skill->stats.sp==SK_ALCHEMY) { 
+        /* more exp is given for higher ingred number recipes */ 
+        int amount = numb*numb*calc_skill_exp(caster,item);
+ 	add_exp(caster,amount);
+	item->stats.exp=0; /* so when skill id this item, less xp is awarded */
+#ifdef EXTREME_ALCHEMY_DEBUG 
+        LOG(llevDebug,"%s gains %d experience points.\n",caster->name,amount); 
+#endif
+      }
+      new_draw_info_format(NDI_UNIQUE, 0,caster, 
+               "The %s %s.",cauldron->name,cauldron_sound());
+    }   
+  }    
  
-    if((item=make_item_from_recipe(cauldron,rp))!=NULL) { 
-       remove_contents(cauldron->inv,item);
-       adjust_product(item,caster,rp->yield); /* adj lvl, nrof on caster level */ 
-       if(!item->env && (item=insert_ob_in_ob(item,cauldron))==NULL) { 
-                new_draw_info_format(NDI_UNIQUE, 0,caster, 
-                   "Your spell causes the %s to explode!",cauldron->name);
-                /* kaboom_cauldron(); */ 
-       } else {
-		if(find_skill(caster,SK_ALCHEMY)!=NULL) {
-		        change_skill(caster,SK_ALCHEMY);
- 			add_exp(caster,calc_skill_exp(caster,item));
-			item->stats.exp=0; /* so when skill id, less xp awarded */
-	        }
-                new_draw_info_format(NDI_UNIQUE, 0,caster, 
-                        "The %s %s.",cauldron->name,cauldron_sound());
-       }   
-    }    
- 
-    return item; 
+  return item; 
 } 
 
 
@@ -201,17 +241,11 @@ object * attempt_recipe(object *caster, object *cauldron, recipe *rp) {
 /* adjust_product() - we adjust the nrof, exp and level of the final product, based
  * on the item's default parameters, and the relevant caster skill level. */
 
-void adjust_product(object *item,object *caster,int yield) {
-   object *skill=NULL;
-   int lvl=1,nrof=1;
+void adjust_product(object *item,int lvl ,int yield) {
+   int nrof=1;
 
    if(!yield) yield = 1;
-
-   /* if the caster has alchemy (mental) exp use that level */
-   if((skill=find_skill(caster,SK_ALCHEMY)) && skill->exp_obj) 
-	lvl = skill->exp_obj->level;
-
-   
+   if(lvl<=0) lvl = 1; /* lets avoid div by zero! */ 
    if(item->nrof) {
 /*     nrof = (RANDOM() % yield + RANDOM() % yield + RANDOM() % yield)/ 3 + 1;*/
      nrof = ( 1.0 - 1.0/(lvl/10.0 + 1.0)) * (RANDOM() % yield + RANDOM() % yield + RANDOM() % yield) + 1;
@@ -335,6 +369,9 @@ void alchemy_failure_effect(object *op,object *cauldron,recipe *rp,int danger) {
       new_draw_info_format(NDI_UNIQUE,0,op, 
 	"The %s %s.",cauldron->name,cauldron_sound());
       return;
+    /* I don't know if this is intential, but this else effectively
+     * inclues the range of 0-9 and 25-39
+     */
   } else if (level< 40) {                	/* MAKE TAINTED ITEM */
       object *tmp=NULL;
 
@@ -342,7 +379,7 @@ void alchemy_failure_effect(object *op,object *cauldron,recipe *rp,int danger) {
 	   if((rp=get_random_recipe((recipelist *) NULL))==NULL) 
 	      	return;
 
-      if((tmp=attempt_recipe(op,cauldron,rp))) { 
+      if((tmp=attempt_recipe(op,cauldron,1,rp,-1))) { 
            if(!QUERY_FLAG(tmp,FLAG_CURSED)) /* curse it */
 	   	SET_FLAG(tmp,FLAG_CURSED);
 
@@ -373,7 +410,8 @@ void alchemy_failure_effect(object *op,object *cauldron,recipe *rp,int danger) {
 
       fl=get_formulalist(numb-1); /* take a lower recipe list */ 
       if(fl &&(rp=get_random_recipe(fl)))
-          (void) attempt_recipe(op,cauldron,rp);
+	  /* even though random, don't grant user any EXP for it */
+          (void) attempt_recipe(op,cauldron,1,rp,-1);
       else 
 	  alchemy_failure_effect(op,cauldron,rp,level-1);
       return;
@@ -397,7 +435,6 @@ void alchemy_failure_effect(object *op,object *cauldron,recipe *rp,int danger) {
            tmp=get_archetype("bomb");
   	   tmp->stats.dam=RANDOM()%level+1;
   	   tmp->stats.hp=RANDOM()%level+1;
-	   break;	
       	   new_draw_info_format(NDI_UNIQUE,0,op,"The %s creates a bomb!",
 		cauldron->name);
 	   break; 
@@ -505,9 +542,10 @@ void remove_contents (object *first_ob, object *save_item) {
  
     while(tmp) {
         next = tmp->below;
-        if(tmp==save_item)
+        if(tmp==save_item) {
           if(!(tmp=next)) break;
           else next=next->below;
+	}
  	if(tmp->inv) remove_contents(tmp->inv,NULL);
         remove_ob(tmp);
         free_object(tmp);
@@ -520,7 +558,9 @@ void remove_contents (object *first_ob, object *save_item) {
  * the number of ingredients, the length of the name of each ingredient,
  * the user's effective level, the user's Int and the enchantment on the
  * mixing device (aka "cauldron"). Higher values of 'danger' indicate more
- * danger. -b.t. 
+ * danger. Note that we assume that we have had the caster ready the alchemy
+ * skill *before* this routine is called. (no longer auto-readies that skill) 
+ * -b.t. 
  */
  
 int calc_alch_danger(object *caster,object *cauldron) {
@@ -528,10 +568,14 @@ int calc_alch_danger(object *caster,object *cauldron) {
    char name[MAX_BUF];
    int danger=0,nrofi=0; 
  
-    /* Higher level, better cauldrons reduce risk */
-   danger -= (SK_level(caster)+(cauldron->magic));
+    /* Knowing alchemy skill reduces yer risk */
+   if(caster->chosen_skill&&caster->chosen_skill->stats.sp==SK_ALCHEMY)
+     danger -= SK_level(caster);
 
-    /* Higher Int, lower the risk */
+   /* better cauldrons reduce risk */
+   danger -= cauldron->magic;
+
+   /* Higher Int, lower the risk */
    danger -= 3 * (caster->stats.Int - 15);
  
     /* Ingredients. Longer names usually mean rarer stuff.
@@ -554,3 +598,4 @@ int calc_alch_danger(object *caster,object *cauldron) {
    return danger;
 }
 
+
