@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_apply_c =
- *   "$Id: apply.c,v 1.63 1998/09/28 02:59:03 master Exp $";
+ *   "$Id: apply.c,v 1.73 1999/07/10 23:44:21 master Exp $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -22,7 +22,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    The author can be reached via e-mail to mwedel@pyramid.com
+    The author can be reached via e-mail to mark@pyramid.com
 */
 
 #include <global.h>
@@ -53,7 +53,7 @@ void draw_find(object *op, object *find) {
 
 int apply_id_altar(object *money, object *altar)
 {
-    object *id, *pl;
+    object *id, *pl, *marked;
     int success=0;
 
     /* Check for MONEY type is a special hack - it prevents 'nothing needs
@@ -68,6 +68,24 @@ int apply_id_altar(object *money, object *altar)
 	LOG(llevError,"Identify Altar: Can't find player!.\n");
 	return 0;
     }
+
+    marked=find_marked_object(pl);
+    /* if the player has a marked item, identify that if it needs to be
+     * identified.  IF it doesn't, then go through the player inventory.
+     */
+    if (marked && !QUERY_FLAG(marked, FLAG_IDENTIFIED) && need_identify(marked)) {
+	if (check_altar(altar)) {
+	    identify(marked);
+	    new_draw_info_format(NDI_UNIQUE, 0, pl,
+		"You have %s.", long_desc(marked));
+            if (marked->msg) {
+	        new_draw_info(NDI_UNIQUE, 0,pl, "The item has a story:");
+	        new_draw_info(NDI_UNIQUE, 0,pl, marked->msg);
+	    }
+	    return 1;
+	} 
+    }
+
     for (id=pl->inv; id; id=id->below) {
 	if (!QUERY_FLAG(id, FLAG_IDENTIFIED) && !id->invisible && 
 	    need_identify(id)) {
@@ -622,6 +640,7 @@ int improve_armour(object *op, object *improver, object *armour)
 /* archetypes don't contain any MONEY_CHANGER object,
  * so it this function really used/useful?
  * Converters seems to make almost same.  -Tero
+ * op is the player, towhat is what we turn into.
  */
 void money_change(object *op,char *towhat)
 {
@@ -658,9 +677,10 @@ void money_change(object *op,char *towhat)
 int convert_item(object *item, object *converter) {
   int nr=0;
   object *tmp;
+
   /* We make some assumptions - we assume if it takes money as it type,
    * it wants some amount.  We don't make change (ie, if something costs
-   * 3 gp and player drops a platinum, tough luck 
+   * 3 gp and player drops a platinum, tough luck)
    */
   if (!strcmp(CONV_FROM(converter),"money")) {
     int cost;
@@ -690,9 +710,10 @@ int convert_item(object *item, object *converter) {
     item->nrof*=nr;
   for(tmp=get_map_ob(converter->map,converter->x,converter->y);
       tmp!=NULL;
-      tmp=tmp->above)
+      tmp=tmp->above) {
     if(tmp->type==SHOP_FLOOR)
       break;
+  }
   if(tmp!=NULL)
     SET_FLAG(item,FLAG_UNPAID);
   item->x=converter->x;
@@ -819,7 +840,7 @@ int apply_container (object *op, object *sack)
 	}
     }
     new_draw_info (NDI_UNIQUE, 0, op, buf);
-    draw_look(op);
+    if (op->contr) op->contr->socket.update_look=1;
     return 1;
 }
 
@@ -827,11 +848,18 @@ int apply_container (object *op, object *sack)
  * Eneq(@csd.uu.se): Handle apply on containers. 
  * Moved to own function and added many features [Tero.Haatanen@lut.fi]
  * This version is for client/server mode.
+ * op is the player, sack is the container the player is opening or closing.
+ * return 1 if an object is apllied somehow or another, 0 if error/no apply
+ *
+ * Reminder - there are three states for any container - closed (non applied),
+ * applied (not open, but objects that match get tossed into it), and open
+ * (applied flag set, and op->container points to the open container)
  */
+
 int esrv_apply_container (object *op, object *sack)
 {
     char buf[MAX_BUF];
-    object *tmp;
+    object *tmp=op->container;
 
     if(op->type!=PLAYER)
 	return 0; /* This might change */
@@ -841,91 +869,94 @@ int esrv_apply_container (object *op, object *sack)
 	return 0;
     }
 
-    if (sack->env != op) {
-	/* It's on the ground, the problems begin */
-	if (op->container != sack) {
-	    /* it's closed OR some player has opened it */
-	    if (QUERY_FLAG(sack, FLAG_APPLIED)) {
-		for(tmp=get_map_ob(sack->map, sack->x, sack->y); 
-		    tmp && tmp->container != sack; tmp=tmp->above);
-		if (tmp) {
-		    /* some other player have opened it */
-		    new_draw_info_format(NDI_UNIQUE, 0, op,
-			"%s is already occupied.", query_name(sack));
-		    return 1;
-		}
-	    }
+    /* If we have a currently open container, then it needs to be closed in all cases
+     * if we are opening this one up.  We then fall through if appropriate for
+     * openening the new container.
+     */
+
+    if (op->container && QUERY_FLAG(sack, FLAG_APPLIED)) {
+	if (op->container->env != op) { /* if container is on the ground */
+	    CLEAR_FLAG (op->container, FLAG_WALK_OFF);
+	    CLEAR_FLAG (op->container, FLAG_FLY_OFF);
 	}
-	if ( QUERY_FLAG(sack, FLAG_APPLIED)) {
-	    if (op->container == NULL) {
-		SET_FLAG (sack, FLAG_WALK_OFF); /* trying force closing it */
-		SET_FLAG (sack, FLAG_FLY_OFF);
-	    } else {
-		CLEAR_FLAG (sack, FLAG_WALK_OFF);
-		CLEAR_FLAG (sack, FLAG_FLY_OFF);
-	    }
+	new_draw_info_format(NDI_UNIQUE, 0, op, "You close %s.",
+		      query_name(op->container));
+	CLEAR_FLAG(op->container, FLAG_APPLIED);
+	op->container=NULL;
+	esrv_update_item (UPD_FLAGS, op, tmp);
+	if (tmp == sack) return 1;
+    }
+		      
+
+    /* If the player is trying to open it (which he must be doing if we got here),
+     * and it is locked, check to see if player has the equipment to open it.
+     */
+
+    if (sack->slaying) { /* it's locked */
+	for (tmp=op->inv; tmp; tmp=tmp->below)
+	    if (tmp->type == SPECIAL_KEY && 
+		tmp->slaying == sack->slaying)
+		break;
+
+	if (tmp) {
+	    sprintf (buf, "You unlock %s with ", query_name(sack));
+	    strcat (buf, query_name(tmp));
+	    strcat (buf, ".");
+	    new_draw_info(NDI_UNIQUE, 0, op, buf);
+	} else {
+	    new_draw_info_format(NDI_UNIQUE, 0, op,  "You don't have the key to unlock %s.",
+			 query_name(sack));
+	    return 0;
 	}
     }
 
-    if (QUERY_FLAG (sack, FLAG_APPLIED)) {
-	if (op->container) {
-	    if (op->container != sack) {
-		tmp = op->container;
-		esrv_apply_container (op, tmp);
-		sprintf (buf, "You close %s and open ", query_name(tmp));
-		op->container = sack;
-		strcat (buf, query_name(sack));
-		strcat (buf, ".");
-		esrv_send_item (op, sack);
-		esrv_send_inventory (op, sack);
-	    } else {
-		CLEAR_FLAG (sack, FLAG_APPLIED);
-		op->container = NULL;
-		sprintf (buf, "You close %s.", query_name(sack));
-		esrv_send_item (op, sack);
-	    }
-	} else {
+    /* By the time we get here, we have made sure any other container has been closed and
+     * if this is a locked container, the player they key to open it.
+     */
+
+    /* There are really two cases - the sack is either on the ground, or the sack is
+     * part of the players inventory.  If on the ground, we assume that the player is
+     * opening it, since if it was being closed, that would have been taken care of above.
+     */
+
+
+    if (sack->env != op) {
+	/* Hypothetical case - the player is trying to open a sack that belong to someone
+	 * else.  This normally should not happen, but a misbehaving client/player could
+	 * try to do it, so lets handle it gracefully.
+	 */
+	if (sack->env) {
+	    new_draw_info_format(NDI_UNIQUE, 0, op, "You can't open %s",
+				 query_name(sack));
+	    return 0;
+	}
+	/* set these so when the player walks off, we can unapply the sack */
+	SET_FLAG (sack, FLAG_WALK_OFF); /* trying force closing it */
+	SET_FLAG (sack, FLAG_FLY_OFF);
+
+	CLEAR_FLAG (sack, FLAG_APPLIED);
+	new_draw_info_format(NDI_UNIQUE, 0, op, "You open %s.", query_name(sack));
+	SET_FLAG (sack, FLAG_APPLIED);
+	op->container = sack;
+	esrv_update_item (UPD_FLAGS, op, sack);
+	esrv_send_inventory (op, sack);
+
+    } else { /* sack is in players inventory */
+	if (QUERY_FLAG (sack, FLAG_APPLIED)) { /* readied sack becoming open */
 	    CLEAR_FLAG (sack, FLAG_APPLIED);
-	    sprintf (buf, "You open %s.", query_name(sack));
+	    new_draw_info_format(NDI_UNIQUE, 0, op, "You open %s.", query_name(sack));
 	    SET_FLAG (sack, FLAG_APPLIED);
 	    op->container = sack;
-	    esrv_send_item (op, sack);
+	    esrv_update_item (UPD_FLAGS, op, sack);
 	    esrv_send_inventory (op, sack);
 	}
-    } else { /* not applied */
-	if (sack->slaying) { /* it's locked */
-	    for (tmp=op->inv; tmp; tmp=tmp->below)
-		if (tmp->type == SPECIAL_KEY && 
-		    tmp->slaying == sack->slaying)
-		    break;
-	    if (tmp) {
-		sprintf (buf, "You unlock %s with ", query_name(sack));
-		strcat (buf, query_name(tmp));
-		strcat (buf, ".");
-		SET_FLAG (sack, FLAG_APPLIED);
-		if (sack->env == NULL) { /* if it's on ground,open it also */
-		    new_draw_info(NDI_UNIQUE, 0, op, buf);
-		    esrv_apply_container (op, sack);
-		    return 1;
-		} else {
-		    esrv_send_item (op, sack);
-		}
-	    } else {
-		sprintf (buf, "You don't have the key to unlock %s.",
-			 query_name(sack));
-	    }
-	} else {
-	    sprintf (buf, "You readied %s.", query_name(sack));
+	else {
+	    CLEAR_FLAG (sack, FLAG_APPLIED);
+	    new_draw_info_format(NDI_UNIQUE, 0, op, "You readied %s.", query_name(sack));
 	    SET_FLAG (sack, FLAG_APPLIED);
-	    if (sack->env == NULL) {  /* if it's on ground,open it also */
-		esrv_apply_container (op, sack);
-		return 1;
-	    } else {
-		esrv_send_item (op, sack);
-	    }
+	    esrv_update_item (UPD_FLAGS, op, sack);
 	}
     }
-    new_draw_info(NDI_UNIQUE, 0, op, buf);
     return 1;
 }
 
@@ -1189,15 +1220,17 @@ int apply(object *op, object *tmp, int aflag) {
     break;
   case HOLE:
     if(tmp->stats.wc>0) /* Is the hole open? */
-      return 1; /* Nope */
+      return 0; /* Nope.  Change return to 0*/
     /* Is this a multipart monster and not the head?  If so, return.
      * Processing will happen if the head runs into the pit
      */
-    if (op->head) return 1;
+    if (op->head) return 0;
     {
 	int i=find_free_spot(op->arch,op->map,EXIT_X(tmp),EXIT_Y(tmp),0,SIZEOFFREE);
 	object *part;
 
+	/* If no free spot, return */
+	if (i==-1) return 0;
 	remove_ob(op);
 	for (part=op; part!=NULL; part=part->more) {
 	    part->x=EXIT_X(tmp)+freearr_x[i] + (part->arch?part->arch->clone.x:0);
@@ -1233,7 +1266,7 @@ int apply(object *op, object *tmp, int aflag) {
       if(op->type!=PLAYER) {
         if(QUERY_FLAG(op, FLAG_UNPAID)) { /* Just move the item to an adjacent place */
           int i=find_free_spot(op->arch,op->map,op->x,op->y,1,9);
-          if(!i) return 1;
+          if(i==-1) return 1;
           transfer_ob(op,op->x+freearr_x[i],op->y+freearr_y[i]);
           CLEAR_FLAG(op, FLAG_NO_APPLY);
           return 1;
@@ -1250,7 +1283,7 @@ int apply(object *op, object *tmp, int aflag) {
       }
       else {
         int i=find_free_spot(op->arch,op->map,op->x,op->y,1,9);
-        if(!i)
+        if(i==-1)
           LOG(llevError,"Internal shop-mat problem.\n");
         else {
           remove_ob(op);
@@ -1304,8 +1337,9 @@ int apply(object *op, object *tmp, int aflag) {
 	  if(!QUERY_FLAG(tmp,FLAG_IDENTIFIED)) {
 	    /*exp_gain *= 2; because they just identified it too */
 	    SET_FLAG(tmp,FLAG_IDENTIFIED);
+	    /* If in a container, update how it looks */
 	    if(tmp->env) esrv_update_item(UPD_FLAGS|UPD_NAME, op,tmp);
-	    else draw_look(op);
+	    else op->contr->socket.update_look=1;
 	  }
           add_exp(op,exp_gain);
           SET_FLAG(tmp,FLAG_NO_SKILL_IDENT); /* so no more xp gained from this book */ 
@@ -1414,7 +1448,7 @@ int apply(object *op, object *tmp, int aflag) {
 	if (tmp->env)
 	    esrv_update_item(UPD_FLAGS|UPD_NAME,op,tmp);
 	else
-	    draw_look(op);
+	    op->contr->socket.update_look=1;
     }
 
     if(check_spell_known(op,tmp->stats.sp)) {
@@ -1486,20 +1520,14 @@ int apply(object *op, object *tmp, int aflag) {
             "You are unable to decipher the strange symbols.");
           break;
         } 
-	/* ok, they can read, but did they fumble the formula? */
-        if(!QUERY_FLAG(op,FLAG_WIZ)&&
-            RANDOM()%(SK_level(op)+get_weighted_skill_stat_sum(op,SK_LITERACY))<tmp->level) 
-	{ 
-            new_draw_info(NDI_UNIQUE,0,op,"You flub the wording of the scroll!"); 
-	    if(tmp->level<(4+RANDOM()%12)) /* goofed it */
-                new_draw_info(NDI_UNIQUE,0,op,"The magic of the scroll is ruined!");
-	    else /* something bad */
-		scroll_failure(op,-5*(RANDOM()%(tmp->level+1)-1),spells[scroll_spell].sp);
-          decrease_ob(tmp);
-	    return 0;
-	} 
-	else if((exp_gain = calc_skill_exp(op,tmp)))
-	    add_exp(op,exp_gain); /* all ok, give the player xp for reading */
+
+	/* We give exp for reading the scroll.  I reduced this (0.95.3) to
+	 * give half as much since there is no longer any risk.  Even this
+	 * could be excessive.
+	 */
+	if((exp_gain = calc_skill_exp(op,tmp)))
+	    add_exp(op,exp_gain/2);
+
 
         /* Now, call here so the right skill is readied -- literacy 
 	 * isnt necesarily connected to the exp obj to which the xp 
@@ -2216,9 +2244,21 @@ int auto_apply (object *op) {
 
   case TREASURE:
     while ((op->stats.hp--)>0)
-      create_treasure(op->randomitems, op, GT_ENVIRONMENT,
+      create_treasure(op->randomitems, op, op->map?GT_ENVIRONMENT:GT_INVENTORY,
 	op->stats.exp ? op->stats.exp : 
 	op->map == NULL ?  14: op->map->difficulty,0);
+
+    /* If we generated on object and put it in this object inventory,
+     * move it to the parent object as the current object is about
+     * to disappear.  An example of this item is the random_* stuff
+     * that is put inside other objects.
+     */
+    if (op->inv) {
+	tmp=op->inv;
+	remove_ob(tmp);
+	if (op->env) insert_ob_in_ob(tmp, op->env);
+	else free_object(tmp);
+    }
     remove_ob(op);
     free_object(op);
     break;
@@ -2242,6 +2282,20 @@ void fix_auto_apply(mapstruct *m) {
       for(tmp=get_map_ob(m,x,y);tmp!=NULL;tmp=above) {
         above=tmp->above;
 
+	if (tmp->inv) {
+	    object *invtmp, *invnext;
+	    for (invtmp=tmp->inv; invtmp != NULL; invtmp = invnext) {
+		invnext = invtmp->below;
+		if(QUERY_FLAG(invtmp,FLAG_AUTO_APPLY))
+		    auto_apply(invtmp);
+		else if(invtmp->type==TREASURE) {
+		    while ((invtmp->stats.hp--)>0)
+			create_treasure(invtmp->randomitems, invtmp, GT_INVENTORY,
+                            m->difficulty,0);
+		}
+	    }
+	}
+
 	if(QUERY_FLAG(tmp,FLAG_AUTO_APPLY))
           auto_apply(tmp);
         else if(tmp->type==TREASURE) {
@@ -2286,8 +2340,12 @@ void eat_special_food(object *who, object *food) {
 	SP_HEROISM }; 
 
   /* matrix for stats we can increase by eating */
-  int i, stat[] = { STR, DEX, CON, CHA };
-  int mod_stat[] = {SP_STRENGTH, SP_DEXTERITY, SP_CONSTITUTION, SP_CHARISMA };
+  int i; 
+  /* Declare these static so they only get initialzed once.  IT doesn't appear
+   * that we are modifying these, so this works out ok.
+   */
+  static int stat[] = { STR, DEX, CON, CHA }, 
+    mod_stat[] = {SP_STRENGTH, SP_DEXTERITY, SP_CONSTITUTION, SP_CHARISMA };
   
   /* check if food modifies stats of the eater */
   for(i=0; i<(sizeof(stat)/sizeof(int)); i++)
@@ -2333,7 +2391,8 @@ void eat_special_food(object *who, object *food) {
 
 void apply_lighter(object *who, object *lighter) {
     object *item = who->inv;
-    int nrof;
+    int count,nrof;
+    char item_name[MAX_BUF];
 
     item=find_marked_object(who);
     if(item) {  
@@ -2348,10 +2407,20 @@ void apply_lighter(object *who, object *lighter) {
 	     return;
         }
 	nrof=item->nrof;
+	count=item->count;
+	/* If the item is destroyed, we don't have a valid pointer to the
+	 * name object, so make a copy so the message we print out makes
+	 * some sense.
+	 */
+	strcpy(item_name, item->name);
+
 	save_throw_object(item,AT_FIRE);
-	if ((nrof != item->nrof ) || QUERY_FLAG(item, FLAG_FREED)) {
+	/* Change to check count and not freed, since the object pointer
+	 * may have gotten recycled
+	 */
+	if ((nrof != item->nrof ) || (count != item->count)) {
 	    new_draw_info_format(NDI_UNIQUE, 0,who,
-		 "You light the %s with the %s.",item->name,lighter->name);
+		 "You light the %s with the %s.",item_name,lighter->name);
 	} else {
 	    new_draw_info_format(NDI_UNIQUE, 0,who,
 		 "You attempt to light the %s with the %s and fail.",item->name,lighter->name);
