@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_attack_c =
- *   "$Id: attack.c,v 1.42 1998/09/28 03:00:55 master Exp $";
+ *   "$Id: attack.c,v 1.52 1999/07/10 23:41:06 master Exp $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -124,8 +124,16 @@ void save_throw_object(object *op, int type) {
 	if(op->nrof>1)
 	      decrease_ob_nr(op,RANDOM()%op->nrof);
 	else {
-	      remove_ob(op);
-	      free_object(op);
+	    if (op->env) {
+		object *tmp= is_player_inv(op->env);
+
+		if (tmp) {
+		    esrv_del_item(tmp->contr, op->count);
+		    esrv_update_item(UPD_WEIGHT, tmp, tmp);
+		}
+	    }
+	    remove_ob(op);
+	    free_object(op);
 	}
 	if(type&(AT_FIRE|AT_ELECTRICITY)) {
 	      op=get_archetype("burnout");
@@ -307,6 +315,15 @@ int attack_ob(object *op,object *hitter) {
     add_refcount(op_name = op->name);
     if(hitter->head!=NULL)
 	hitter=hitter->head;
+
+    if (hitter->name==NULL) {
+	if(settings.debug) {
+	    dump_object(hitter);
+	    LOG(llevDebug,"Object without name tried to attack.\n%s\n",errmsg);
+	}
+	return 1;
+    }
+	
     if(op->stats.luck) {
 	luck=RANDOM()%abs(op->stats.luck);
 	if(op->stats.luck<0)
@@ -476,7 +493,7 @@ void tear_down_wall(object *op)
     }
 }
 
-/* This returns the amount of damage hitter does to op with the appropriate`
+/* This returns the amount of damage hitter does to op with the appropriate
  * attacktype.  Only 1 attacktype should be set at a time.  This doesn't
  * damage the player, but returns how much it should take.  However, it will
  * do other effects (paralyzation, slow, etc.)
@@ -502,7 +519,7 @@ int hit_player_attacktype(object *op, object *hitter, int dam,
     if (attacktype & AT_INTERNAL) return dam;
 
     if (hitter->slaying) {
-	if (((op->race !=NULL && strstr(op->race, hitter->slaying)) ||
+	if (((op->race !=NULL && strstr(hitter->slaying,op->race)) ||
 #ifndef MULTIPLE_GODS
 	  (strstr(hitter->slaying, undead_name) && QUERY_FLAG(op,FLAG_UNDEAD)) ||
 #endif
@@ -525,6 +542,8 @@ int hit_player_attacktype(object *op, object *hitter, int dam,
 
     if (attacktype & AT_PHYSICAL) {
 	if (op->armour) dam=((100-op->armour)*dam/100);
+	/*  here also check for diseases */
+	check_physically_infect(op,hitter);
  /* Don't need to do anything for magic, fire, electricity, cold */    
     } else if (attacktype & 
       (AT_CONFUSION|AT_POISON|AT_SLOW|AT_PARALYZE|AT_FEAR|AT_CANCELLATION|
@@ -669,9 +688,13 @@ int hit_player(object *op,int dam, object *hitter, int type) {
 	 * and keep on processing if we have other attacktypes.
 	 * return if only magic or nothing is left - under normal code
 	 * we don't attack with pure magic if there is another attacktype.
+	 * Only do processing if the initial attacktype includes one of those
+	 * attack so we don't cancel out things like magic bullet.
 	 */
-	type &= ~(AT_PARALYZE | AT_SLOW);
-	if (!type || type==AT_MAGIC) return 0;
+	if (type & (AT_PARALYZE | AT_SLOW)) {
+	    type &= ~(AT_PARALYZE | AT_SLOW);
+	    if (!type || type==AT_MAGIC) return 0;
+	}
 #endif
 	op=op->head;
     }
@@ -683,6 +706,13 @@ int hit_player(object *op,int dam, object *hitter, int type) {
     if(QUERY_FLAG(op,FLAG_WIZ)||!QUERY_FLAG(op,FLAG_ALIVE)||op->stats.hp<0)
 	return 0;
 
+    /* If its already dead, or we're the wizard, don't attack it - no point */
+    if(hitter->name==NULL) {
+	if (settings.debug) 
+	    LOG(llevDebug, "hit_player: hitter has no name\n");
+	return 0;
+    }
+
 #ifdef ATTACK_DEBUG
     LOG(llevDebug,"hit player: attacktype %d, dam %d\n", type, dam);
 #endif
@@ -718,8 +748,10 @@ int hit_player(object *op,int dam, object *hitter, int type) {
 	    maxdam=(maxdam>ndam)?maxdam:ndam;
 	}
     }
-    LOG(llevDebug,"Attacktype %d did %d damage\n", type, maxdam);
 #if 0
+
+    LOG(llevDebug,"Attacktype %d did %d damage\n", type, maxdam);
+
     /* It doesn't appear that being scared will have anything to do with
      * hitback.  In fact, hitback (monster hitting player) before the
      * player hitting monster code is called.
@@ -790,21 +822,34 @@ int hit_player(object *op,int dam, object *hitter, int type) {
 	    owner=hitter;
 
 	/* Player killed something */
-	if(owner->type==PLAYER&&(owner->level/2<op->level||op->stats.exp>1000)) {
-	    if(owner!=hitter) {
-		(void) sprintf(buf,"You killed %s with %s.",query_name(op)
-		   ,query_name(hitter));
+	if(owner->type==PLAYER) {
+	    Log_Kill(owner->name,
+		     query_name(op),op->type,
+		     (owner!=hitter) ? query_name(hitter) : NULL,
+		     (owner!=hitter) ? hitter->type : 0);
+
+	    /* This appears to be doing primitive filtering to only
+	     * display the more interesting monsters.
+	     */
+	    if ( owner->level/2<op->level || op->stats.exp>1000) {
+		if(owner!=hitter) {
+		    (void) sprintf(buf,"You killed %s with %s.",query_name(op)
+				       ,query_name(hitter));
 #ifdef ALLOW_SKILLS
-		old_hitter = hitter;
-		owner->exp_obj=hitter->exp_obj; 
+		    old_hitter = hitter;
+		    owner->exp_obj=hitter->exp_obj; 
 #endif
-	    } else
-		(void) sprintf(buf,"You killed %s.",query_name(op));
-	    play_sound_map(owner->map, owner->x, owner->y, SOUND_PLAYER_KILLS);
-	    new_draw_info(NDI_BLACK, 0,owner,buf);
+		} else {
+			(void) sprintf(buf,"You killed %s.",query_name(op));
+		}
+		play_sound_map(owner->map, owner->x, owner->y, SOUND_PLAYER_KILLS);
+		new_draw_info(NDI_BLACK, 0,owner,buf);
+	    }/* message should be displayed */
+
 	    if(op->type == PLAYER && hitter != op)
 		 change_luck(hitter, -1);
-	}
+	} /* was a player that hit this creature */
+
 
 	/* Pet killed something. */
 	if(get_owner(hitter)!=NULL) {
@@ -823,7 +868,7 @@ int hit_player(object *op,int dam, object *hitter, int type) {
 	if(hitter!=op&&!QUERY_FLAG(op, FLAG_WAS_WIZ)) {
 	    int exp=op->stats.exp;
 
-	    if(hitter->level>op->level)
+	    if(!settings.simple_exp && hitter->level>op->level)
 		exp=(exp*(op->level+1))/MAX(hitter->level+1, 1);
 
 /* new exp system in here. Try to insure the right skill is modifying gained exp */ 
@@ -844,10 +889,15 @@ int hit_player(object *op,int dam, object *hitter, int type) {
 	    if (op->type==PLAYER)
 		exp/=10;
 
-	    exp=exp/2;
-	    if(hitter->type!=PLAYER || hitter->contr->party_number<=0)
+	    /* Don't know why this is set this way - doesn't make
+	     * sense to just divide everything by two for no reason.
+	     */
+	    if (!settings.simple_exp)
+		exp=exp/2;
+
+	    if(hitter->type!=PLAYER || hitter->contr->party_number<=0) {
 		add_exp(hitter,exp);
-	    else {
+	    } else {
 		int shares=0,count=0;
 		player *pl;
 		int no=hitter->contr->party_number;
@@ -942,7 +992,7 @@ int hit_player(object *op,int dam, object *hitter, int type) {
 		SET_FLAG(tmp, FLAG_UNAGGRESSIVE);
 	    j=find_first_free_spot(tmp->arch,op->map,op->x,op->y);
 	    if (j==-1) /* No spot to put this monster */
-		free(tmp);
+		free_object(tmp);
 	    else {
 		tmp->x=op->x+freearr_x[j],tmp->y=op->y+freearr_y[j];
 		insert_ob_in_map(tmp,op->map);
