@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_ban_c =
- *   "$Id: ban.c,v 1.1 1994/05/06 08:02:09 master Exp $";
+ *   "$Id: ban.c,v 1.2 1999/03/18 10:45:24 master Exp $";
  */
 
 /*
@@ -29,7 +29,7 @@ int checkbanned(char *login, char *host)
   int           num1;
   int   Hits=0;                 /* Hits==2 means we're banned */
 
-  sprintf (buf, "%s/%s", LIBDIR, BANFILE);
+  sprintf (buf, "%s/%s", settings.datadir, BANFILE);
   if ((bannedfile = fopen(buf, "r")) == NULL) {
     LOG (llevDebug, "Could not find file Banned file.\n");
     return(0);
