@@ -45,7 +45,10 @@ int execute_newserver_command(object *pl, char *command)
     pl->contr->has_hit=0;
 
     cp=strchr(command, ' ');
-    if (cp) *(cp++) ='\0';
+    if (cp) { 
+	*(cp++) ='\0';
+	while (*cp==' ') cp++;
+    }
 
     csp = find_command_element(command, NewServerCommands,
 		NewServerCommandSize);
