@@ -8,6 +8,34 @@
 #include <sproto.h>
 #include <living.h>
 
+/* this is a a debug function.  We dump the object with matching 'tag'.
+ * This is mostly used for client debugging, so it referances data with
+ * just the tag.  This is a costly call, since it searches through all
+ * objects.  It dumps the output to the server logfile.
+ */
+int dump_object_from_tag(object *pl, char *val)
+{
+    int tag=atoi(val);
+    object *op;
+
+    if (tag<=0) {
+	new_draw_info_format(NDI_UNIQUE, 0, pl,"Invalid tag given: %s\n", val);
+	return 0;
+    }
+
+    for (op=objects; op!=NULL; op=op->next)
+	if (op->count==tag) break;
+
+    if (!op) {
+	new_draw_info_format(NDI_UNIQUE, 0, pl,"Could not find matching object tag (%d)\n", tag);
+    }
+    else {
+	dump_object(op);
+	LOG(llevDebug,"Object dump for tag %d:\n%s\n", tag, errmsg);
+    }
+    return 0;
+}
+
 /*
  * Object id parsing functions
  */
@@ -308,6 +336,12 @@ void pick_up_object (object *pl, object *op, object *tmp, int nrof)
 	else
 		esrv_send_item (pl, tmp2);
     } else {
+	/* If the object is in a container, send a delete to the client.
+	 * - we are moving all the items from the container to elsewhere,
+	 * so it needs to be deleted.
+	 */
+	if (tmp->env) 
+	    esrv_del_item (pl->contr, tmp->count);
 	remove_ob(tmp); /* Unlink it */
     }
     if(QUERY_FLAG(tmp, FLAG_UNPAID))
@@ -433,7 +467,8 @@ int command_take (object *op, char *params)
 	if (!tmp) new_draw_info(NDI_UNIQUE, 0,op, "There is nothing to pick up.");
     }
 
-    draw_look(op);
+/* Shouldn't be needed - pick_up should update this */
+/*    draw_look(op);*/
     return 0;
 }
 
@@ -800,8 +835,8 @@ int command_dropall (object *op, char *params) {
       curinv = nextinv;
     }
   }
-
-  draw_look(op);
+  op->contr->socket.update_look=1;
+/*  draw_look(op);*/
   return 0;
 }
 
@@ -830,7 +865,8 @@ int command_drop (object *op, char *params)
 	if (!did_one) new_draw_info(NDI_UNIQUE, 0,op,"Nothing to drop.");
     }
     op->contr->count=0;
-    draw_look(op);
+    op->contr->socket.update_look=1;
+/*    draw_look(op);*/
     return 0;
 }
 
