@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_c_wiz_c =
- *   "$Id: c_wiz.c,v 1.18 1998/09/28 03:05:40 master Exp master $";
+ *   "$Id: c_wiz.c,v 1.20 1999/03/20 06:45:06 master Exp $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -210,6 +210,10 @@ int command_summon (object *op, char *params)
         return 1;
       }
       i=find_free_spot(op->arch,op->map,op->x,op->y,1,8);
+      if (i==-1) {
+	new_draw_info(NDI_UNIQUE, 0, op, "Can not find a free spot to place summoned player.");
+	return 1;
+      }
       dummy=get_object();
       EXIT_PATH(dummy)=add_string(op->map->path);
       EXIT_X(dummy)=op->x+freearr_x[i];
@@ -711,7 +715,7 @@ static int checkdm(object *op, char *pl_name, char *pl_passwd, char *pl_host)
   *pl_name=op->name?op->name:"*";
 #endif
 
-  sprintf (buf, "%s/%s", LIBDIR, DMFILE);
+  sprintf (buf, "%s/%s", settings.datadir, DMFILE);
   if ((dmfile = fopen(buf, "r")) == NULL) {
     LOG (llevDebug, "Could not find DM file.\n");
     return(0);
