@@ -1,3 +1,8 @@
+/*
+ * static char *rcsid_ban_c =
+ *   "$Id: commands.c,v 1.3 1999/07/13 05:15:01 cvs Exp $";
+ */
+
 /*
  * Command parser
  */
@@ -24,6 +29,7 @@ CommArray_s Commands[] = {
 
 #ifdef DEBUG
   {"sstable", command_sstable,	0.0},
+  {"dumptag", dump_object_from_tag, 0.0},
 #endif
 #ifdef DEBUG_MALLOC_LEVEL
   {"verify", command_malloc_verify,0.0},
@@ -31,7 +37,6 @@ CommArray_s Commands[] = {
   {"apply", command_apply,	1.0},	/* should be variable */
   {"archs", command_archs,	0.0},
   {"bell", command_bell,	0.0},
-  {"berzerk", command_berzerk,	0.0},
   {"brace", command_brace,	0.0},
   {"cast", command_cast,	0.2},	/* Is this right? */
   {"disarm", command_disarm,	1.0},
@@ -47,6 +52,7 @@ CommArray_s Commands[] = {
   {"invoke", command_invoke,	1.0},
   {"last", command_last,	0.0},
   {"listen", command_listen,	0.0},
+  {"logs", command_logs,	0.0},
   {"malloc", command_malloc,	0.0},
   {"maps", command_maps,	0.0},
   {"mapinfo", command_mapinfo,	0.0},
@@ -56,6 +62,7 @@ CommArray_s Commands[] = {
   {"output-count", command_output_count,0.0},
   {"peaceful", command_peaceful,0.0},
   {"pickup", command_pickup,	1.0},
+  {"players", command_players,	0.0},
   {"prepare", command_prepare,	1.0},
   {"quit", command_quit,	0.0},
   {"rotateshoottype", command_rotateshoottype,	0.0},
@@ -143,9 +150,34 @@ CommArray_s WizCommands [] = {
   {"summon", command_summon,0.0},
   {"wizpass", command_wizpass,0.0},
 };
-
 const int WizCommandsSize =sizeof(WizCommands) / sizeof(CommArray_s);
 
+/* Socket commands - these should really do nothing more than output things
+ * to the various players/sockets.
+ */
+CommArray_s Socket_Commands[] = {
+  {"hiscore", command_hiscore,	0.0},
+  {"logs", command_logs,	0.0},
+  {"maps", command_maps,	0.0},
+  {"motd", command_motd,	0.0},
+  {"players", command_players,	0.0},
+  {"version", command_version,	0.0},
+  {"who", command_who,		0.0},
+};
+
+const int Socket_CommandsSize =sizeof(Socket_Commands) / sizeof(CommArray_s);
+
+
+/* Socket commands - these should really do nothing more than output things
+ * to the various players/sockets.
+ */
+CommArray_s Socket2_Commands[] = {
+  {"shout", command_shout,	0.0},
+  {"tell", command_tell,	0.0},
+};
+
+const int Socket2_CommandsSize =sizeof(Socket2_Commands) / sizeof(CommArray_s);
+
 
 
 static int compare_A(const void *a, const void *b)
@@ -165,6 +197,42 @@ void init_commands()
 #endif
 
 
+CommFunc find_oldsocket_command(char *cmd)
+{
+  CommArray_s *asp, dummy;
+  char *cp;
+
+  for (cp=cmd; *cp; cp++) {
+    *cp =tolower(*cp);
+  }
+
+  dummy.name =cmd;
+  asp =(CommArray_s *)bsearch((void *)&dummy,
+			      (void *)Socket_Commands, Socket_CommandsSize,
+			      sizeof(CommArray_s), compare_A);
+  if (asp)
+    return asp->func;
+  return NULL;
+}
+
+CommFunc find_oldsocket_command2(char *cmd)
+{
+  CommArray_s *asp, dummy;
+  char *cp;
+
+  for (cp=cmd; *cp; cp++) {
+    *cp =tolower(*cp);
+  }
+
+  dummy.name =cmd;
+  asp =(CommArray_s *)bsearch((void *)&dummy,
+			      (void *)Socket2_Commands, Socket2_CommandsSize,
+			      sizeof(CommArray_s), compare_A);
+  if (asp)
+    return asp->func;
+  return NULL;
+}
+
 static CommFunc find_command(char *cmd)
 {
   CommArray_s *asp, dummy;
@@ -236,6 +304,8 @@ int parse_string(object *op, char *str)
      */
 
     *(cp++) ='\0';
+    /* Clear all spaces from the start of the optional argument */
+    while (*cp==' ') cp++;
 
     if ((f=find_command(str)))
 	return f(op, cp);
@@ -285,7 +355,3 @@ int parse_command(object *op, char *str) {
   }
   return 0;
 }
-
-		
-  
-  
