@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_apply_c =
- *   "$Id: gods.c,v 1.12 1998/09/28 03:09:56 master Exp master $";
+ *   "$Id: gods.c,v 1.13 1998/12/28 05:29:49 master Exp $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -438,6 +438,8 @@ void god_intervention(object *op, object *god) {
     /* add the gods attacktype*/
       if(!(RANDOM()%2)&&!(weapon->attacktype&god->attacktype)) {
         new_draw_info(NDI_UNIQUE,0,op,"Your weapon suddenly glows!");
+	if (weapon->attacktype==0)
+	    weapon->attacktype = AT_PHYSICAL;
 	weapon->attacktype=weapon->attacktype|god->attacktype;
 	return;
       }
