@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_init_c =
- *   "$Id: init.c,v 1.53 1998/09/28 03:19:27 master Exp master $";
+ *   "$Id: init.c,v 1.59 1999/03/28 01:32:11 master Exp $";
  */
 
 /*
@@ -50,7 +50,8 @@ void set_dumpmon8() {settings.dumpvalues=8; }
 void set_dumpmon9() {settings.dumpvalues=9; }
 void set_dumpmont(char *name) {settings.dumpvalues=10; settings.dumparg=name; }
 void set_daemon() {settings.daemonmode=1; }
-void set_libdir(char *path) { settings.libdir=path; }
+void set_datadir(char *path) { settings.datadir=path; }
+void set_localdir(char *path) { settings.localdir=path; }
 void set_mapdir(char *path) { settings.mapdir=path; }
 void set_archetypes(char *path) { settings.archetypes=path; }
 void set_treasures(char *path) { settings.treasures=path; }
@@ -73,6 +74,13 @@ void set_csport(char *val)
     }
 }
 
+static void stat_loss_on_death_true() {settings.stat_loss_on_death = 1; }
+static void stat_loss_on_death_false() {settings.stat_loss_on_death = 0; }
+
+static void simple_exp_true() {settings.simple_exp = 1; }
+static void simple_exp_false() {settings.simple_exp = 0; }
+
+
 /* Most of this is shamelessly stolen from XSysStats.  But since that is
  * also my program, no problem.
  */
@@ -98,12 +106,15 @@ struct Command_Line_Options options[] = {
  * initialize any data.
  */
 {"-h", 0, 1, help},
+/* Honor -help also, since it is somewhat common */
+{"-help", 0, 1, help},
 {"-v", 0, 1, call_version},
 {"-d", 0, 1, set_debug},
 {"+d", 0, 1, unset_debug},
 {"-mon", 0, 1, set_mondebug},
 #ifndef SECURE
-{"-lib",1,1, set_libdir},
+{"-data",1,1, set_datadir},
+{"-local",1,1, set_localdir},
 {"-maps", 1, 1, set_mapdir},
 {"-arch", 1, 1, set_archetypes},
 {"-playerdir", 1, 1, set_playerdir},
@@ -118,6 +129,7 @@ struct Command_Line_Options options[] = {
 {"-log", 1, 2, set_logfile},
 {"-csport", 1, 2, set_csport},
 {"-detach", 0, 2, set_daemon},
+
 /* Start of pass 3 information. In theory, by pass 3, all data paths
  * and defaults should have been set up. 
  */
@@ -136,6 +148,10 @@ struct Command_Line_Options options[] = {
 #endif
 {"-s", 0, 3, showscores},
 {"-score", 1, 3, showscoresparm},
+{"-simple_exp", 0, 3, simple_exp_true},
+{"+simple_exp", 0, 3, simple_exp_false},
+{"-stat_loss_on_death", 0, 3, stat_loss_on_death_true},
+{"+stat_loss_on_death", 0, 3, stat_loss_on_death_false},
 };
 
 
@@ -229,21 +245,44 @@ void init(int argc, char **argv) {
 
 void usage() {
   (void) fprintf(logfile,
-	"Usage: crossfire [-h] [-<flags>]... -display [display1] -display [display2]...\n");
+	"Usage: crossfire [-h] [-<flags>]...\n");
 }
 
 void help() {
-    usage();
+/* The information in usage is redundant with what is given below, so why call it? */
+/*    usage();*/
     printf("Flags:\n");
-    printf(" -b          Black/white instead of colors.\n");
+    printf(" -csport <port> Specifies the port to use for the new client/server code.\n");
     printf(" -d          Turns on some debugging.\n");
-    printf(" -display <display> Open crossfire on the specified display.  Multiple\n");
-    printf("             displays can be given.\n");
-
-    printf(" -f          Only Flush, don't Synchronize.\n");
+    printf(" +d          Turns off debugging (useful if server compiled with debugging\n");
+    printf("             as default).\n");
+    printf(" -detach     The server will go in the background, closing all\n");
+    printf("             connections to the tty.\n");
     printf(" -h          Display this information.\n");
-    printf(" -l          Removes local player (Won't try to add player $DISPLAY).\n");
+    printf(" -log <file> Specifies which file to send output to.\n");
+    printf("             Only has meaning if -detach is specified.\n");
+    printf(" -mon        Turns on monster debugging.\n");
+    printf(" -o          Prints out info on what was defined at compile time.\n");
+    printf(" -s          Display the high-score list.\n");
+    printf(" -score <name or class> Displays all high scores with matching name/class.\n");
+    printf(" -stat_loss_on_death - if set, player loses stat when they die");
+    printf(" +stat_loss_on_death - if set, player does not lose a stat when they die");
+    printf(" -v          Print version and contributors.\n");
+
+#ifndef SECURE
+    printf("\nThe following options are only available if a secure server was not compiled.\n");
+    printf(" -data       Sets the lib dir (archetypes, treasures, etc.)\n");
+    printf(" -local      Read/write local data (hiscore, unique items, etc.)\n");
+    printf(" -maps       Sets the directory for maps.\n");
+    printf(" -arch       Sets the archetype file to use.\n");
+    printf(" -playerdir  Sets the directory for the player files.\n");
+    printf(" -treasures	 Sets the treasures file to use.\n");
+    printf(" -uniquedir  Sets the unique items/maps directory.\n");
+    printf(" -tmpdir     Sets the directory for temporary files (mostly maps.)\n");
+#endif
+
 #ifdef DUMP_SWITCHES
+    printf("\nThe following are only available in DUMP_SWITCHES was compiled in.\n");
     printf(" -m          Lists out suggested experience for all monsters.\n");
     printf(" -m2         Dumps out abilities.\n");
     printf(" -m3         Dumps out artificat information.\n");
@@ -255,20 +294,6 @@ void help() {
     printf(" -m9         Dumps out more alchemy information (formula checking).\n");
     printf(" -mt <name>  Dumps out list of treasures for a monster.\n");
 #endif
-    printf(" -mon        Turns on monster debugging.\n");
-    printf(" -o          Prints out info on what was defined at compile time.\n");
-    printf(" -p          Don't try to fix the fontpath.\n");
-    printf(" -pix        Uses pixmaps instead of fonts.\n");
-    printf(" -s          Display the high-score list.\n");
-    printf(" -score <name or class> Displays all high scores with matching name/class.\n");
-    printf(" -split      Makes split-windows default.\n");
-    printf(" -v          Print version and contributors.\n");
-    printf(" -csport <port> Specifies the port to use for the new client/server code.\n");
-    printf(" -detach     The server will go in the background, closing all\n");
-    printf("             connections to the tty.\n");
-    printf(" -log <file> Specifies which file to send output to.\n");
-    printf("             Only has meaning if -detach is specified.\n");
-    printf(" -server     Puts crossfire into server mode.\n");
     exit(0);
 }
 
@@ -328,7 +353,7 @@ void init_startup() {
   int comp;
 
 #ifdef SHUTDOWN_FILE
-  sprintf(buf,"%s/%s",settings.libdir,SHUTDOWN_FILE);
+  sprintf(buf,"%s/%s",settings.datadir,SHUTDOWN_FILE);
   if ((fp = open_and_uncompress(buf, 0, &comp)) != NULL) {
     while (fgets(buf, MAX_BUF-1, fp) != NULL)
       printf("%s", buf);
@@ -379,7 +404,8 @@ void compile_info() {
 #else
   printf("Secure:\t\t<false>\n");
 #endif
-  printf("Libdir:\t\t%s\n",settings.libdir);
+  printf("Datadir:\t\t%s\n",settings.datadir);
+  printf("Localdir:\t\t%s\n",settings.localdir);
 #ifdef PERM_FILE
   printf("Perm file:\t<LIB>/%s\n",PERM_FILE);
 #endif
@@ -532,7 +558,6 @@ void setup_library() {
   set_process_active_maps(process_active_maps);
   set_update_buttons(update_buttons);
   set_draw_info(new_draw_info);
-  set_draw_look(draw_look);
   set_apply(apply);
   set_draw(draw);
   set_monster_check_apply(monster_check_apply);
@@ -563,7 +588,7 @@ void init_races () {
   init_done=1;
   first_race=NULL;
 
-  sprintf(fname,"%s/races",settings.libdir);
+  sprintf(fname,"%s/races",settings.datadir);
   LOG(llevDebug, "Reading races from %s...",fname);
   if(! (file=fopen(fname,"r"))) {
         perror(fname); return;
