@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_input_c =
- *   "$Id: input.c,v 1.66 1998/09/28 03:22:27 master Exp master $";
+ *   "$Id: input.c,v 1.74 1999/07/13 05:19:47 master Exp master $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -174,100 +174,108 @@ char *long_desc(object *tmp) {
 }
 
 void examine(object *op, object *tmp) {
-  char buf[VERY_BIG_BUF];
+    char buf[VERY_BIG_BUF];
 
-  if (tmp == NULL || tmp->type == CLOSE_CON)
-    return;
-/* Eneq(csd.uu.se): If NO_PRETEXT is defined we should only print the name. */
-  if (QUERY_FLAG(tmp, FLAG_NO_PRETEXT))
-    sprintf(buf, "%s.", long_desc(tmp));
-  else
-    sprintf(buf, "That is %s.", long_desc(tmp));
-  new_draw_info(NDI_UNIQUE, 0,op,buf);
-  buf[0]='\0';
-  switch(tmp->type) {
-  case SPELLBOOK:
-    if(QUERY_FLAG(tmp, FLAG_IDENTIFIED) && tmp->stats.sp > 0 && tmp->stats.sp <= NROFREALSPELLS ) {
-      if(!strcmp(tmp->arch->name,"cleric_book"))
-        sprintf(buf,"%s is a %d level prayer.",
-              spells[tmp->stats.sp].name,spells[tmp->stats.sp].level);
-      else
-        sprintf(buf,"%s is a %d level spell.",
-              spells[tmp->stats.sp].name,spells[tmp->stats.sp].level);
+    if (tmp == NULL || tmp->type == CLOSE_CON)
+	return;
+
+    /* Eneq(csd.uu.se): If NO_PRETEXT is defined we should only print the name. */
+    if (QUERY_FLAG(tmp, FLAG_NO_PRETEXT))
+	sprintf(buf, "%s.", long_desc(tmp));
+    else
+	sprintf(buf, "That is %s.", long_desc(tmp));
+
+    new_draw_info(NDI_UNIQUE, 0,op,buf);
+    buf[0]='\0';
+    switch(tmp->type) {
+	case SPELLBOOK:
+	    if(QUERY_FLAG(tmp, FLAG_IDENTIFIED) && tmp->stats.sp > 0 && tmp->stats.sp <= NROFREALSPELLS ) {
+		if(!strcmp(tmp->arch->name,"cleric_book"))
+		    sprintf(buf,"%s is a %d level prayer.",
+			    spells[tmp->stats.sp].name,spells[tmp->stats.sp].level);
+		else
+		    sprintf(buf,"%s is a %d level spell.",
+			    spells[tmp->stats.sp].name,spells[tmp->stats.sp].level);
+	    }
+	break;
+
+	case BOOK:
+	    if(tmp->msg!=NULL)
+		strcpy(buf,"Something is written in it.");
+	break;
+
+	case CONTAINER:
+	    if(tmp->race!=NULL) {
+		if(tmp->weight_limit && tmp->stats.Str<100)
+		    sprintf (buf,"It can hold only %s and its weight limit is %.1f kg.", 
+			 tmp->race, tmp->weight_limit/(10.0 * (100 - tmp->stats.Str)));
+		else
+		    sprintf (buf,"It can hold only %s.", tmp->race);
+	    } else
+		if(tmp->weight_limit && tmp->stats.Str<100)
+		    sprintf (buf,"Its weight limit is %.1f kg.", 
+			     tmp->weight_limit/(10.0 * (100 - tmp->stats.Str)));
+	    break;
+
+	case WAND:
+	    if(QUERY_FLAG(tmp, FLAG_IDENTIFIED))
+		sprintf(buf,"It has %d charges left.",tmp->stats.food);
+	    break;
     }
-    break;
-  case BOOK:
-    if(tmp->msg!=NULL)
-      strcpy(buf,"Something is written in it.");
-    break;
-  case CONTAINER:
-    if(tmp->race!=NULL) {
-      if(tmp->weight_limit && tmp->stats.Str<100)
-        sprintf (buf,"It can hold only %s and its weight limit is %.1f kg.", 
-		 tmp->race, tmp->weight_limit/(10.0 * (100 - tmp->stats.Str)));
-      else
-        sprintf (buf,"It can hold only %s.", tmp->race);
-    } else
-      if(tmp->weight_limit && tmp->stats.Str<100)
-        sprintf (buf,"Its weight limit is %.1f kg.", 
-		tmp->weight_limit/(10.0 * (100 - tmp->stats.Str)));
-    break;
-  case WAND:
-    if(QUERY_FLAG(tmp, FLAG_IDENTIFIED))
-      sprintf(buf,"It has %d charges left.",tmp->stats.food);
-    break;
-  }
-  if(buf[0]!='\0')
-    new_draw_info(NDI_UNIQUE, 0,op,buf);
-  if(tmp->material) {
-    strcpy(buf,"It is made of: ");
-    if(tmp->material&M_PAPER)
-      strcat(buf,"paper ");
-    if(tmp->material&M_IRON)
-      strcat(buf,"iron ");
-    if(tmp->material&M_GLASS)
-      strcat(buf,"glass ");
-    if(tmp->material&M_LEATHER)
-      strcat(buf,"leather ");
-    if(tmp->material&M_WOOD)
-      strcat(buf,"wood ");
-    if(tmp->material&M_ORGANIC)
-      strcat(buf,"organics ");
-    if(tmp->material&M_STONE)
-      strcat(buf,"stone ");
-    if(tmp->material&M_CLOTH)
-      strcat(buf,"cloth ");
-    if(tmp->material&M_ADAMANT)
-      strcat(buf,"adamantite ");
-    new_draw_info(NDI_UNIQUE, 0,op,buf);
-  }
-  if(tmp->weight) {
-    sprintf(buf,"%s weighs %3.3f kg.", tmp->nrof>1?"They":"It",
+
+    if(buf[0]!='\0')
+	new_draw_info(NDI_UNIQUE, 0,op,buf);
+
+    if(tmp->material) {
+	strcpy(buf,"It is made of: ");
+	if(tmp->material&M_PAPER)	    strcat(buf,"paper ");
+	if(tmp->material&M_IRON)	    strcat(buf,"iron ");
+	if(tmp->material&M_GLASS)	    strcat(buf,"glass ");
+	if(tmp->material&M_LEATHER)	    strcat(buf,"leather ");
+	if(tmp->material&M_WOOD)	    strcat(buf,"wood ");
+	if(tmp->material&M_ORGANIC)	    strcat(buf,"organics ");
+	if(tmp->material&M_STONE)	    strcat(buf,"stone ");
+	if(tmp->material&M_CLOTH)	    strcat(buf,"cloth ");
+	if(tmp->material&M_ADAMANT)	    strcat(buf,"adamantite ");
+	new_draw_info(NDI_UNIQUE, 0,op,buf);
+    }
+
+    if(tmp->weight) {
+	sprintf(buf,"%s weighs %3.3f kg.", tmp->nrof>1?"They":"It",
             (tmp->nrof?tmp->weight*tmp->nrof:tmp->weight)/1000.0);
-    new_draw_info(NDI_UNIQUE, 0,op,buf);
-  }
-  if(tmp->value&&!QUERY_FLAG(tmp, FLAG_STARTEQUIP)) {
-    if(QUERY_FLAG(tmp, FLAG_UNPAID))
-      sprintf(buf,"%s would cost you %s.",
-              tmp->nrof>1?"They":"It",query_cost_string(tmp,op,F_BUY));
-    else
-      sprintf(buf,"You would get %s for %s.",
-              query_cost_string(tmp,op,F_SELL), tmp->nrof>1?"them":"it");
-    new_draw_info(NDI_UNIQUE, 0,op,buf);
-  }
-  if(QUERY_FLAG(tmp, FLAG_MONSTER))
-    examine_monster(op,tmp);
-  if(tmp->msg && tmp->type != EXIT && tmp->type != BOOK && tmp->type != CORPSE
-     && !QUERY_FLAG(tmp, FLAG_WALK_ON)) {
-    if (need_identify(tmp) && QUERY_FLAG(tmp, FLAG_IDENTIFIED))
-      new_draw_info(NDI_UNIQUE, 0,op, "The object has a story:");
-#if 0 /* it might not be written on it */
-    else
-      new_draw_info(NDI_UNIQUE, 0,op,"Something is written on it:");
-#endif
-    new_draw_info(NDI_UNIQUE, 0,op,tmp->msg);
-  }
-  new_draw_info(NDI_UNIQUE, 0,op," "); /* Blank line */
+	new_draw_info(NDI_UNIQUE, 0,op,buf);
+    }
+
+    if(tmp->value&&!QUERY_FLAG(tmp, FLAG_STARTEQUIP)) {
+	if(QUERY_FLAG(tmp, FLAG_UNPAID))
+	    sprintf(buf,"%s would cost you %s.",
+		    tmp->nrof>1?"They":"It",query_cost_string(tmp,op,F_BUY));
+	else
+	    sprintf(buf,"You would get %s for %s.",
+		    query_cost_string(tmp,op,F_SELL), tmp->nrof>1?"them":"it");
+	new_draw_info(NDI_UNIQUE, 0,op,buf);
+    }
+
+    if(QUERY_FLAG(tmp, FLAG_MONSTER))
+	examine_monster(op,tmp);
+   
+
+    /* Does the object have a message?  Don't show message for all object
+     * types - especially if the first entry is a match
+     */
+    if(tmp->msg && tmp->type != EXIT && tmp->type != BOOK && 
+       tmp->type != CORPSE && !QUERY_FLAG(tmp, FLAG_WALK_ON) && 
+       strncasecmp(tmp->msg, "@match",7)) {
+
+	/* This is just a hack so when identifying hte items, we print
+	 * out the extra message
+	 */
+	if (need_identify(tmp) && QUERY_FLAG(tmp, FLAG_IDENTIFIED))
+	    new_draw_info(NDI_UNIQUE, 0,op, "The object has a story:");
+
+	new_draw_info(NDI_UNIQUE, 0,op,tmp->msg);
+    }
+    new_draw_info(NDI_UNIQUE, 0,op," "); /* Blank line */
 }
 
 /*
@@ -298,7 +306,7 @@ void inventory(object *op,object *inv) {
       new_draw_info(NDI_UNIQUE, 0,op,"You carry nothing.");
       return;
     } else {
-      length = INFOCHARS-19;
+      length = 30;
       in = "";
       if (op)
         clear_win_info(op);
@@ -308,7 +316,7 @@ void inventory(object *op,object *inv) {
     if (items==0) 
       return;
     else { 
-      length = INFOCHARS-21;
+      length = 30;
       in = "  ";
     }
   }
@@ -326,64 +334,11 @@ void inventory(object *op,object *inv) {
   }
   if(!inv && op) {
     sprintf(buf,"%-*s %-8s",
-            INFOCHARS-9,"Total weight :",query_weight(op));
+            41,"Total weight :",query_weight(op));
     new_draw_info(NDI_UNIQUE, 0,op,buf);
   }
 }
 
-/*
- * look_at prints items on the specifc square.
- * [ removed EARTHWALL check and added check for containers inventory.
- *   Tero.Haatanen@lut.fi ]
- */
-void look_at(object *op,int dx,int dy) {
-  object *tmp;
-  char buf[MAX_BUF];
-  int flag=0;
-
-  if (out_of_map(op->map, op->x+dx, op->y+dy)) return;
-  if(op->above!=NULL) {
-    remove_ob(op);
-    insert_ob_in_map(op,op->map);
-  }
-  if(dx||dy) 
-    for(tmp=get_map_ob(op->map,op->x+dx,op->y+dy);tmp!=NULL&&tmp->above!=NULL;
-      tmp=tmp->above);
-  else
-    tmp=op->below;
-  while(tmp && (QUERY_FLAG(op, FLAG_WIZ) ||(!tmp->invisible && tmp!=op))) {
-    if(!flag) {
-      if(dx||dy)
-        new_draw_info(NDI_UNIQUE, 0,op,"There you see:");
-      else {
-        clear_win_info(op);
-        new_draw_info(NDI_UNIQUE, 0,op,"You see:");
-      }
-      flag=1;
-    }
-    if(QUERY_FLAG(op, FLAG_WIZ))
-      (void) sprintf(buf,"- %s (%d).",query_name(tmp),tmp->count);
-    else
-      (void) sprintf(buf,"- %s.",query_name(tmp));
-    new_draw_info(NDI_UNIQUE, 0,op,buf);
-    if((tmp->inv!=NULL || (tmp->head && tmp->head->inv)) && 
-       ( (!dx&&!dy) || tmp->type != CONTAINER || QUERY_FLAG(op, FLAG_WIZ)
-/* added some cases here -b.t. */
-	|| !(tmp->type) || tmp->type!=FLESH ))
-      inventory(op,tmp->head==NULL?tmp:tmp->head);
-    if(QUERY_FLAG(tmp, FLAG_IS_FLOOR)&&!QUERY_FLAG(op, FLAG_WIZ))	/* don't continue under the floor */
-      break;
-    tmp=tmp->below;
-  }
-  if(!flag) {
-    if(dx||dy)
-      new_draw_info(NDI_UNIQUE, 0,op,"You see nothing there.");
-    else
-      new_draw_info(NDI_UNIQUE, 0,op,"You see nothing.");
-  }
-}
-
-
 
 void receive_player_name(object *op,char k) {
 
@@ -489,15 +444,15 @@ static void help_topics(object *op, int what)
   
     switch (what) {
 	case 1:
-	    sprintf(filename, "%s/wizhelp", settings.libdir);
+	    sprintf(filename, "%s/wizhelp", settings.datadir);
 	    new_draw_info(NDI_UNIQUE, 0,op, "      Wiz commands:");
 	    break;
 	case 3:
-	    sprintf(filename, "%s/mischelp", settings.libdir);
+	    sprintf(filename, "%s/mischelp", settings.datadir);
 	    new_draw_info(NDI_UNIQUE, 0,op, "      Misc help:");
 	    break;
 	default:
-	    sprintf(filename, "%s/help", settings.libdir);
+	    sprintf(filename, "%s/help", settings.datadir);
 	    new_draw_info(NDI_UNIQUE, 0,op, "      Commands:");
 	    break;
     }
@@ -575,7 +530,7 @@ int command_help (object *op, char *params)
    * Main help page?
  */
   if (!params) {
-    sprintf(filename, "%s/def_help", settings.libdir);
+    sprintf(filename, "%s/def_help", settings.datadir);
     if ((fp=fopen(filename, "r")) == NULL) {
       LOG(llevError, "Can't open %s\n", filename);
       perror("Can't read default help");
@@ -622,13 +577,13 @@ int command_help (object *op, char *params)
     return 0;
   }
 
-  sprintf(filename, "%s/mischelp/%s", settings.libdir, params);
+  sprintf(filename, "%s/mischelp/%s", settings.datadir, params);
   if (stat(filename, &st) || !S_ISREG(st.st_mode)) {
     if (op) {
-      sprintf(filename, "%s/help/%s", settings.libdir, params);
+      sprintf(filename, "%s/help/%s", settings.datadir, params);
       if (stat(filename, &st) || !S_ISREG(st.st_mode)) {
 	if (QUERY_FLAG(op, FLAG_WIZ)) {
-	  sprintf(filename, "%s/wizhelp/%s", settings.libdir, params);
+	  sprintf(filename, "%s/wizhelp/%s", settings.datadir, params);
 	  if (stat(filename, &st) || !S_ISREG(st.st_mode))
 	    goto nohelp;
 	} else
@@ -907,11 +862,15 @@ int command_title (object *op, char *params)
 
 int command_save (object *op, char *params)
 {
-      if(save_player(op,1))
-	new_draw_info(NDI_UNIQUE, 0,op,"You have been saved.");
-      else
-	new_draw_info(NDI_UNIQUE, 0,op,"SAVE FAILED!");
-      return 1;
+    if (blocks_cleric(op->map, op->x, op->y)) {
+	new_draw_info(NDI_UNIQUE, 0, op, "You can not save on unholy ground");
+    } else {
+	if(save_player(op,1))
+	    new_draw_info(NDI_UNIQUE, 0,op,"You have been saved.");
+	else
+	    new_draw_info(NDI_UNIQUE, 0,op,"SAVE FAILED!");
+    }
+    return 1;
 }
 
 #ifdef SEARCH_ITEMS
@@ -951,15 +910,6 @@ int command_peaceful (object *op, char *params)
       return 1;
     }
 
-int command_berzerk (object *op, char *params)
-{
-      if((op->contr->berzerk=!op->contr->berzerk))
-        new_draw_info(NDI_UNIQUE, 0,op,"Berzerk is enabled.");
-      else
-        new_draw_info(NDI_UNIQUE, 0,op,"Berzerk is disabled.");
-      return 1;
-    }
-
 int command_strength (object *op, char *params)
 {
       int i;
@@ -1009,13 +959,8 @@ int command_wimpy (object *op, char *params)
 
 int command_quit (object *op, char *params)
 {
-    char *wiz_quit="This will delete your character!\nAre you still sure you want to quit(y/n)?",
-	*quit="Are you sure you want to quit(y/n)?",*cp;
-
-    if(op->stats.exp&&!QUERY_FLAG(op, FLAG_WAS_WIZ)) cp=wiz_quit;
-    else cp=quit;
-
-    send_query(&op->contr->socket,CS_QUERY_SINGLECHAR,cp);
+    send_query(&op->contr->socket,CS_QUERY_SINGLECHAR,
+	       "Quitting will delete your character.\nAre you sure you want to quit (y/n):");
 
     op->contr->state = ST_CONFIRM_QUIT;
     return 1;
@@ -1214,7 +1159,7 @@ void change_spell(object *op,char k) {
     if(op->contr->shoottype >= range_size)
       op->contr->shoottype = range_none;
     else if (op->contr->shoottype <= range_bottom)
-      op->contr->shoottype = (rangetype) range_size-1;
+      op->contr->shoottype = (rangetype)(range_size-1);
   } while (!legal_range(op,op->contr->shoottype));
   switch(op->contr->shoottype) {
   case range_none:
