@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_login_c =
- *   "$Id: login.c,v 1.53 1998/09/28 03:23:47 master Exp master $";
+ *   "$Id: login.c,v 1.60 1999/07/13 05:17:57 master Exp master $";
  */
 
 /*
@@ -31,6 +31,7 @@
 #endif
 #include <spells.h>
 #include <loader.h>
+#include <define.h>
 
 extern spell spells[NROFREALSPELLS];
 extern void sub_weight (object *, signed long);
@@ -95,11 +96,11 @@ void emergency_save(int flag) {
 void delete_character(char *name, int new) {
     char buf[MAX_BUF];
 
-    sprintf(buf,"%s/%s/%s.pl",settings.libdir,settings.playerdir,name);
+    sprintf(buf,"%s/%s/%s.pl",settings.localdir,settings.playerdir,name);
     if(unlink(buf)== -1 && settings.debug)
 	perror("crossfire (delete character)");
     if (new) {
-	sprintf(buf,"%s/%s/%s",settings.libdir,settings.playerdir,name);
+	sprintf(buf,"%s/%s/%s",settings.localdir,settings.playerdir,name);
 	/* this effectively does an rm -rf on the directory */
 	remove_directory(buf);
     }
@@ -123,7 +124,7 @@ void delete_character(char *name, int new) {
 void unlock_player(char *name) {
     char buf[MAX_BUF];
 
-    sprintf(buf,"%s/%s/%s.lock",settings.libdir,settings.playerdir,name);
+    sprintf(buf,"%s/%s/%s.lock",settings.localdir,settings.playerdir,name);
     if(!rmdir(buf)) {
 #ifdef DEBUG
 	perror("Couldn't remove lockfile(dir)");
@@ -131,6 +132,7 @@ void unlock_player(char *name) {
     }
 }
 
+#if 0
 /* creates a lock for player 'name'.  returns 0 if the lock is successful,
  * 1 otherwise.
  */
@@ -138,7 +140,7 @@ void unlock_player(char *name) {
 static int lock_player(char *name) {
     char buf[MAX_BUF];
 
-    sprintf(buf,"%s/%s/%s.lock",settings.libdir,settings.playerdir,name);
+    sprintf(buf,"%s/%s/%s.lock",settings.localdir,settings.playerdir,name);
     if(!mkdir(buf,0770))
 	return 0;
     if(errno != EEXIST) {
@@ -147,6 +149,44 @@ static int lock_player(char *name) {
     }
     return 1;
 }
+#endif
+
+/* This verify that a character of name exits, and that it matches
+ * password.  It return 0 if there is match, 1 if no such player,
+ * 2 if incorrect password.
+ */
+
+int verify_player(char *name, char *password)
+{
+    char buf[MAX_BUF];
+    int comp;
+    FILE *fp;
+
+    sprintf(buf,"%s/%s/%s/%s.pl",settings.localdir,settings.playerdir,name,name);
+    if ((fp=open_and_uncompress(buf,0,&comp))==NULL) return 1;
+
+    /* Read in the file until we find the password line.  Our logic could
+     * be a bit better on cleaning up the password from the file, but since
+     * it is written by the program, I think it is fair to assume that the
+     * syntax should be pretty standard.
+     */
+    while (fgets(buf, MAX_BUF-1, fp) != NULL) {
+	if (!strncmp(buf,"password ",9)) {
+	    buf[strlen(buf)-1]=0;	/* remove newline */
+	    if (check_password(password, buf+9)) {
+		close_and_delete(fp, comp);
+		return 0;
+	    }
+	    else {
+		close_and_delete(fp, comp);
+		return 2;
+	    }
+	}
+    }
+    LOG(llevDebug,"Could not find a password line in player %s\n", name);
+    close_and_delete(fp, comp);
+    return 1;
+}
 
 /* Checks to see if anyone else by 'name' is currently playing.  We
  * do this by a lockfile (playername.lock) in the save directory.  If
@@ -157,7 +197,6 @@ static int lock_player(char *name) {
 
 int check_name(player *me,char *name) {
     player *pl;
-    char buf[MAX_BUF];
 
     for(pl=first_player;pl!=NULL;pl=pl->next)
 	if(pl!=me&&pl->ob->name!=NULL&&!strcmp(pl->ob->name,name)) {
@@ -165,6 +204,15 @@ int check_name(player *me,char *name) {
 	    return 0;
 	}
 
+#if 0
+    /* This is commented out - unexpected client/server crashes can leave the
+     * lock files laying around.  In retrospect, I don't think the reason
+     * give above is needed for lock files.  If two new people are creating
+     * characters at the same time (or logging in), the server data
+     * is still consistent (ie, it will get the name from player 1, store
+     * it in the player object, get the name from player 2, check it against
+     * current players and find a duplicated.)
+     */
     if(lock_player(name)) {
 	/* Include the 'locked' so that the error message is more descriptive.
 	 * This way, players can include a slightly more detailed message
@@ -173,7 +221,7 @@ int check_name(player *me,char *name) {
 	new_draw_info(NDI_UNIQUE, 0,me->ob,"That name is already in use (locked).");
 	return 0;
     }
-
+#endif
     if(!playername_ok(name)) {
 	unlock_player(name);
 	new_draw_info(NDI_UNIQUE, 0,me->ob,"That name contains illegal characters.");
@@ -246,14 +294,23 @@ int save_player(object *op, int flag) {
     return 0;
   }
 
+    /* Sanity check - some stuff changes this when player is exiting */
+    if (op->type != PLAYER) return 0;
+
+    /* Prevent accidental saves if connection is reset after player has
+     * mostly exited.
+     */
+    if (pl->state != ST_PLAYING && pl->state != ST_GET_PARTY_PASSWORD)
+	return 0;
+
   if (flag == 0)
     terminate_all_pets(op);
 
   /* Delete old style file */
-  sprintf(filename,"%s/%s/%s.pl",settings.libdir,settings.playerdir,op->name);
+  sprintf(filename,"%s/%s/%s.pl",settings.localdir,settings.playerdir,op->name);
   unlink(filename);
 
-  sprintf(filename,"%s/%s/%s/%s.pl",settings.libdir,settings.playerdir,op->name,op->name);
+  sprintf(filename,"%s/%s/%s/%s.pl",settings.localdir,settings.playerdir,op->name,op->name);
   make_path_to_file(filename);
   tmpfilename = tempnam_local(settings.tmpdir,NULL);
   fp=fopen(tmpfilename, "w");
@@ -285,7 +342,6 @@ int save_player(object *op, int flag) {
   fprintf(fp,"listening %d\n",pl->listening);
   fprintf(fp,"spell %d\n",pl->chosen_spell);
   fprintf(fp,"shoottype %d\n",pl->shoottype);
-  fprintf(fp,"berzerk %d\n",pl->berzerk);
   fprintf(fp,"peaceful %d\n",pl->peaceful);
   fprintf(fp,"digestion %d\n",pl->digestion);
   fprintf(fp,"pickup %d\n", pl->mode);
@@ -439,6 +495,7 @@ static int spell_sort(const char *a1,const char *a2)
 }
 #endif
 
+
 void check_login(object *op) {
   FILE *fp;
   char filename[MAX_BUF];
@@ -450,14 +507,14 @@ void check_login(object *op) {
   strcpy (pl->maplevel, first_map_path);
 
   /* First, lets check for newest form of save */
-  sprintf(filename,"%s/%s/%s/%s.pl",settings.libdir,settings.playerdir,op->name,op->name);
+  sprintf(filename,"%s/%s/%s/%s.pl",settings.localdir,settings.playerdir,op->name,op->name);
   if (access(filename, F_OK)==-1) {
     /* not there,  Try the old style */
 
-    sprintf(filename,"%s/%s/%s.pl",settings.libdir,settings.playerdir,op->name);
+    sprintf(filename,"%s/%s/%s.pl",settings.localdir,settings.playerdir,op->name);
     /* Ok - old style exists.  Lets make the new style directory */
     if (access(filename, F_OK)==0) {
-	sprintf(buf,"%s/%s/%s",settings.libdir,settings.playerdir,op->name);
+	sprintf(buf,"%s/%s/%s",settings.localdir,settings.playerdir,op->name);
 	make_path_to_file(buf);
     }
   }
@@ -533,8 +590,6 @@ void check_login(object *op) {
           pl->chosen_spell=value;
         else if (!strcmp(buf,"listening"))
           pl->listening=value;
-        else if (!strcmp(buf,"berzerk"))
-          pl->berzerk=value;
         else if (!strcmp(buf,"peaceful"))
           pl->peaceful=value;
         else if (!strcmp(buf,"digestion"))
@@ -664,8 +719,9 @@ void check_login(object *op) {
 	 * sent to the client.
 	 */
 	legal_range(op, op->contr->shoottype);
-        fix_player(op);
 	fix_weight ();
+	/* fix_weight calls fix_player */
+	/*fix_player(op);*/
 	esrv_new_player(op->contr,op->weight+op->carrying);
 	esrv_send_inventory(op, op);
 
@@ -678,6 +734,9 @@ void check_login(object *op) {
 
 
         new_draw_info(NDI_UNIQUE, 0,op,"Welcome Back!");
+	new_draw_info_format(NDI_UNIQUE | NDI_ALL, 5, NULL, 
+			     "%s has entered the game.",pl->ob->name);
+
         if(pl->loading == NULL) {
           if(!out_of_map(op->map,x,y))
             op->x=x, op->y=y;
@@ -687,7 +746,7 @@ void check_login(object *op) {
                   op->map->path);
           pl->removed = 0; /* Pl. will be inserted when map is loaded */
         }
-        draw_look(op);
+	op->contr->socket.update_look=1;
         close_and_delete(fp, comp);
         LOG(llevDebug,"Checksums: %x %x\n",
                 checksum,calculate_checksum(filename,1));
