@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_main_c =
- *    "$Id: main.c,v 1.46 1998/09/28 03:26:39 master Exp master $";
+ *    "$Id: main.c,v 1.54 1999/06/13 22:14:08 master Exp $";
  */
 
 /*
@@ -26,28 +26,24 @@
     The author can be reached via e-mail to master@rahul.net
 */
 
-#if ((defined(__sun__) || defined(__sgi)) && defined(SVR4))
-#include <crypt.h>
-#endif
-#if defined(__osf__)
-/* <crypt.h> declares crypt_r(), but not crypt() !?! (OSF/1 1.0) */
-extern char *crypt(const char *, const char *);
-#endif
-
-#if defined(linux)
+#ifdef HAVE_CRYPT_H
 #include <crypt.h>
 #endif
 
 #include <version.h>
 #include <global.h>
+#include <object.h>
+
 #ifndef __CEXTRACT__
 #include <sproto.h>
 #endif
-#include <object.h>
-#if defined (_IBMR2) || defined (___IBMR2) /* Which is correct? */
+
+#ifdef HAVE_TIME_H
 #include <time.h>
 #endif
 
+#include <../random_maps/rproto.h>
+
 static char days[7][4] = {
   "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
 
@@ -62,7 +58,7 @@ void version(object *op) {
  */
   if (op==NULL) return;
   new_draw_info(NDI_UNIQUE, 0,op,"Authors and contributors to this program:");
-  new_draw_info(NDI_UNIQUE, 0,op,"master@rahul.net (Mark Wedel)");
+  new_draw_info(NDI_UNIQUE, 0,op,"mark@pyramid.com (Mark Wedel)");
   new_draw_info(NDI_UNIQUE, 0,op,"frankj@ifi.uio.no (Frank Tore Johansen)");
   new_draw_info(NDI_UNIQUE, 0,op,"kjetilho@ifi.uio.no (Kjetil Torgrim Homme)");
   new_draw_info(NDI_UNIQUE, 0,op,"tvangod@ecst.csuchico.edu (Tyler Van Gorder)");
@@ -149,7 +145,7 @@ char *crypt_string(char *str, char *salt) {
   else
     s[0]= salt[0],
     s[1]= salt[1];
-  return crypt(str,s);
+  return (char*)crypt(str,s);
 }
 
 int check_password(char *typed,char *crypted) {
@@ -209,203 +205,246 @@ char *normalize_path (char *src, char *dst) {
  */
 
 void enter_exit(object *op, object *exit_ob) {
-    char buf[MAX_BUF], apartment[MAX_BUF]="";
-    mapstruct *oldmap, dummy_map;
-    int x=0, y=0, removed=QUERY_FLAG(op,FLAG_REMOVED);
-    char *newpath=NULL, *lastlevel=NULL;
-    int last_x = op->x, last_y = op->y, notunique=1;
+  char apartment[MAX_BUF];
+  mapstruct *oldmap, dummy_map;
+  int x=0, y=0, removed=QUERY_FLAG(op,FLAG_REMOVED);
+  char *newpath=NULL, *lastlevel=NULL;
+  int last_x = op->x, last_y = op->y, unique=0;
 
-    dummy_map.pending = (objectlink *) NULL;
-    dummy_map.in_memory = MAP_LOADING;
+  dummy_map.pending = (objectlink *) NULL;
+  dummy_map.in_memory = MAP_LOADING;
+  *apartment='\0';
 
-    /* First, lets figure out what map the player is going to go to */
-    if (exit_ob) {
-	x=EXIT_X(exit_ob);
-	y=EXIT_Y(exit_ob);
+  /* First, lets figure out what map the player is going to go to */
+  if (exit_ob) {
+	 x=EXIT_X(exit_ob);
+	 y=EXIT_Y(exit_ob);
 
-	if (EXIT_PATH(exit_ob)) {
-	    newpath = normalize_path (exit_ob->map->path, EXIT_PATH(exit_ob));
-	} else {
-	    if (EXIT_LEVEL (exit_ob) > 0)
-		LOG(llevError,"Number Map levels are no more supported\n");
-	    return;
-	}
-    } else
-	newpath = op->contr->maplevel;
+	 /* check to see if we make a randomly generated map */
+	 if(EXIT_PATH(exit_ob)&&EXIT_PATH(exit_ob)[1]=='!') 
+		{
+		  mapstruct *new_map;
+		  FILE *newmap_params;  /* give the new map its parameters */
+		  newmap_params=fopen("/tmp/rmap_params","w");
+		  if(newmap_params!=NULL) {
+			 char newmap_name[MAX_BUF];
+			 char oldmap_name[MAX_BUF];
+			 int i;
+
+			 /* write the map parameters to the file. */
+			 fprintf(newmap_params,"%s",exit_ob->msg);
+
+			 /* provide for returning to where we came from. */
+			 fprintf(newmap_params,"origin_map %s\n",op->map->path);
+			 fprintf(newmap_params,"origin_x %d\n",exit_ob->x);
+			 fprintf(newmap_params,"origin_y %d\n",exit_ob->y);
+			 /* cause there to be treasure. */
+			 fprintf(newmap_params,"generate_treasure_now 1\n");
+			 fclose(newmap_params);
+			 
+			 /* change the old map path into a single token */
+			 strcpy(oldmap_name,op->map->path);
+			 for(i=0;i<strlen(oldmap_name);i++) {
+				if(oldmap_name[i]=='/' || oldmap_name[i]=='.') oldmap_name[i]='_';
+			 }
+
+			 /* pick a new pathname for the new map:  it is of the form
+			  oldmapname_x_y with underscores instead of '/' and '.', with
+			  the entrance coordinates tacked on. */
+			 sprintf(newmap_name,"/random/%s_%d_%d",oldmap_name,exit_ob->x,exit_ob->y);
+
+			 /* now to generate the actual map. */
+			 new_map=(mapstruct *)generate_random_map("/tmp/rmap_params",newmap_name);
+			 
+			 /* set the hp,sp,path of the exit for the new */
+			 if(new_map) {
+				x=exit_ob->stats.hp = new_map->map_object->stats.hp;	
+				y=exit_ob->stats.sp = new_map->map_object->stats.sp;
+				exit_ob->slaying = add_string(newmap_name);
+			 }
+		  }
+		  else {
+			 LOG(llevError,"Couldn't open parameter-passing file for random map.");
+		  }
+		}
+	 if (EXIT_PATH(exit_ob)) {
+		newpath = normalize_path (exit_ob->map->path, EXIT_PATH(exit_ob));
+	 } else {
+		if (EXIT_LEVEL (exit_ob) > 0)
+		  LOG(llevError,"Number Map levels are no more supported\n");
+		return;
+	 }
+  } else
+	 newpath = op->contr->maplevel;
 
 
-    /* If no map path has been found yet, just keep the player on the
-     * map he is on right now
+  /* If no map path has been found yet, just keep the player on the
+	* map he is on right now
+	*/
+  if(!newpath)
+	 newpath = op->map->path;
+
+   /* If the exit is marked unique, this is a special 'apartment' map -
+    * a unique one for each player.
+    */
+
+  if (op->type==PLAYER && exit_ob && QUERY_FLAG(exit_ob, FLAG_UNIQUE)) {
+	 sprintf(apartment, "%s/%s/%s/%s", settings.localdir,
+				settings.playerdir, op->name, clean_path(newpath));
+
+	 /* If we already have a unique map for the player, use it.
+	  * Otherwise, we fall through below where
+	  * depending on values where it checks for the original map again
+	  */
+	 if (check_path(apartment,0)!= -1) {
+		newpath = apartment;
+		unique=1;
+	 }
+  }
+
+    /* If under nonstandard name, it means the map is unique 
+     * If its not unique, and it hasn't been loaded, see if the map actually
+     * exists.
      */
-    if(!newpath)
-	newpath = op->map->path;
-
-    /* If the exit is marked unique, this is a special 'apartment' map -
-     * a unique one for each player.
-     */
-    if (op->type==PLAYER && exit_ob && QUERY_FLAG(exit_ob, FLAG_UNIQUE)) {
-	sprintf(apartment, "%s/%s/%s/%s", settings.libdir,
-		settings.playerdir, op->name, clean_path(newpath));
-
-	/* If the map is in memory or the destination (already loaded then
-         * saved) map exsits, then set the path appropriately and mark
-	 * this a unique map.  Otherwise, we fall through below where
-	 * depending on values where it checks for the original map again
-	 */
-	if (has_been_loaded(apartment) && check_path(apartment,0)!= -1) {
-	    newpath = apartment;
-	    notunique=0;
-	}
+    if (check_path(newpath, 0) != - 1) {
+	unique=1;
+    } else if (!unique && !has_been_loaded(newpath) && (check_path(newpath,1)==-1)) {
+	new_draw_info_format(NDI_UNIQUE, 0,op, "The %s is closed.", newpath);
+	return;
     }
 
-    /* If notunique has been cleared, then the stuff above has already
-     * found a map, so no need to check again.  Otherwise, check
-     * to see if the actual file exists.
-     * We check to see if a unique version also exists - needed if the
-     * player saves on the unique map.
-     */
-    if (notunique && !has_been_loaded(newpath) && 
-      check_path(newpath,notunique) == -1) {
-	if (check_path(newpath, 0) == -1) {
-	    new_draw_info_format(NDI_UNIQUE, 0,op, "The %s is closed.", newpath);
-	    return;
-	}
-	else {
-	    notunique=0;
-	}
-    }
 
-    /* Clear the player's count, and reset direction */
-    op->direction=0;
-    op->contr->count=0;
-    op->contr->count_left=0;
+  /* Clear the player's count, and reset direction */
+  op->direction=0;
+  op->contr->count=0;
+  op->contr->count_left=0;
 
-    /* For exits that cause damages (like pits) */
-    if(exit_ob && exit_ob->stats.dam && op->type==PLAYER)
-       hit_player(op,exit_ob->stats.dam,exit_ob,exit_ob->attacktype);
+  /* For exits that cause damages (like pits) */
+  if(exit_ob && exit_ob->stats.dam && op->type==PLAYER)
+	 hit_player(op,exit_ob->stats.dam,exit_ob,exit_ob->attacktype);
 
-    /* Keep track of the map the player is on right now */
-    oldmap=op->map;
+  /* Keep track of the map the player is on right now */
+  oldmap=op->map;
 
 
-    /* When logging in, the object is already removed.  If that is
-     * not the case, then the following is used */
-    if(!removed) {
-	remove_ob(op);
+  /* When logging in, the object is already removed.  If that is
+	* not the case, then the following is used */
+  if(!removed) {
+	 remove_ob(op);
 
-	lastlevel = oldmap->path;
-	op->map = NULL;
+	 lastlevel = oldmap->path;
+	 op->map = NULL;
 
-	/* If we are changing maps, do some extra logic.  In theory,
-	 * if the player is going to the same map, we could do this much
-	 * simply and just update the player x,y
-	 */
-	if(strcmp (newpath, oldmap->path)) {
-	    /* Remove any golems */
-	    if(op->contr->golem) {
-		remove_friendly_object(op->contr->golem);
-		remove_ob(op->contr->golem);
-		free_object(op->contr->golem);
-		op->contr->golem=NULL;
-	    }
+	 /* If we are changing maps, do some extra logic.  In theory,
+	  * if the player is going to the same map, we could do this much
+	  * simply and just update the player x,y
+	  */
+	 if(strcmp (newpath, oldmap->path)) {
+		/* Remove any golems */
+		if(op->contr->golem) {
+		  remove_friendly_object(op->contr->golem);
+		  remove_ob(op->contr->golem);
+		  free_object(op->contr->golem);
+		  op->contr->golem=NULL;
+		}
 
-	    /* This stuff should probably be moved to ready_map: */
-	    op->map = &dummy_map;
+		/* This stuff should probably be moved to ready_map: */
+		op->map = &dummy_map;
 
 #if MAP_MAXTIMEOUT
-	    oldmap->timeout = MAP_TIMEOUT(oldmap);
-	    /* Do MINTIMEOUT first, so that MAXTIMEOUT is used if that is
-	     * lower than the min value.
-	     */
+		oldmap->timeout = MAP_TIMEOUT(oldmap);
+		/* Do MINTIMEOUT first, so that MAXTIMEOUT is used if that is
+		 * lower than the min value.
+		 */
 #if MAP_MINTIMEOUT
-	    if (oldmap->timeout < MAP_MINTIMEOUT) {
-		oldmap->timeout = MAP_MINTIMEOUT;
-	    }
+		if (oldmap->timeout < MAP_MINTIMEOUT) {
+		  oldmap->timeout = MAP_MINTIMEOUT;
+		}
 #endif
-	    if (oldmap->timeout > MAP_MAXTIMEOUT) {
-		oldmap->timeout = MAP_MAXTIMEOUT;
-	    }
-	    /* Swap out the oldest map if low on mem */
-	    swap_below_max (newpath);
+		if (oldmap->timeout > MAP_MAXTIMEOUT) {
+		  oldmap->timeout = MAP_MAXTIMEOUT;
+		}
+		/* Swap out the oldest map if low on mem */
+		swap_below_max (newpath);
 #else
-	    /* save out the map */
-	    swap_map(oldmap);
+		/* save out the map */
+		swap_map(oldmap);
 #endif /* MAP_MAXTIMEOUT */
-	}
-	oldmap->players--;
-    }
+	 }
+	 oldmap->players--;
+  }
 
-    /* Do any processing to get the map loaded and ready */
-    op->map = ready_map_name(newpath,(notunique?0:MAP_PLAYER_UNIQUE));
+  /* Do any processing to get the map loaded and ready */
+  op->map = ready_map_name(newpath,(unique?MAP_PLAYER_UNIQUE:0));
 
 
-    /* Did the load fail for some reason?  If so, put the player back on the
-     * map they came from and remove the exit that pointed the player to
-     * the bad map.
-     */
-    if (op->map==NULL) { /* Something went wrong, try to go back */
-	int x2,y2;
-	object *enc;
+  /* Did the load fail for some reason?  If so, put the player back on the
+	* map they came from and remove the exit that pointed the player to
+	* the bad map.
+	*/
+  if (op->map==NULL) { /* Something went wrong, try to go back */
+	 int x2,y2;
+	 object *enc;
 
-	LOG(llevError,"Error, couldn't open map %s.\n", newpath);
-	op->map = ready_map_name (lastlevel, 0);
-	x = last_x;
-	y = last_y;
-	LOG(llevDebug, "Trying to remove all entries to the map.\n");
+	 LOG(llevError,"Error, couldn't open map %s.\n", newpath);
+	 op->map = ready_map_name (lastlevel, 0);
+	 x = last_x;
+	 y = last_y;
+	 LOG(llevDebug, "Trying to remove all entries to the map.\n");
 
-	for (x2 = (-2); x2 < 3; x2++) {
-	    for (y2 = (-2); y2 < 3; y2++) {
-		if (out_of_map(op->map, x2 + op->x, y2 + op->y))
+	 for (x2 = (-2); x2 < 3; x2++) {
+		for (y2 = (-2); y2 < 3; y2++) {
+		  if (out_of_map(op->map, x2 + op->x, y2 + op->y))
 		    continue;
-		enc = get_map_ob(op->map, x2 + op->x, y2 + op->y);
-		if (!enc)
+		  enc = get_map_ob(op->map, x2 + op->x, y2 + op->y);
+		  if (!enc)
 		    continue;
-		if (enc->type != ENCOUNTER || enc->slaying == NULL ||
-		    strcmp(enc->slaying, newpath))
-			continue;
-		free_string(enc->slaying);
-		enc->slaying = (char *) NULL;
-	    }
-	}
-    }
-    /* If we got the map we wanted and it is UNIQUE, we need to update
-     * it so it gets saved in the right place.  Set unique so that
-     * when we save it, it knows to save it in the right place
-     */
-    else if (exit_ob && QUERY_FLAG(exit_ob, FLAG_UNIQUE)) {
-	strcpy(op->map->path, apartment);
-	SET_FLAG(op->map->map_object, FLAG_UNIQUE);
-    }
+		  if (enc->type != ENCOUNTER || enc->slaying == NULL ||
+				strcmp(enc->slaying, newpath))
+			 continue;
+		  free_string(enc->slaying);
+		  enc->slaying = (char *) NULL;
+		}
+	 }
+  }
+  /* If we got the map we wanted and it is UNIQUE, we need to update
+	* it so it gets saved in the right place.  Set unique so that
+	* when we save it, it knows to save it in the right place
+	*/
+  else if (exit_ob && QUERY_FLAG(exit_ob, FLAG_UNIQUE)) {
+	 strcpy(op->map->path, apartment);
+	 SET_FLAG(op->map->map_object, FLAG_UNIQUE);
+  }
 	    
-    op->map->players++;
+  op->map->players++;
 
-    /* If objects are being updated while the map is loading, things like
-     * pets will be put into the players map, pending element.  That is
-     * really just the dummy_map.  Since the map has actually loaded now,
-     * we want to append that list to the 'real' loaded maps pending
-     * list -- MSW
-     */
-    if(dummy_map.pending != (objectlink *) NULL) {
-	objectlink *obl;
+  /* If objects are being updated while the map is loading, things like
+	* pets will be put into the players map, pending element.  That is
+	* really just the dummy_map.  Since the map has actually loaded now,
+	* we want to append that list to the 'real' loaded maps pending
+	* list -- MSW
+	*/
+  if(dummy_map.pending != (objectlink *) NULL) {
+	 objectlink *obl;
 
-	for(obl = op->map->pending; obl!= NULL && obl->next != NULL; 
-	    obl=obl->next);
-	if(obl == NULL)
-	    op->map->pending = dummy_map.pending;
-	else
-	    obl->next = dummy_map.pending;
-    }
+	 for(obl = op->map->pending; obl!= NULL && obl->next != NULL; 
+		  obl=obl->next);
+	 if(obl == NULL)
+		op->map->pending = dummy_map.pending;
+	 else
+		obl->next = dummy_map.pending;
+  }
 
-    op->contr->loading = op->map;
-    op->contr->new_x = x;
-    op->contr->new_y = y;
-    op->contr->removed = removed;
-    op->map->timeout = 0;
+  op->contr->loading = op->map;
+  op->contr->new_x = x;
+  op->contr->new_y = y;
+  op->contr->removed = removed;
+  op->map->timeout = 0;
 
 #ifdef USE_LIGHTING
-    if(op->lights||op->glow_radius>0) remove_carried_lights(op,oldmap);
+  if(op->lights||op->glow_radius>0) remove_carried_lights(op,oldmap);
 #endif
-    enter_map(op);
+  enter_map(op);
 }
 
 /*
@@ -422,6 +461,8 @@ void enter_map(object *op) {
     int i = find_free_spot(op->arch,op->map,
                            EXIT_X(op->map->map_object),
 			   EXIT_Y(op->map->map_object),1,9);
+    /* If no free spot, put on preset destination */
+    if (i==-1) i=0;
     op->x = EXIT_X(op->map->map_object) + freearr_x[i];
     op->y = EXIT_Y(op->map->map_object) + freearr_y[i];
     if (out_of_map (op->map, op->x, op->y)) {
@@ -559,8 +600,16 @@ void process_players1(mapstruct *map)
 	     * the player is logging in.
 	     */
 	    if ((pl->last_save_tick+AUTOSAVE)<pticks && pl->state==ST_PLAYING) {
-		save_player(pl->ob,1);
-		pl->last_save_tick = pticks;
+		/* Don't save the player on unholy ground.  Instead, increase the
+		 * tick time so it will be about 10 seconds before we try and save
+		 * again.
+		 */
+		if (blocks_cleric(pl->ob->map, pl->ob->x, pl->ob->y)) {
+		    pl->last_save_tick += 100;
+		} else {
+		    save_player(pl->ob,1);
+		    pl->last_save_tick = pticks;
+		}
 	    }
 #endif
 	    if(pl->ob->speed_left>0) {
@@ -761,7 +810,7 @@ int forbid_play()
     clock = time (NULL);
     tm = (struct tm *) localtime (&clock);
 
-    sprintf (buf, "%s/%s", settings.libdir, PERM_FILE);
+    sprintf (buf, "%s/%s", settings.datadir, PERM_FILE);
     if ((fp = open_and_uncompress(buf, 0, &comp)) == NULL)
 	return 0;
 
@@ -805,6 +854,11 @@ void do_specials() {
     return;
   special_count = 0;
   special2++;
+
+#ifdef WATCHDOG
+  watchdog();
+#endif
+
   flush_old_maps();    /* Clears the tmp-files of maps which have reset */
   if(!(special2%5)) {
     fix_weight();        /* Hack to fix weightproblems caused by bugs */
