@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_move_c =
- *    "$Id: move.c,v 1.16 1998/09/28 03:30:21 master Exp master $";
+ *    "$Id: move.c,v 1.19 1999/03/20 06:46:08 master Exp $";
  */
 
 /*
@@ -129,14 +129,13 @@ int move_ob(object *op,int dir) {
   }
   op->x+=freearr_x[dir],op->y+=freearr_y[dir];  /* Move this object */
 
-  esrv_map_scroll(&op->contr->socket, freearr_x[dir],freearr_y[dir]);
-
   /* If head of object (or single part object), reinsert into map. */
   if(op->head==NULL)
     insert_ob_in_map(op,op->map);
 
   if (op->type==PLAYER) {
-    draw_look(op);
+    esrv_map_scroll(&op->contr->socket, freearr_x[dir],freearr_y[dir]);
+    op->contr->socket.update_look=1;
   }
   return 1;
 }
@@ -188,8 +187,9 @@ void teleport(object *teleporter,unsigned char tele_type) {
     return;
   }
   other_teleporter=altern[RANDOM()%nrofalt];
-  if(!(k=find_free_spot(teleported->arch,other_teleporter->map,
-                        other_teleporter->x,other_teleporter->y,1,9)))
+  k=find_free_spot(teleported->arch,other_teleporter->map,
+                        other_teleporter->x,other_teleporter->y,1,9);
+  if (k==-1)
     return;
   remove_ob(teleported);
   for(tmp=teleported;tmp!=NULL;tmp=tmp->more)
