@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_player_c =
- *   "$Id: player.c,v 1.72 1998/09/28 03:33:37 master Exp master $";
+ *   "$Id: player.c,v 1.89 1999/06/22 05:40:28 master Exp $";
  */
 
 /*
@@ -45,7 +45,7 @@ void display_motd(object *op) {
   FILE *fp;
   int comp;
 
-  sprintf(buf,"%s/%s",settings.libdir,MOTD);
+  sprintf(buf,"%s/%s",settings.datadir,MOTD);
   if((fp=open_and_uncompress(buf,0,&comp))==NULL) {
     return;
   }
@@ -122,8 +122,7 @@ int add_player(NewSocket *ns) {
 #ifdef MOTD
     display_motd(p->ob);
 #endif
-    p->peaceful=0;
-    p->berzerk=0;
+    p->peaceful=1;
     p->own_title[0]='\0';
     get_name(p->ob);
     return 0;
@@ -168,6 +167,8 @@ object *get_player(player *p, mapstruct *m) {
     } else {
 	i=find_free_spot(NULL,m,EXIT_X(m->map_object),EXIT_Y(m->map_object),
 			 0,SIZEOFFREE);
+	/* If no free spot, just stuff the player wherever it says */
+	if (i==-1) i=0;
 	op->x=EXIT_X(m->map_object)+freearr_x[i];
 	op->y=EXIT_Y(m->map_object)+freearr_y[i];
     }
@@ -177,7 +178,6 @@ object *get_player(player *p, mapstruct *m) {
     p->prev_cmd=' ';
     p->prev_fire_on=0;
     p->mode=0;
-    p->berzerk=1;
     p->idle=0;
 #ifdef AUTOSAVE
     p->last_save_tick = 9999999;
@@ -228,8 +228,8 @@ object *get_player(player *p, mapstruct *m) {
 #endif
     if(QUERY_FLAG(op,FLAG_READY_SKILL))
         CLEAR_FLAG(op,FLAG_READY_SKILL); 
-  draw_look(op);
-  return op;
+    p->socket.update_look=0;
+    return op;
 }
 
 object *get_nearest_player(object *mon) {
@@ -405,6 +405,9 @@ int receive_play_again(object *op, char key)
 	op->type=DEAD_OBJECT;
 	free_object(op);
 	op=tmp;
+    } else {
+	/* user pressed something else so just ask again... */
+	play_again(op);
     }
     return 0;
 }
@@ -666,7 +669,7 @@ int key_change_class(object *op, char key)
 	/* We create this now because some of the unique maps will need it
 	 * to save here.
 	 */
-	sprintf(buf,"%s/%s/%s",settings.libdir,settings.playerdir,op->name);
+	sprintf(buf,"%s/%s/%s",settings.localdir,settings.playerdir,op->name);
 	make_path_to_file(buf);
 
 #ifdef AUTOSAVE
@@ -747,7 +750,7 @@ int key_confirm_quit(object *op, char key)
     op->contr->own_title[0]='\0';
 #endif /* SET_TITLE */
     if(!QUERY_FLAG(op,FLAG_WAS_WIZ)) {
-      sprintf(buf,"%s/%s/%s/%s.pl",settings.libdir,settings.playerdir,op->name,op->name);
+      sprintf(buf,"%s/%s/%s/%s.pl",settings.localdir,settings.playerdir,op->name,op->name);
       if(unlink(buf)== -1 && settings.debug)
         perror("crossfire (delete character)");
     }
@@ -793,7 +796,6 @@ void flee_player(object *op) {
  * stop.
  */
 int check_pick(object *op) {
-  int item_picked=0;		/* set to true if an item is picked up */
 
   if(QUERY_FLAG(op,FLAG_FLYING) || op->below==NULL || !can_pick(op,op->below))
     return 1;
@@ -808,7 +810,6 @@ int check_pick(object *op) {
 	  next=tmp->below;
 	  if(item_matched_string(op, tmp, op->contr->search_str)) {
 	    pick_up(op,tmp);
-	    item_picked=1;
 	  }
 	  tmp=next;
 	}
@@ -833,32 +834,29 @@ int check_pick(object *op) {
 	case 5: 
 	case 6:
 	case 7: {
-		object *item,*temp;
-
-		item = op->below;
-		while (item) {
-		    temp = item->below;
-		    if (can_pick(op, item)) {
+	    object *item,*temp;
+	    
+	    for (item = op->below; item; item=temp) {
+		temp = item->below;
+		if (can_pick(op, item)) {
 			if (op->contr->mode==6) {
-			    if (QUERY_FLAG(item, FLAG_KNOWN_MAGICAL) &&
+			    if (is_magical(item) &&
 			      !QUERY_FLAG(item, FLAG_KNOWN_CURSED)) {
 				pick_up(op, item);
-				item_picked=1;
 			    }
 			}
 			else if (op->contr->mode==7) {
 			    if (item->type==MONEY || item->type==GEM) {
-				item_picked=1;
 				pick_up(op, item);
 			    }
 			} else {
-			    item_picked=1;
 			    pick_up(op, item);
 			}
-		    }
-		    item = temp;
 		}
-		return (op->contr->mode != 4 ? 1 : 0);
+		    item = temp;
+	    }
+	    if (op->contr->mode == 5) return 0;
+	    else return 1;
 	}
 
 	/* use value density */
@@ -871,7 +869,6 @@ int check_pick(object *op) {
 		if(can_pick(op, item) && !(QUERY_FLAG(item, FLAG_UNPAID)) &&
 		 (query_cost(item,op,F_TRUE)*100/
 		    (item->weight * MAX(item->nrof,1))>= op->contr->mode) ) {
-			item_picked=1;
 			pick_up(op,item);
 		}
 		item=temp;
@@ -1196,15 +1193,10 @@ void move_player_attack(object *op, int dir)
      */
 
     if(tmp->type==LOCKED_DOOR) {
-#if 0
-      tmp2=op->inv;
-      while(tmp2 && (tmp2->type != SPECIAL_KEY ||
-	    tmp2->slaying != tmp->slaying)) /* Find the key */
-	tmp2=tmp2->below;
-#else
       tmp2=FindKey(tmp,op->inv);
-#endif
       if(tmp2) {
+	  new_draw_info_format(NDI_UNIQUE, NDI_BROWN, op, 
+	       "You open the door with the %s", query_short_name(tmp2));
 	  decrease_ob_nr(tmp2, 1); /* Use the key */
 	  remove_door2(tmp); /* remove door without violence ;-) */
 	  play_sound_map(op->map, op->x, op->y, SOUND_OPEN_DOOR);
@@ -1221,6 +1213,21 @@ void move_player_attack(object *op, int dir)
      * and thus will not push them.
      */
 
+    /* If the creature is a pet, push it even if the player is not
+     * peaceful.  Our assumption is the creature is a pet if the
+     * player owns it and it is either friendly or unagressive.
+     */
+    if ((op->type==PLAYER) && get_owner(tmp)==op && 
+	(QUERY_FLAG(tmp,FLAG_UNAGGRESSIVE) ||  QUERY_FLAG(tmp, FLAG_FRIENDLY)))
+    {
+	/* If we're braced, we don't want to switch places with it */
+	if (op->contr->braced) return;
+	play_sound_map(op->map, op->x, op->y, SOUND_PUSH_PLAYER);
+	(void) push_ob(tmp,dir,op);
+	if(op->contr->tmp_invis||op->hide) make_visible(op);
+	return;
+    }
+
     if ((tmp->type==PLAYER || tmp->enemy != op) &&
       (tmp->type==PLAYER || QUERY_FLAG(tmp,FLAG_UNAGGRESSIVE)
 	|| QUERY_FLAG(tmp, FLAG_FRIENDLY)) &&
@@ -1277,36 +1284,38 @@ void move_player_attack(object *op, int dir)
 }
 
 int move_player(object *op,int dir) {
-  int face = dir ? (dir - 1) / 2 : -1;
+    int face = dir ? (dir - 1) / 2 : -1, pick;
+
+    if(op->map == NULL || op->map->in_memory != MAP_IN_MEMORY)
+	return 0;
+
+    /* peterm:  added following line */
+    op->facing = dir;
+    if(QUERY_FLAG(op,FLAG_CONFUSED) && dir)
+	dir = absdir(dir + RANDOM()%3 + RANDOM()%3 - 2);
+
+    if(op->hide) do_hidden_move(op);
+
+    if(op->contr->fire_on) {
+	fire(op,dir);
+    }
+    else move_player_attack(op,dir);
+
+    /* Add special check for newcs players and fire on - this way, the
+     * server can handle repeat firing.
+     */
+    pick = check_pick(op); 
+    if (op->contr->fire_on || (op->contr->run_on && pick!=0)) {
+	op->direction = dir;
+    } else {
+	op->direction=0;
+    }
+
+    if(face != -1)
+	SET_ANIMATION(op,face);
+    update_object(op);
 
-  if(op->map == NULL || op->map->in_memory != MAP_IN_MEMORY)
     return 0;
-
-  /* peterm:  added following line */
-  op->facing = dir;
-  if(QUERY_FLAG(op,FLAG_CONFUSED) && dir)
-    dir = absdir(dir + RANDOM()%3 + RANDOM()%3 - 2);
-
-  if(op->hide) do_hidden_move(op);
-
-  if(op->contr->fire_on) {
-    fire(op,dir);
-  }
-  else move_player_attack(op,dir);
-
-  /* Add special check for newcs players and fire on - this way, the
-   * server can handle repeat firing.
-   */
-  if((check_pick(op)&&op->contr->run_on)||
-     (op->contr->berzerk&&op->contr->run_on) ||
-     (op->contr->fire_on))
-    op->direction=dir;
-  else
-    op->direction=0;
-  if(face != -1)
-    SET_ANIMATION(op,face);
-  update_object(op);
-  return 0;
 }
 
 /* This is similar to handle_player, below, but is only used by the
@@ -1330,13 +1339,6 @@ int handle_newcs_player(object *op)
 	op->invisible--;
 	if(!op->invisible) make_visible(op);
     }
-#if 0
-    /* Moved to process_players2 */
-    /* This should really be called after we move, since somethings
-     * could actually damage us.
-     */
-    esrv_update_stats(&op->contr->socket,op);
-#endif
     /* call this here - we also will call this in do_ericserver, but
      * the players time has been increased when doericserver has been
      * called, so we recheck it here.
@@ -1344,10 +1346,6 @@ int handle_newcs_player(object *op)
     HandleClient(&op->contr->socket, op->contr);
     if (op->speed_left<0) return 0;
 
-#if 0
-    fprintf(stderr,"dir=%d, runon=%d, fireon=%d\n", op->direction,
-	    op->contr->run_on, op->contr->fire_on);
-#endif
     if(op->direction && (op->contr->run_on || op->contr->fire_on)) {
 	/* All move commands take 1 tick, at least for now */
 	op->speed_left--;
@@ -1356,103 +1354,12 @@ int handle_newcs_player(object *op)
 	 * there, as well as the confusion stuff.
 	 */
 	move_player(op, op->direction);
-#if 0
-	if(op->contr->berzerk&&(op->contr->braced||(!op->contr->fire_on)))
-	    move_player(op,op->direction);
-	else if((!move_ob(op,op->direction) && !op->contr->run_on)
-		||!check_pick(op))
-	    op->direction=0;
-#endif
 	if (op->speed_left>0) return 1;
 	else return 0;
     }
     return 0;
 }
 
-object *esrv_get_ob_from_count(object *pl, long count)
-{
-    object *op, *tmp;
-
-    if (pl->count == count)
-	return pl;
-
-    for(op = pl->inv; op; op = op->below)
-	if (op->count == count)
-	    return op;
-	else if (op->type == CONTAINER && pl->container == op)
-	    for(tmp = op->inv; tmp; tmp = tmp->below)
-		if (tmp->count == count)
-		    return tmp;
-
-    for(op = get_map_ob (pl->map, pl->x, pl->y); op; op = op->above)
-	if (op->count == count)
-	    return op;
-	else if (op->type == CONTAINER && pl->container == op)
-	    for(tmp = op->inv; tmp; tmp = tmp->below)
-		if (tmp->count == count)
-		    return tmp;
-    return NULL;
-}
-
-void esrv_examine_object (object *pl, long tag)
-{
-    object *op = esrv_get_ob_from_count(pl, tag);
-
-    if (!op) {
-      LOG(llevDebug, "Player '%s' tried examine the unknown object (%d)\n",
-	  pl->name, tag);
-      return;
-    }
-    examine (pl, op);
-}
-
-void esrv_apply_object (object *pl, long tag)
-{
-    object *op = esrv_get_ob_from_count(pl, tag);
-
-    if (!op) {
-      LOG(llevDebug, "Player '%s' tried apply the unknown object (%d)\n",
-	  pl->name, tag);
-      return;
-    }
-    apply (pl, op,0);
-}
-
-void esrv_move_object (object *pl, long to, long tag, long nrof)
-{
-    object *op, *env;
-
-    printf ("esrv_move_object:\n");
-    printf ("Trying to locate object %ld from player %s.\n", tag, pl->name);
-    op = esrv_get_ob_from_count(pl, tag);
-    if (!op) {
-      LOG(llevDebug, "Player '%s' tried to move the unknown object (%ld)\n",
-	  pl->name, tag);
-      return;
-    }
-    printf ("and the object was '%s'.\n", op->name);
-
-    if (!to) {	/* drop it to the ground */
-	printf ("Drop it on the ground.\n");
-      drop_object (pl, op, nrof);
-      return;
-    } else if (to == pl->count) {     /* pick it up to the inventory */
-      pick_up_object (pl, pl, op, nrof);
-      return ;
-    }
-    /* If not dropped or picked up, we are putting it into a sack */
-    env = esrv_get_ob_from_count(pl, to);
-    if (!env) {
-      LOG(llevDebug, 
-	  "Player '%s' tried to move object to the unknown location (%d)\n",
-	  pl->name, to);
-      return;
-    }
-    printf ("Sacks name was '%s'.\n", env->name);
-    put_object_in_sack (pl, env, op, nrof);
-}
-
-
 int save_life(object *op) {
   object *tmp;
   char buf[MAX_BUF];
@@ -1464,6 +1371,8 @@ int save_life(object *op) {
       sprintf(buf,"Your %s vibrates violently, then evaporates.",
 	      query_name(tmp));
       new_draw_info(NDI_UNIQUE, 0,op,buf);
+      if (op->contr) 
+	esrv_del_item(op->contr, tmp->count);
       remove_ob(tmp);
       free_object(tmp);
       CLEAR_FLAG(op, FLAG_LIFESAVE);
@@ -1624,18 +1533,32 @@ void do_some_living(object *op) {
 /*                                                                          */
 /****************************************************************************/
 
- /**************************************/
- /*                                    */
- /* Pick a stat, and steal on pt from  */
- /* it...                              */
- /*                                    */
- /**************************************/
-    i = RANDOM() % 7;
-    change_attr_value(&(op->stats), i,-1);
-    check_stat_bounds(&(op->stats));
-    change_attr_value(&(op->contr->orig_stats), i,-1);
-    check_stat_bounds(&(op->contr->orig_stats));
-    new_draw_info(NDI_UNIQUE, 0,op, lose_msg[i]);
+    if (settings.stat_loss_on_death) {
+	/* Pick a random stat and take a point off it.  Tell the player
+	 * what he lost.
+	 */
+	i = RANDOM() % 7; 
+	change_attr_value(&(op->stats), i,-1);
+	check_stat_bounds(&(op->stats));
+	change_attr_value(&(op->contr->orig_stats), i,-1);
+	check_stat_bounds(&(op->contr->orig_stats));
+	new_draw_info(NDI_UNIQUE, 0,op, lose_msg[i]);
+    } else {
+	    /* deplete a stat */
+	archetype *deparch=find_archetype("depletion");
+	object *dep;
+
+	i = RANDOM() % 7;
+	dep = present_arch_in_ob(deparch,op);
+	if(!dep) {
+	    dep = arch_to_object(deparch);
+	    insert_ob_in_ob(dep, op);
+	}
+	change_attr_value(&(dep->stats), i,-1);
+	SET_FLAG(dep, FLAG_APPLIED);
+	new_draw_info(NDI_UNIQUE, 0,op, lose_msg[i]);
+	fix_player(op);
+    }
 
 
  /**************************************/
@@ -1669,6 +1592,7 @@ void do_some_living(object *op) {
     /* remove any poisoning and confusion the character may be suffering. */
     cast_heal(op, 0, SP_CURE_POISON);
     cast_heal(op, 0, SP_CURE_CONFUSION);
+	 cure_disease(op,0);  /* remove any disease */
 	
     add_exp(op, (op->stats.exp * -0.20));
     if(op->stats.food < 0) op->stats.food = 500;
@@ -1828,6 +1752,10 @@ void fix_weight() {
     if(old == sum)
       continue;
     fix_player(pl->ob);
+    /* This will cause a warning when the player first logs in because
+     * we haven't sent the player object yet.  No clean way around it,
+     * and not a big deal, as it only happens once during login.
+     */
     esrv_update_item(UPD_WEIGHT, pl->ob, pl->ob);
     LOG(llevDebug,"Fixed inventory in %s (%d -> %d)\n",
 	pl->ob->name, old, sum);
