@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_rune_c =
- *   "$Id: rune.c,v 1.19 1998/05/16 02:52:54 master Exp $";
+ *   "$Id: rune.c,v 1.20 1999/01/23 09:57:40 master Exp $";
  */
 
 /*
@@ -189,8 +189,19 @@ void move_rune(object *op) {
 
 void rune_attack(object *op,object *victim)
 {
-  if(victim)  hit_player(victim,op->stats.dam,op,op->attacktype);
+  if(victim) {
+	 hit_player(victim,op->stats.dam,op,op->attacktype);
+	 /*  if there's a disease in the needle, put it in the player */
+	 if(op->randomitems!=NULL) create_treasure(op->randomitems,op,GT_INVENTORY,
+															 victim->map->difficulty,0);
+	 if(op->inv) {
+		object *disease=op->inv;
+		remove_ob(op->inv);
+		insert_ob_in_ob(disease,victim);
+	 }
+  }
    else  hit_map(op,0,op->attacktype);
+ 
 }
 
 /*  This function generalizes attacks by runes/traps.  This ought to make
