@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_shop_c =
- *   "$Id: shop.c,v 1.37 1998/09/28 03:42:03 master Exp master $";
+ *   "$Id: shop.c,v 1.39 1999/03/23 07:26:40 master Exp $";
  */
 
 /*
@@ -296,7 +296,7 @@ int query_money(object *op) {
 int pay_for_item(object *op,object *pl) {
     int item_cost=query_cost(op,pl,F_BUY),i, count;
     int to_pay;
-    object *tmp, *coin_objs[NUM_COINS];
+    object *tmp, *coin_objs[NUM_COINS], *next;
     archetype *at;
 
     if (item_cost==0) return 1;
@@ -309,31 +309,36 @@ int pay_for_item(object *op,object *pl) {
     }
 
     /* This hunk should remove all the money objects from the player */
-    while ((tmp=present_in_ob(MONEY, pl))!=NULL) {
-        for (i=0; i<NUM_COINS; i++) {
-	    if (!strcmp(coins[NUM_COINS-1-i], tmp->arch->name)) {
+    for (tmp=pl->inv; tmp; tmp=next) {
+	next = tmp->below;
 
-		/* This should not happen, but if it does, just
-		 * merge the two.
-		 */
-		if (coin_objs[i]!=NULL) {
-		    LOG(llevError,"%s has two money entries of (%s)\n",
-			pl->name, coins[NUM_COINS-1-i]);
-		    remove_ob(tmp);
-		    coin_objs[i]->nrof += tmp->nrof;
-		    esrv_del_item(pl->contr, tmp->count);
-		    free_object(tmp);
+	if (tmp->type == MONEY) {
+	    for (i=0; i<NUM_COINS; i++) {
+		if (!strcmp(coins[NUM_COINS-1-i], tmp->arch->name) &&
+		    (tmp->value == tmp->arch->clone.value) ) {
+
+		    /* This should not happen, but if it does, just
+		     * merge the two.
+		     */
+		    if (coin_objs[i]!=NULL) {
+			LOG(llevError,"%s has two money entries of (%s)\n",
+			    pl->name, coins[NUM_COINS-1-i]);
+			remove_ob(tmp);
+			coin_objs[i]->nrof += tmp->nrof;
+			esrv_del_item(pl->contr, tmp->count);
+			free_object(tmp);
+		    }
+		    else {
+			remove_ob(tmp);
+			esrv_del_item(pl->contr, tmp->count);
+			coin_objs[i] = tmp;
+		    }
+		    break;
 		}
-		else {
-		    remove_ob(tmp);
-		    esrv_del_item(pl->contr, tmp->count);
-		    coin_objs[i] = tmp;
-		}
-		break;
 	    }
+	    if (i==NUM_COINS)
+		LOG(llevError,"in pay_for_item: Did not find string match for %s\n", tmp->arch->name);
 	}
-	if (i==NUM_COINS)
-	    LOG(llevError,"in pay_for_item: Did not find string match for %s\n", tmp->arch->name);
     }
 
     /* Fill in any gaps in the coin_objs array - needed to make change. */
