@@ -186,9 +186,9 @@ int do_skill (object *op, int dir, char *string) {
  */
 
 int calc_skill_exp(object *who, object *op) {
-  int who_lvl= SK_level(who);
-  int sk,op_exp=0,op_lvl= 0;
-  float base,value,stat_mult=1.0,lvl_mult=0.0;
+    int who_lvl= SK_level(who);
+    int sk,op_exp=0,op_lvl= 0;
+    float base,value,stat_mult=1.0,lvl_mult=0.0;
 
     /* sometimes we dont have a specific opponent to 'overcome'.
      * 'hiding' is just such a case. For these skills, our
@@ -271,8 +271,10 @@ int calc_skill_exp(object *who, object *op) {
  */
  
 float calc_stat_mult(object *who,int sk) {
-  int sum;
-  float factor = 1.0;
+    int sum;
+    float factor = 1.0;
+
+    if (settings.simple_exp) return 1.0;
          
     sum = get_weighted_skill_stat_sum (who,sk);
  
@@ -478,7 +480,7 @@ void read_skill_params () {
   int cat,bexp,time,stat1,stat2,stat3,skillindex;
   float lexp;
  
-  sprintf(fname,"%s/%s",settings.libdir,"skill_params");
+  sprintf(fname,"%s/%s",settings.datadir,"skill_params");
   LOG(llevDebug,"Reading skill_params from %s...",fname);
   if(! (skill_params=fopen(fname,"r")))
     {
@@ -987,7 +989,7 @@ void show_skills(object *op) {
       return;
   } else {
 #endif
-      length = INFOCHARS-19;
+      length = 31;
       in = "";
       if (op)
         clear_win_info(op);
@@ -1074,7 +1076,7 @@ int use_skill(object *op, char *string) {
 	if (sknum==-1) {
 	    new_draw_info_format(NDI_UNIQUE, 0, op, 
 		 "Unable to find skill by name %s", string);
-	    return;
+	    return 0;
 	}
 
 	len=strlen(skills[sknum].name);
@@ -1302,7 +1304,7 @@ int do_skill_attack(object *tmp, object *op, char *string) {
     int success; 
     object *pskill = op->chosen_skill;
     char buf[MAX_BUF], *name = query_name(tmp);
-    char *attack_hth_skill[] = {"skill_karate",	"skill_clawing",
+    static char *attack_hth_skill[] = {"skill_karate",	"skill_clawing",
 	"skill_flame_touch", "skill_punching", NULL };
  
    /* For Players only: if there is no ready weapon, and no "attack" skill
