@@ -276,11 +276,16 @@ int pick_lock(object *pl, int dir)
       if(!tmp) continue;
       switch(tmp->type) { 
         case DOOR:
-            if (attempt_pick_lock(tmp, pl)) { 
-		success = 1;
-                sprintf(buf, "you pick the lock.");
-            } else 
-                sprintf(buf, "you fail to pick the lock.");
+	    if (!QUERY_FLAG(tmp, FLAG_NO_PASS)) {
+		strcpy(buf,"The door has no lock!");
+	    } else {
+		if (attempt_pick_lock(tmp, pl)) { 
+		    success = 1;
+		    sprintf(buf, "you pick the lock.");
+		} else {
+		    sprintf(buf, "you fail to pick the lock.");
+		}
+	    }
 	    break;
         case LOCKED_DOOR: 
             sprintf(buf, "you can't pick that lock!");
@@ -659,73 +664,88 @@ int do_skill_ident(object *pl, int obj_class) {
  */
 
 int use_oratory(object *pl, int dir) {
-  int expsum=0,x=pl->x+freearr_x[dir],y=pl->y+freearr_y[dir],chance;
-  int stat1 = get_skill_stat1(pl);
-  object *tmp;
+    int x=pl->x+freearr_x[dir],y=pl->y+freearr_y[dir],chance;
+    int stat1 = get_skill_stat1(pl);
+    object *tmp;
  
-	if(pl->type!=PLAYER) return 0;	/* only players use this skill */ 
-	if(out_of_map(pl->map,x,y)) return 0;
+    if(pl->type!=PLAYER) return 0;	/* only players use this skill */ 
+    if(out_of_map(pl->map,x,y)) return 0;
 
-        for(tmp=get_map_ob(pl->map,x,y);tmp;tmp=tmp->above) { 
-        	if(!tmp) return 0;
-		if(!QUERY_FLAG(tmp,FLAG_MONSTER)) continue; 
-        	if(tmp->type==PLAYER) continue;	      /* can't persude players! */ 
+    for(tmp=get_map_ob(pl->map,x,y);tmp;tmp=tmp->above) { 
+       	if(!tmp) return 0;
+	if(!QUERY_FLAG(tmp,FLAG_MONSTER)) continue; 
+        /* can't persude players - return because there is nothing else
+	 * on that space to charm.  Same for multi space monsters and
+	 * special monsters - we don't allow them to be charmed, and there
+	 * is no reason to do further processing since they should be the
+	 * only monster on the space.
+	 */ 
+       	if(tmp->type==PLAYER) return 0;
+       	if(tmp->more || tmp->head) return 0;
+	if(tmp->msg) return 0;
 
-                new_draw_info_format(NDI_UNIQUE, 
+
+	new_draw_info_format(NDI_UNIQUE, 
 			0,pl, "You orate to the %s.",query_name(tmp));
 
 	/* the following conditions limit who may be 'charmed' */
 
-		if(!QUERY_FLAG(tmp,FLAG_UNAGGRESSIVE) &&   /* it's hostile! */ 
-			!QUERY_FLAG(tmp, FLAG_FRIENDLY)) {  
-                        new_draw_info_format(NDI_UNIQUE, 0,pl, 
+	/* it's hostile! */ 
+	if(!QUERY_FLAG(tmp,FLAG_UNAGGRESSIVE) && !QUERY_FLAG(tmp, FLAG_FRIENDLY)) {  
+               new_draw_info_format(NDI_UNIQUE, 0,pl, 
 			   "Too bad the %s isn't listening!\n",query_name(tmp));
-			return 0;	
-		}
-    	   /* it's already allied! */ 
-                if(QUERY_FLAG(tmp,FLAG_FRIENDLY)&&(tmp->move_type==PETMOVE)){  
-			if(get_owner(tmp)==pl) {
-                           new_draw_info(NDI_UNIQUE, 0,pl, 
-                             "Your follower loves your speach.\n");
-			   return 0;
-		 	} else if(SK_level(pl)>tmp->level) { /* you steal the follower! */
-		   	   set_owner(tmp,pl);	
-                           new_draw_info_format(NDI_UNIQUE, 0,pl, 
-                             "You convince the %s to follow you instead!\n"
-			     ,query_name(tmp));
-			   return calc_skill_exp(pl,tmp);
-			}
-                } 
-
-        	if(tmp->more || tmp->head) continue;  /* no multiple square monsters*/
-		if(tmp->msg) continue; 	            /* no special message monsters */
-
-		chance=SK_level(pl)*2+(stat1-2*tmp->stats.Int)/2;
-	/* Ok, got a 'sucker' lets try to make them a follower */
-        	if(chance && tmp->level<(RANDOM()%chance)) {
-                        new_draw_info_format(NDI_UNIQUE, 0,pl, 
-			  "You convince the %s to become your follower.\n"
-			  ,query_name(tmp));
-       			set_owner(tmp,pl);
-        		SET_FLAG(tmp,FLAG_MONSTER);
-        		tmp->stats.exp = 0;
-          	        add_friendly_object(tmp);
-        		SET_FLAG(tmp,FLAG_FRIENDLY);
-        		tmp->move_type = PETMOVE;
- 			expsum += calc_skill_exp(pl,tmp);
-		}
-	/* maybe we made it angry */ 
-        	else if((SK_level(pl)+((stat1-10)/2))<RANDOM()%((2*tmp->level)+1)) { 
-                        new_draw_info_format(NDI_UNIQUE, 0,pl, 
-			  "Your speach angers the %s!\n",query_name(tmp)); 
-        		if(QUERY_FLAG(tmp,FLAG_FRIENDLY)) {
-        			CLEAR_FLAG(tmp,FLAG_FRIENDLY);
-        			tmp->move_type = 0; 	/* needed? */ 
-			}
-        		CLEAR_FLAG(tmp,FLAG_UNAGGRESSIVE);
-		}
+		return 0;	
 	}
-	return expsum;
+	/* it's already allied! */ 
+        if(QUERY_FLAG(tmp,FLAG_FRIENDLY)&&(tmp->move_type==PETMOVE)){  
+	    if(get_owner(tmp)==pl) {
+		new_draw_info(NDI_UNIQUE, 0,pl, 
+			      "Your follower loves your speach.\n");
+		return 0;
+	    } else if(SK_level(pl)>tmp->level) { /* you steal the follower! */
+	   	set_owner(tmp,pl);	
+                new_draw_info_format(NDI_UNIQUE, 0,pl, 
+			"You convince the %s to follow you instead!\n",
+			query_name(tmp));
+#if 0
+		return calc_skill_exp(pl,tmp);
+#else
+		/* Abuse fix - don't give exp since this can otherwise
+		 * be used by a couple players to gets lots of exp.
+		 */
+		return 0;
+#endif
+	    }
+	} /* Creature was already a pet of someone */
+
+	chance=SK_level(pl)*2+(stat1-2*tmp->stats.Int)/2;
+
+	/* Ok, got a 'sucker' lets try to make them a follower */
+       	if(chance && tmp->level<(RANDOM()%chance)) {
+	    new_draw_info_format(NDI_UNIQUE, 0,pl, 
+		"You convince the %s to become your follower.\n", 
+		query_name(tmp));
+
+	    set_owner(tmp,pl);
+	    SET_FLAG(tmp,FLAG_MONSTER);
+	    tmp->stats.exp = 0;
+	    add_friendly_object(tmp);
+	    SET_FLAG(tmp,FLAG_FRIENDLY);
+	    tmp->move_type = PETMOVE;
+	    return calc_skill_exp(pl,tmp);
+	}
+	/* Charm failed.  Creature may be angry now */
+       	else if((SK_level(pl)+((stat1-10)/2))<RANDOM()%((2*tmp->level)+1)) { 
+	    new_draw_info_format(NDI_UNIQUE, 0,pl, 
+		  "Your speach angers the %s!\n",query_name(tmp)); 
+	    if(QUERY_FLAG(tmp,FLAG_FRIENDLY)) {
+		CLEAR_FLAG(tmp,FLAG_FRIENDLY);
+		tmp->move_type = 0; 	/* needed? */ 
+	    }
+	    CLEAR_FLAG(tmp,FLAG_UNAGGRESSIVE);
+	}
+    } /* For loop cyclign through the objects on this space */
+    return 0;	/* Fall through - if we get here, we didn't charm anything */
 }
 
 /* Singing() -this skill allows the player to pacify nearby creatures.
