@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_newspells_c =
- *   "$Id: spell_effect.c,v 1.26 1998/09/28 04:01:55 master Exp master $";
+ *   "$Id: spell_effect.c,v 1.32 1999/03/20 06:50:46 master Exp $";
  */
 
 
@@ -42,6 +42,10 @@ extern object *objects;
  * of failure badness.
  */
 #ifdef SPELL_FAILURE_EFFECTS
+
+/* Might be a better way to do this, but this should work */
+#define ISQRT(val) ((int)sqrt((double) val))
+
 void spell_failure(object *op, int failure,int power)
 {  
     if(failure<= -20&&failure > -40) /* wonder */
@@ -1039,6 +1043,10 @@ cast_heal(object *op,int dir,int spell_type) {
 
   if(tmp==NULL) return 0;
   switch(spell_type) {
+  case SP_CURE_DISEASE:
+	 heal = 0;
+	 cure_disease(tmp,op);
+	 break;
   case SP_MINOR_HEAL:
     heal=(RANDOM()%7)+1;
     new_draw_info(NDI_UNIQUE, 0,tmp, "Your wounds start to close.");
@@ -1083,6 +1091,7 @@ cast_heal(object *op,int dir,int spell_type) {
   case SP_RESTORATION:  /* does cure poison, cure madness, heal,and removes depletion, food=999. */
     cast_heal(op,dir,SP_CURE_POISON);
     cast_heal(op,dir,SP_CURE_CONFUSION);
+	 cast_heal(op,dir,SP_CURE_DISEASE);
     tmp->stats.food=999;
 #if 0
     /* Leave removing depletion to the restore potion. */
@@ -1100,6 +1109,7 @@ cast_heal(object *op,int dir,int spell_type) {
 				    as a side effect. */
     return 1;
   }
+  reduce_symptoms(tmp,heal);
   if (tmp->stats.hp==tmp->stats.maxhp)
     return 0;
   tmp->stats.hp+=heal;
@@ -1420,7 +1430,7 @@ int summon_pet(object *op, int dir, SpellTypeFrom item) {
   }
   if (!dir)
     dir = find_free_spot(at, op->map, op->x, op->y, 1, SIZEOFFREE);
-  if(arch_blocked(at,op->map, op->x + freearr_x[dir], op->y+freearr_y[dir]))
+  if((dir==-1) || arch_blocked(at,op->map, op->x + freearr_x[dir], op->y+freearr_y[dir]))
   {
     new_draw_info(NDI_UNIQUE, 0,op, "There is something in the way.");
     if(op->type == PLAYER)
@@ -1543,21 +1553,30 @@ void animate_bomb(object *op) {
 
 
 int fire_cancellation(object *op,int dir,archetype *at, int magic) {
-  object *tmp;
-  if(at==NULL)
-    return 0;
-  tmp=arch_to_object(at);
-  if(tmp==NULL)
-    return 0;
-  tmp->x=op->x,tmp->y=op->y;
-  tmp->direction=dir;
-  if(magic)
-    tmp->attacktype|=AT_MAGIC;
-  set_owner(tmp,op);
-  if(op->type==PLAYER)
-  insert_ob_in_map(tmp,op->map);
-  move_cancellation(tmp);
-  return 1;
+    object *tmp;
+
+    if(at==NULL)
+	return 0;
+
+    tmp=arch_to_object(at);
+
+    if(tmp==NULL)
+	return 0;
+
+    tmp->x=op->x,tmp->y=op->y;
+    tmp->direction=dir;
+    if(magic)
+	tmp->attacktype|=AT_MAGIC;
+
+    if(op->type==PLAYER)
+	set_owner(tmp,op);
+
+    insert_ob_in_map(tmp,op->map);
+
+    /* It is possible that the object got destroyed by the insert above */
+    if (!QUERY_FLAG(tmp, FLAG_FREED))
+	move_cancellation(tmp);
+    return 1;
 }
 
 void move_cancellation(object *op) {
@@ -2165,70 +2184,86 @@ int summon_fog(object *op, object *caster,int dir,int spellnum) {
 
 int create_the_feature(object *op, object *caster,int dir, int spell_effect)
 {
-  object *tmp=NULL;
-  char buf1[20];
-  int putflag=0;
-  if(!dir) dir=op->facing; else putflag=1;
-  switch(spell_effect) {
-    case SP_BUILD_DIRECTOR:
-  	sprintf(buf1,"director_%d",dir);
-	tmp=get_archetype(buf1);
-	SET_FLAG(tmp, FLAG_IS_USED_UP);
-        tmp->stats.food=SP_PARAMETERS[spell_effect].bdur+10*SP_level_strength_adjust(op,caster,spell_effect);
-        tmp->stats.hp=SP_PARAMETERS[spell_effect].bdam+5*SP_level_dam_adjust(op,caster,spell_effect);
-	tmp->stats.maxhp=tmp->stats.hp;
-	break;
-    case SP_BUILD_LWALL:
-  	sprintf(buf1,"lightningwall_%d",dir);
-	tmp=get_archetype(buf1);
-	SET_FLAG(tmp, FLAG_IS_USED_UP);
-	SET_FLAG(tmp, FLAG_TEAR_DOWN);
-	SET_FLAG(tmp, FLAG_ALIVE);
-        tmp->stats.food=SP_PARAMETERS[spell_effect].bdur+10*SP_level_strength_adjust(op,caster,spell_effect);
-        tmp->stats.hp=SP_PARAMETERS[spell_effect].bdam+5*SP_level_dam_adjust(op,caster,spell_effect);
-	tmp->stats.maxhp=tmp->stats.hp;
-	break;
-    case SP_BUILD_BWALL:
-  	sprintf(buf1,"lbulletwall_%d",dir);
-	tmp=get_archetype(buf1);
-	SET_FLAG(tmp, FLAG_IS_USED_UP);
-	SET_FLAG(tmp, FLAG_TEAR_DOWN);
-	SET_FLAG(tmp, FLAG_ALIVE);
-        tmp->stats.food=SP_PARAMETERS[spell_effect].bdur+10*SP_level_strength_adjust(op,caster,spell_effect);
-        tmp->stats.hp=SP_PARAMETERS[spell_effect].bdam+5*SP_level_dam_adjust(op,caster,spell_effect);
-	tmp->stats.maxhp=tmp->stats.hp;
-	break;
-    case SP_BUILD_FWALL:
-  	sprintf(buf1,"firewall_%d",dir);
-	tmp=get_archetype(buf1);
-	SET_FLAG(tmp, FLAG_IS_USED_UP);
-	SET_FLAG(tmp, FLAG_TEAR_DOWN);
-	SET_FLAG(tmp, FLAG_ALIVE);
-        tmp->stats.food=SP_PARAMETERS[spell_effect].bdur+10*SP_level_strength_adjust(op,caster,spell_effect);
-        tmp->stats.hp=SP_PARAMETERS[spell_effect].bdam+5*SP_level_dam_adjust(op,caster,spell_effect);
-	tmp->stats.maxhp=tmp->stats.hp;
-	break;
-  }
+    object *tmp=NULL;
+    char buf1[20];
+    int putflag=0;
+
+    if(!dir) dir=op->facing;
+    else putflag=1;
+
+    if(blocked(op->map,op->x+freearr_x[dir],op->y+freearr_y[dir])) {
+	new_draw_info(NDI_UNIQUE, 0,op,"Something is in the way.");
+	return 0;
+    }
+
+    switch(spell_effect) {
+	case SP_BUILD_DIRECTOR:
+	    sprintf(buf1,"director_%d",dir);
+	    tmp=get_archetype(buf1);
+	    SET_FLAG(tmp, FLAG_IS_USED_UP);
+	    tmp->stats.food=SP_PARAMETERS[spell_effect].bdur+10*SP_level_strength_adjust(op,caster,spell_effect);
+	    tmp->stats.hp=SP_PARAMETERS[spell_effect].bdam+5*SP_level_dam_adjust(op,caster,spell_effect);
+	    tmp->stats.maxhp=tmp->stats.hp;
+	    break;
+
+	case SP_BUILD_LWALL:
+	    sprintf(buf1,"lightningwall_%d",dir);
+	    tmp=get_archetype(buf1);
+	    SET_FLAG(tmp, FLAG_IS_USED_UP);
+	    SET_FLAG(tmp, FLAG_TEAR_DOWN);
+	    SET_FLAG(tmp, FLAG_ALIVE);
+	    tmp->stats.food=SP_PARAMETERS[spell_effect].bdur+10*SP_level_strength_adjust(op,caster,spell_effect);
+	    tmp->stats.hp=SP_PARAMETERS[spell_effect].bdam+5*SP_level_dam_adjust(op,caster,spell_effect);
+	    tmp->stats.maxhp=tmp->stats.hp;
+	    break;
+
+	case SP_BUILD_BWALL:
+	    sprintf(buf1,"lbulletwall_%d",dir);
+	    tmp=get_archetype(buf1);
+	    SET_FLAG(tmp, FLAG_IS_USED_UP);
+	    SET_FLAG(tmp, FLAG_TEAR_DOWN);
+	    SET_FLAG(tmp, FLAG_ALIVE);
+	    tmp->stats.food=SP_PARAMETERS[spell_effect].bdur+10*SP_level_strength_adjust(op,caster,spell_effect);
+	    tmp->stats.hp=SP_PARAMETERS[spell_effect].bdam+5*SP_level_dam_adjust(op,caster,spell_effect);
+	    tmp->stats.maxhp=tmp->stats.hp;
+	    break;
+
+	case SP_BUILD_FWALL:
+	    sprintf(buf1,"firewall_%d",dir);
+	    tmp=get_archetype(buf1);
+	    SET_FLAG(tmp, FLAG_IS_USED_UP);
+	    SET_FLAG(tmp, FLAG_TEAR_DOWN);
+	    SET_FLAG(tmp, FLAG_ALIVE);
+	    tmp->stats.food=SP_PARAMETERS[spell_effect].bdur+10*SP_level_strength_adjust(op,caster,spell_effect);
+	    tmp->stats.hp=SP_PARAMETERS[spell_effect].bdam+5*SP_level_dam_adjust(op,caster,spell_effect);
+	    tmp->stats.maxhp=tmp->stats.hp;
+	    break;
+    }
+
 #ifdef WALL_CREDIT
-  set_owner(tmp,op);
+    set_owner(tmp,op);
 #endif  /* determines whether someone gets credit for kills. */
-  tmp->level=SK_level(op)/2;  /*  so that the spell that the wall casts
+
+    tmp->level=SK_level(op)/2;  /*  so that the spell that the wall casts
 				 inherit part of the effectiveness of
 				 of the wall builder */
-  tmp->x=op->x;tmp->y=op->y;
-  if(putflag) { tmp->x+=freearr_x[dir];tmp->y+=freearr_y[dir];}
-  if (out_of_map(op->map, tmp->x, tmp->y)) {
-    free_object(tmp);
-    return 0;
-  }
-  insert_ob_in_map(tmp,op->map);
-  if(QUERY_FLAG(tmp, FLAG_BLOCKSVIEW))
-    update_all_los(op->map);
-  if(op->type==PLAYER)
-    draw(op);
-  else
-    SET_FLAG(op, FLAG_SCARED); /* We don't want them to walk through the wall! */
-  return 1;
+    tmp->x=op->x;tmp->y=op->y;
+    if(putflag) { 
+	tmp->x+=freearr_x[dir];
+	tmp->y+=freearr_y[dir];
+    }
+    if (out_of_map(op->map, tmp->x, tmp->y)) {
+	free_object(tmp);
+	return 0;
+    }
+    insert_ob_in_map(tmp,op->map);
+    if(QUERY_FLAG(tmp, FLAG_BLOCKSVIEW))
+	update_all_los(op->map);
+    if(op->type==PLAYER)
+	draw(op);
+    else
+	SET_FLAG(op, FLAG_SCARED); /* We don't want them to walk through the wall! */
+    return 1;
 }
 
 
@@ -2526,7 +2561,7 @@ int summon_cult_monsters(object *op, int dir) {
       
   if (!dir)                               
     dir = find_free_spot(at, op->map, op->x, op->y, 1, SIZEOFFREE);
-  if(arch_blocked(at,op->map, op->x + freearr_x[dir], op->y+freearr_y[dir]))
+  if((dir==-1) || arch_blocked(at,op->map, op->x + freearr_x[dir], op->y+freearr_y[dir]))
   {  
     new_draw_info(NDI_UNIQUE, 0,op, "There is something in the way.");
     if(op->type == PLAYER)
@@ -2627,7 +2662,7 @@ int summon_avatar(object *op,object *caster,int dir, archetype *at, int spellnum
   if(!dir)
     dir = find_free_spot(at, op->map, op->x, op->y, 1, SIZEOFFREE);
 
-  if(arch_blocked(at,op->map, op->x + freearr_x[dir], op->y+freearr_y[dir])) { 
+  if((dir==-1) || arch_blocked(at,op->map, op->x + freearr_x[dir], op->y+freearr_y[dir])) { 
     new_draw_info(NDI_UNIQUE, 0,op,"There is something in the way.");
     if(op->type==PLAYER)
       op->contr->count_left=0;
@@ -2784,7 +2819,7 @@ int cast_consecrate(object *op) {
              tmp->title = add_string(god->name);
              sprintf(buf,"You consecrated the altar to %s!",god->name);
              success = 1;
-	     if(op->type==PLAYER) draw_look(op);
+	     if(op->type==PLAYER) esrv_update_item(UPD_NAME, op, tmp);
              break;
         }
 #endif
@@ -2852,7 +2887,7 @@ int staff_to_snake(object *op,object *caster,int dir, archetype *at, int spellnu
     }
   if(!dir) 
     dir=find_free_spot(NULL,op->map,op->x,op->y,1,9);
-  if(blocked(op->map,op->x+freearr_x[dir],op->y+freearr_y[dir])) {
+  if((dir==-1) || blocked(op->map,op->x+freearr_x[dir],op->y+freearr_y[dir])) {
     new_draw_info(NDI_UNIQUE, 0,op,"There is something in the way.");
     if(op->type==PLAYER)
       op->contr->count_left=0;
@@ -3087,3 +3122,95 @@ int make_object_glow(object *op, int radius, int time) {
    return 1;
 }
 
+
+/*  cast_cause_disease:  this spell looks along <dir> from the
+player and infects someone. */
+
+int cast_cause_disease(object *op, object *caster, int dir, archetype *disease_arch, int type) {
+  int x,y,i;
+  object *walk;
+
+  x = op->x;  y = op->y;
+
+
+  /* search in a line for a victim */
+  for(i=0;i<5;i++) {
+	 x += freearr_x[dir]; y+= freearr_y[dir];
+	 if(out_of_map(op->map,x,y)) continue;
+	 /* search this square for a victim */
+	 for(walk=get_map_ob(op->map,x,y);walk;walk=walk->above)
+		if(QUERY_FLAG(walk,FLAG_MONSTER) 
+			|| !(walk->type==PLAYER)) {  /* found a victim */
+
+		  object *disease = arch_to_object(disease_arch);
+		  set_owner(disease,op);
+		  disease->stats.exp = 0;
+		  disease->level = op->level;
+
+		  /*do level adjustments */
+		  if(disease->stats.wc)
+			 disease->stats.wc +=  SP_level_strength_adjust(op,caster,type)/2;
+
+		  if(disease->magic)
+			 disease->magic += SP_level_strength_adjust(op,caster,type)/4;
+
+		  if(disease->stats.maxhp>0)
+			 disease->stats.maxhp += SP_level_strength_adjust(op,caster,type);
+
+		  if(disease->stats.maxgrace>0)
+			 disease->stats.maxgrace += SP_level_strength_adjust(op,caster,type);
+
+		  if(disease->stats.dam) {
+			 if(disease->stats.dam > 0)
+				disease->stats.dam += SP_level_dam_adjust(op,caster,type);
+			 else disease->stats.dam -= SP_level_dam_adjust(op,caster,type);
+		  }
+
+		  if(disease->last_sp) {
+			 disease->last_sp -= 2*SP_level_dam_adjust(op,caster,type);
+			 if(disease->last_sp <1) disease->last_sp = 1;
+		  }
+
+		  if(disease->stats.maxsp) {
+			 if(disease->stats.maxsp > 0)
+				disease->stats.maxsp += SP_level_dam_adjust(op,caster,type);
+			 else disease->stats.maxsp -= SP_level_dam_adjust(op,caster,type);
+		  }
+		  
+		  if(disease->stats.ac) 
+			 disease->stats.ac += SP_level_dam_adjust(op,caster,type);
+
+		  if(disease->last_eat)
+			 disease->last_eat -= SP_level_dam_adjust(op,caster,type);
+
+		  if(disease->stats.hp)
+			 disease->stats.hp -= SP_level_dam_adjust(op,caster,type);
+
+		  if(disease->stats.sp)
+			 disease->stats.sp -= SP_level_dam_adjust(op,caster,type);
+		  
+
+		  if(infect_object(walk,disease)) {
+			 char buf[128];
+			 object *flash;  /* visual effect for inflicting disease */
+			 sprintf(buf,"You inflict %s on %s!",disease->name,walk->name);
+			 free_object(disease); /* don't need this one anymore */
+			 new_draw_info(NDI_UNIQUE,0,op,buf);
+			 flash=get_archetype("detect_magic");
+			 flash->x = x;
+			 flash->y = y;
+			 flash->map = walk->map;
+			 insert_ob_in_map(flash,walk->map);
+			 return 1;
+		  }
+		  free_object(disease);
+		}
+  }
+  new_draw_info(NDI_UNIQUE,0,op,"No one caught anything!");
+  return 0;
+}
+			 
+			 
+		  
+  
+  
