@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_spells_c =
- *   "$Id: spell_util.c,v 1.27 1998/09/28 04:08:40 master Exp master $";
+ *   "$Id: spell_util.c,v 1.35 1999/03/20 06:51:25 master Exp $";
  */
 
 /*
@@ -520,6 +520,7 @@ if (item == spellNormal && !ability ){
   case SP_CURE_POISON:
   case SP_CURE_CONFUSION:
   case SP_CURE_BLINDNESS:
+  case SP_CURE_DISEASE:
     success = cast_heal(op,dir,type);
     break;
   case SP_REGENERATE_SPELLPOINTS:
@@ -740,7 +741,18 @@ if (item == spellNormal && !ability ){
     success = cast_create_missile(op,caster,dir,stringarg);
     break;
 
+    case SP_CAUSE_EBOLA:
+    case SP_CAUSE_FLU:
+    case SP_CAUSE_PLAGUE:
+    case SP_CAUSE_LEPROSY:
+    case SP_CAUSE_SMALLPOX:
+    case SP_CAUSE_PNEUMONIC_PLAGUE:
+    case SP_CAUSE_ANTHRAX:
+    case SP_CAUSE_TYPHOID:
+	    success = cast_cause_disease(op,caster,dir,spellarch[type],type);
+	    break;
   }
+
   play_sound_map(op->map, op->x, op->y, SOUND_CAST_SPELL_0 + type);
 #ifdef CASTING_TIME
 	  /* free the spell arg */
@@ -777,7 +789,7 @@ int summon_monster(object *op,object *caster,int dir,archetype *at,int spellnum)
     }
   if(!dir)
     dir=find_free_spot(NULL,op->map,op->x,op->y,1,9);
-  if(blocked(op->map,op->x+freearr_x[dir],op->y+freearr_y[dir])) {
+  if((dir==-1) || blocked(op->map,op->x+freearr_x[dir],op->y+freearr_y[dir])) {
     new_draw_info(NDI_UNIQUE, 0,op,"There is something in the way.");
     if(op->type==PLAYER)
       op->contr->count_left=0;
@@ -961,8 +973,9 @@ int fire_arch(object *op,object *caster,int dir,archetype *at, int type, int mag
   tmp->direction=dir;
   set_owner(tmp,op);
 #ifdef MULTIPLE_GODS /* needed for AT_HOLYWORD,AT_GODPOWER stuff */
-  if(tmp->attacktype&AT_HOLYWORD||tmp->attacktype&AT_GODPOWER)
+  if(tmp->attacktype&AT_HOLYWORD||tmp->attacktype&AT_GODPOWER) {
 	      if(!tailor_god_spell(tmp,op)) return 0; 
+  } else /* Ugly else going across endif */
 #endif 
   if(magic)
     tmp->attacktype|=AT_MAGIC;
@@ -1036,62 +1049,77 @@ cast_cone(object *op, object *caster,int dir, int strength, int spell_type,arche
 }
 
 void move_cone(object *op) {
-  int i;
+    int i;
 
-  /* if no map then hit_map will crash so just ignore object */
-  if (! op->map) {
-    LOG(llevError,"Tried to move_cone object %s without a map.\n",
-      op->name ? op->name : "unknown");
-    return;
-  }
-
-  if (QUERY_FLAG(op, FLAG_LIFESAVE)) {/* lava saves it's life, but not yours  :) */
-      hit_map(op,0,op->attacktype);
-      return;
-  }
-  if(get_owner(op)==NULL) {
-    remove_ob(op);
-    free_object(op);
-    return;
-  }
-  /* Hit map returns 1 if it hits a monster.  If it does, set
-   * food to 1, which will stop the cone from progressing.
-   */
-  op->stats.food |= hit_map(op,0,op->attacktype);
-  if((op->stats.hp-=2)<0) {
-    if(op->stats.exp) {
-      op->speed = 0;
-      update_ob_speed(op);
-      op->stats.exp=0;
-      op->stats.sp=0; /* so they will join */
-    } else {
-      remove_ob(op);
-      free_object(op);
+    /* if no map then hit_map will crash so just ignore object */
+    if (! op->map) {
+	LOG(llevError,"Tried to move_cone object %s without a map.\n",
+	    op->name ? op->name : "unknown");
+	return;
     }
-    return;
-  }
-  if(op->stats.food)   return;
-  op->stats.food=1;
-  for(i= -1;i<2;i++) {
-    int x=op->x+freearr_x[absdir(op->stats.sp+i)],
-        y=op->y+freearr_y[absdir(op->stats.sp+i)];
-    if(ok_to_put_more(op->map,x,y,op,op->attacktype)) {
-      object *tmp=arch_to_object(op->arch);
-      set_owner(tmp,op->owner);
-      tmp->x=x, tmp->y=y;
-/* added to make face of death work,and counterspell */
-      /* tmp->level=op->level;*/  
-      tmp->level=SK_level(op);  
+
+    /* lava saves it's life, but not yours  :) */
+    if (QUERY_FLAG(op, FLAG_LIFESAVE)) {
+	hit_map(op,0,op->attacktype);
+	return;
+    }
+
+    /* If no owner left, the spell dies out. */
+    if(get_owner(op)==NULL) {
+	remove_ob(op);
+	free_object(op);
+	return;
+    }
+
+    /* Hit map returns 1 if it hits a monster.  If it does, set
+     * food to 1, which will stop the cone from progressing.
+     */
+    op->stats.food |= hit_map(op,0,op->attacktype);
+
+    if((op->stats.hp-=2)<0) {
+	if(op->stats.exp) {
+	    op->speed = 0;
+	    update_ob_speed(op);
+	    op->stats.exp=0;
+	    op->stats.sp=0; /* so they will join */
+	} else {
+	    remove_ob(op);
+	    free_object(op);
+	}
+	return;
+    }
+
+    if(op->stats.food)   return;
+
+    op->stats.food=1;
+
+    for(i= -1;i<2;i++) {
+	int x=op->x+freearr_x[absdir(op->stats.sp+i)],
+	    y=op->y+freearr_y[absdir(op->stats.sp+i)];
+
+	if(ok_to_put_more(op->map,x,y,op,op->attacktype)) {
+	    object *tmp=arch_to_object(op->arch);
+	    set_owner(tmp,op->owner);
+	    if(op->chosen_skill && (op->chosen_skill != tmp->chosen_skill)){
+		tmp->exp_obj = op->exp_obj;
+		tmp->chosen_skill = op->chosen_skill;
+	    }
+	    tmp->x=x, tmp->y=y;
+
+	    /* added to make face of death work,and counterspell */
+	    tmp->level=SK_level(op);  
+
 #ifdef MULTIPLE_GODS /* holy word stuff */
-      if(tmp->attacktype&AT_HOLYWORD||tmp->attacktype&AT_GODPOWER) 
-            if(!tailor_god_spell(tmp,op)) return;
+	    if(tmp->attacktype&AT_HOLYWORD||tmp->attacktype&AT_GODPOWER) 
+		if(!tailor_god_spell(tmp,op)) return;
 #endif
-      tmp->stats.sp=op->stats.sp,tmp->stats.hp=op->stats.hp+1;
-      tmp->stats.maxhp=op->stats.maxhp;
-      tmp->attacktype=op->attacktype;
-      insert_ob_in_map(tmp,op->map);
+	    tmp->stats.sp=op->stats.sp,tmp->stats.hp=op->stats.hp+1;
+	    tmp->stats.maxhp=op->stats.maxhp;
+	    tmp->stats.dam = op->stats.dam;
+	    tmp->attacktype=op->attacktype;
+	    insert_ob_in_map(tmp,op->map);
+	}
     }
-  }
 }
 
 void fire_a_ball(object *op,int dir,int strength) {
@@ -2002,7 +2030,7 @@ void init_spell_param()
   ATTACKS[21].fg=color_array[black];
   ATTACKS[21].bg=color_array[khaki];  
 
-  sprintf(fname,"%s/spell_params",settings.libdir);
+  sprintf(fname,"%s/spell_params",settings.datadir);
   if(! (spell_params=fopen(fname,"r")))
     {
 	perror(fname);
