@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_time_c =
- *    "$Id: time.c,v 1.40 1998/09/28 04:10:33 master Exp master $";
+ *    "$Id: time.c,v 1.48 1999/03/20 06:53:11 master Exp $";
  */
 
 /*
@@ -82,7 +82,7 @@ void generate_monster(object *gen) {
     return;
   }
   i=find_free_spot(at,gen->map,gen->x,gen->y,1,9);
-  if(!i) return;
+  if (i==-1) return;
   while(at!=NULL) {
     op=arch_to_object(at);
     op->x=gen->x+freearr_x[i]+at->clone.x;
@@ -198,91 +198,131 @@ void poison_more(object *op) {
 
 
 void move_gate(object *op) { /* 1 = going down, 0 = goind up */
-  object *tmp;
-  if(op->stats.wc < 0 || (int)op->stats.wc  >= NUM_ANIMATIONS(op)) {
-    LOG(llevError,"Gate error: animation was %d, max=%d\n",op->stats.wc,
-	NUM_ANIMATIONS(op));
-    dump_object(op);
-    LOG(llevError,"%s\n",errmsg);
-    op->stats.wc=0;
-  }
-  if(op->value) { /* We're going down */
-    if(--op->stats.wc<=0) { /* Reached bottom, let's stop */
-      op->stats.wc=0;
-      if(op->arch->clone.speed)
-        op->value=0;
-      else {
-	op->speed = 0;
-	update_ob_speed(op);
-      }
-#if 0	/* Dont think this is needed, as the section below should be hit */
-      CLEAR_FLAG(op, FLAG_NO_PASS);
-      CLEAR_FLAG(op, FLAG_BLOCKSVIEW);
-      update_all_los(op->map);
-#endif
-    }
-    if((int)op->stats.wc < (NUM_ANIMATIONS(op)/2+1)) {
-      CLEAR_FLAG(op, FLAG_NO_PASS);
-      CLEAR_FLAG(op, FLAG_BLOCKSVIEW);
-      update_all_los(op->map);
-    }
-    SET_ANIMATION(op, op->stats.wc);
-    update_object(op);
-    return;
-  }
-  /* We're going up */
+    object *tmp;
 
-  /* First, lets see if we are already at the top */
-  if((unsigned char) op->stats.wc==(NUM_ANIMATIONS(op)-1)
-     &&op->above==NULL) {
-    if(op->arch->clone.speed)
-      op->value=1;
-    else {
-	op->speed = 0;
-	update_ob_speed(op); /* Reached top, let's stop */
+    if(op->stats.wc < 0 || (int)op->stats.wc  >= NUM_ANIMATIONS(op)) {
+	LOG(llevError,"Gate error: animation was %d, max=%d\n",op->stats.wc,
+	    NUM_ANIMATIONS(op));
+	dump_object(op);
+	LOG(llevError,"%s\n",errmsg);
+	op->stats.wc=0;
     }
-    return;
-  }
-  if(op->stats.food) {    /* The gate is going temporarily down */
-    if(--op->stats.wc<=0) { /* Gone all the way down? */
-      op->stats.food=0;	    /* Then let's try again */
-      op->stats.wc=0;
-    }
-  } else {                /* The gate is still going up */
-    op->stats.wc++;
-    if((int)op->stats.wc >= (NUM_ANIMATIONS(op)))
-      op->stats.wc=(signed char)NUM_ANIMATIONS(op)-1;
 
-    if((int)op->stats.wc >= NUM_ANIMATIONS(op)/2) {
-      /* Halfway or further, check blocks */
-      for(tmp=op->above;tmp!=NULL&&tmp->above!=NULL;tmp=tmp->above); /* top */
-      if(tmp!=NULL) {
-        if(QUERY_FLAG(tmp, FLAG_ALIVE)) {
-          hit_player(tmp,RANDOM()%(op->stats.dam+1)+1,op,AT_PHYSICAL);
-          if(tmp->type==PLAYER) {
-	    new_draw_info_format(NDI_UNIQUE, 0, tmp,
-		"You are crushed by the %s!",op->name);
-          }
-        } else if(!(tmp->speed&&tmp->direction)) {
-          /* If it has speed, it should move itself, otherwise: */
-          int i=find_free_spot(tmp->arch,op->map,op->x,op->y,1,9);
-          remove_ob(tmp);
-          tmp->x+=freearr_x[i],tmp->y+=freearr_y[i];
-          insert_ob_in_map(tmp,op->map);
-        }
-      }
-      if(op->above!=NULL)   /* Still something in the way? */
-        op->stats.food=1;   /* Then let's go down and gather some speed 8) */
-      else {
-        SET_FLAG(op, FLAG_NO_PASS);    /* The coast is clear, block the way */
-        if(!op->arch->clone.stats.ac)
-          SET_FLAG(op, FLAG_BLOCKSVIEW);
-        update_all_los(op->map);
-      }
+    /* We're going down */
+    if(op->value) {
+	if(--op->stats.wc<=0) { /* Reached bottom, let's stop */
+	    op->stats.wc=0;
+	    if(op->arch->clone.speed)
+		op->value=0;
+	    else {
+		op->speed = 0;
+		update_ob_speed(op);
+	    }
+	}
+	if((int)op->stats.wc < (NUM_ANIMATIONS(op)/2+1)) {
+	    CLEAR_FLAG(op, FLAG_NO_PASS);
+	    CLEAR_FLAG(op, FLAG_BLOCKSVIEW);
+	    update_all_los(op->map);
+	}
+	SET_ANIMATION(op, op->stats.wc);
+	update_object(op);
+	return;
     }
-  }
-  SET_ANIMATION(op, op->stats.wc);
-  update_object(op);
+
+    /* We're going up */
+
+    /* First, lets see if we are already at the top */
+    if((unsigned char) op->stats.wc==(NUM_ANIMATIONS(op)-1)) {
+
+	/* Check to make sure that only non pickable and non rollable
+	 * objects are above the gate.  If so, we finish closing the gate,
+	 * otherwise, we fall through to the code below which should lower
+	 * the gate slightly.
+	 */
+
+	for (tmp=op->above; tmp!=NULL; tmp=tmp->above) 
+	    if (!QUERY_FLAG(tmp, FLAG_NO_PICK)
+		|| QUERY_FLAG(tmp, FLAG_CAN_ROLL)
+		|| QUERY_FLAG(tmp, FLAG_ALIVE))
+		break;
+
+	if (tmp==NULL) {
+	    if(op->arch->clone.speed)
+		op->value=1;
+	    else {
+		op->speed = 0;
+		update_ob_speed(op); /* Reached top, let's stop */
+	    }
+	    return;
+	}
+    }
+
+    if(op->stats.food) {    /* The gate is going temporarily down */
+	if(--op->stats.wc<=0) { /* Gone all the way down? */
+	    op->stats.food=0;	    /* Then let's try again */
+	    op->stats.wc=0;
+	}
+    } else {                /* The gate is still going up */
+	op->stats.wc++;
+
+	if((int)op->stats.wc >= (NUM_ANIMATIONS(op)))
+	    op->stats.wc=(signed char)NUM_ANIMATIONS(op)-1;
+
+	/* If there is something on top of the gate, we try to roll it off.
+	 * If a player/monster, we don't roll, we just hit them with damage
+	 */
+	if((int)op->stats.wc >= NUM_ANIMATIONS(op)/2) {
+	    /* Halfway or further, check blocks */
+	    /* First, get the top object on the square. */
+	    for(tmp=op->above;tmp!=NULL && tmp->above!=NULL;tmp=tmp->above);
+
+	    if(tmp!=NULL) {
+		if(QUERY_FLAG(tmp, FLAG_ALIVE)) {
+		    hit_player(tmp,RANDOM()%(op->stats.dam+1)+1,op,AT_PHYSICAL);
+		    if(tmp->type==PLAYER) 
+			new_draw_info_format(NDI_UNIQUE, 0, tmp,
+					     "You are crushed by the %s!",op->name);
+		} else 
+		    /* If the object is not alive, and the object either can
+		     * not be picked up or the object rolls, move the object
+		     * off the gate.
+		     */
+		    if(!QUERY_FLAG(tmp, FLAG_ALIVE)
+			&& (!QUERY_FLAG(tmp, FLAG_NO_PICK)
+			   ||QUERY_FLAG(tmp,FLAG_CAN_ROLL))) {
+		    /* If it has speed, it should move itself, otherwise: */
+		    int i=find_free_spot(tmp->arch,op->map,op->x,op->y,1,9);
+
+		    /* If there is a free spot, move the object someplace */
+		    if (i!=-1) {
+			remove_ob(tmp);
+			tmp->x+=freearr_x[i],tmp->y+=freearr_y[i];
+			insert_ob_in_map(tmp,op->map);
+		    }
+		}
+	    }
+
+	    /* See if there is still anything blocking the gate */
+	    for (tmp=op->above; tmp!=NULL; tmp=tmp->above) 
+		if (!QUERY_FLAG(tmp, FLAG_NO_PICK)
+			|| QUERY_FLAG(tmp, FLAG_CAN_ROLL)
+			|| QUERY_FLAG(tmp, FLAG_ALIVE))
+		    break;
+
+	    /* IF there is, start putting the gate down  */
+	    if(tmp) {
+		    op->stats.food=1;
+	    } else {
+		SET_FLAG(op, FLAG_NO_PASS);    /* The coast is clear, block the way */
+		if(!op->arch->clone.stats.ac)
+		    SET_FLAG(op, FLAG_BLOCKSVIEW);
+		update_all_los(op->map);
+	    }
+	} /* gate is halfway up */
+
+	SET_ANIMATION(op, op->stats.wc);
+	update_object(op);
+    } /* gate is going up */
 }
 
 /*  hp      : how long door is open/closed
@@ -317,38 +357,40 @@ void move_timed_gate(object *op)
 
 void move_detector(object *op) 
 {
-  object *tmp;
-  int last = op->value;
-  int detected;
-  detected = 0;
-  for(tmp = get_map_ob(op->map,op->x,op->y);tmp!=NULL&&!detected;tmp=tmp->above)
-    if (!strcmp(op->slaying,tmp->name))
-		{
-		  detected = 1;
-		}
-  
-  if(op->stats.sp == 1) 
-	 {
-		if(detected && last == 0) {
-		  op->value = 1;
-		  update_button(op);
-		}
-		if(!detected && last == 1) {
-		  op->value = 0;
-		  update_button(op);
-		}
-	 }
-  else
-	 {
-		if(detected && last == 1) {
-		  op->value = 0;
-		  update_button(op);
-		}
-		if(!detected && last == 0) {
-		  op->value = 1;
-		  update_button(op);
-		}
-	 }
+    object *tmp;
+    int last = op->value;
+    int detected;
+    detected = 0;
+
+    for(tmp = get_map_ob(op->map,op->x,op->y);tmp!=NULL&&!detected;tmp=tmp->above) {
+	if (!strcmp(op->slaying,tmp->name)) {
+	  detected = 1;
+	}
+	else if (tmp->type==SPECIAL_KEY && tmp->slaying==op->slaying)
+	    detected=1;
+    }
+
+    /* the detector sets the button if detection is found */
+    if(op->stats.sp == 1)  {
+	if(detected && last == 0) {
+	    op->value = 1;
+	    push_button(op);
+	}
+	if(!detected && last == 1) {
+	    op->value = 0;
+	    push_button(op);
+	}
+    }
+    else { /* in this case, we unset buttons */
+	if(detected && last == 1) {
+	    op->value = 0;
+	    push_button(op);
+	}
+	if(!detected && last == 0) {
+	    op->value = 1;
+	    push_button(op);
+	}
+    }
 }
 
 
@@ -363,31 +405,35 @@ void animate_trigger (object *op)
 }
 
 void move_hole(object *op) { /* 1 = opening, 0 = closing */
-  if(op->value) { /* We're opening */
-    if(--op->stats.wc<=0) { /* Opened, let's stop */
-      op->stats.wc=0;
-      op->speed = 0;
-      update_ob_speed(op);
-      SET_FLAG(op, FLAG_WALK_ON);
-      while(op->above!=NULL && apply(op->above,op,0))
-        ;
+    object *next,*tmp;
+
+    if(op->value) { /* We're opening */
+	if(--op->stats.wc<=0) { /* Opened, let's stop */
+	    op->stats.wc=0;
+	    op->speed = 0;
+	    update_ob_speed(op);
+	    SET_FLAG(op, FLAG_WALK_ON);
+	    for (tmp=op->above; tmp!=NULL; tmp=next) {
+		next=tmp->above;
+		apply(tmp,op,0);
+	    }
+	}
+	SET_ANIMATION(op, op->stats.wc);
+	update_object(op);
+	return;
     }
+    /* We're closing */
+    CLEAR_FLAG(op, FLAG_WALK_ON);
+    op->stats.wc++;
+    if((int)op->stats.wc >= NUM_ANIMATIONS(op))
+	op->stats.wc=NUM_ANIMATIONS(op)-1;
     SET_ANIMATION(op, op->stats.wc);
     update_object(op);
-    return;
-  }
-  /* We're closing */
-  CLEAR_FLAG(op, FLAG_WALK_ON);
-  op->stats.wc++;
-  if((int)op->stats.wc >= NUM_ANIMATIONS(op))
-    op->stats.wc=NUM_ANIMATIONS(op)-1;
-  SET_ANIMATION(op, op->stats.wc);
-  update_object(op);
-  if((unsigned char) op->stats.wc==(NUM_ANIMATIONS(op)-1)) {
-    op->speed = 0;
-    update_ob_speed(op); /* closed, let's stop */
-    return;
-  }
+    if((unsigned char) op->stats.wc==(NUM_ANIMATIONS(op)-1)) {
+	op->speed = 0;
+	update_ob_speed(op); /* closed, let's stop */
+	return;
+    }
 }
 
 
@@ -747,6 +793,10 @@ int process_object(object *op) {
     if(QUERY_FLAG(op, FLAG_APPLIED))
       remove_force(op);
     else {
+	/* IF necessary, delete the item from the players inventory */
+	object *pl=is_player_inv(op);
+	if (pl)
+	    esrv_del_item(pl->contr, op->count);
       remove_ob(op);
       if (QUERY_FLAG(op, FLAG_SEE_ANYWHERE))
         make_sure_not_seen(op);
@@ -771,6 +821,12 @@ int process_object(object *op) {
   case POISONING:
     poison_more(op);
     return 0;
+  case DISEASE:
+	 move_disease(op);
+	 return 0;
+  case SYMPTOM:
+	 move_symptom(op);
+	 return 0;
   case WORD_OF_RECALL:
     execute_wor(op);
     return 0;
